(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    271111,       7695]
NotebookOptionsPosition[    243956,       7289]
NotebookOutlinePosition[    244635,       7311]
CellTagsIndexPosition[    244592,       7308]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.759061079395566*^9, 
  3.75906108022565*^9}},ExpressionUUID->"46e16825-9137-474e-8a90-\
926dc5d4657e"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["\n",
  FontSize->12],
 "\t\t\n",
 StyleBox["RIEMANNIAN GEOMETRY & TENSOR CALCULUS\n",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox["A set of functions for tensor calculations in Riemannian Geometry \
and General Relativity\n",
  FontSize->16]
}], "Text",
 ShowGroupOpener->True,
 CellChangeTimes->{3.7957916298156147`*^9},
 TextAlignment->Center,
 TextJustification->0,
 FontColor->RGBColor[
  0, 0, 1],ExpressionUUID->"93712e9f-463d-418a-aa7e-ede3df646b0f"],

Cell["version 3.8.9 - May 2013", "Text",
 TextAlignment->Center,
 TextJustification->0,
 FontFamily->"Times",
 FontSize->14,
 FontSlant->"Italic",ExpressionUUID->"5d38bb7e-caba-4a3a-819d-4ab9175b2d11"],

Cell[TextData[{
 StyleBox["\n",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ButtonBox["S. Bonanos",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/~sbonano/SB.html"], None}],
 StyleBox["\n",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["\n",
  FontWeight->"Bold"],
 StyleBox[ButtonBox["Institute of Nuclear Physics",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/"], None}],
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[",  ",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[ButtonBox["NCSR \"Demokritos\"",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.demokritos.gr/index_muk.asp"], None}],
  FontSlant->"Italic"],
 StyleBox[", \nAghia Paraskevi 15310, Greece. ",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["\n",
  FontSize->14,
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["\n",
  FontWeight->"Bold"],
 "Please send comments, suggestions, bug reports to:  ",
 ButtonBox["sbonano@inp.demokritos.gr",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["mailto:sbonano@inp.demokritos.gr"], None}],
 StyleBox[" \t",
  FontWeight->"Bold"]
}], "Text",
 TextAlignment->Center,
 TextJustification->0,
 FontFamily->"Times",
 FontSize->16,ExpressionUUID->"c55db92e-c919-43f8-8a2b-3ac0cca1e381"]
}, Closed]],

Cell[TextData[{
 "\[CapitalDelta]\[Omega]\[Rho]\[Epsilon]",
 Cell[BoxData[
  StyleBox[
   OverscriptBox["\[Alpha]", "`"],
   FontFamily->"Times"]],ExpressionUUID->
  "24ca4384-d95f-4192-9bae-99901c84f207"],
 "\[Nu] \[Epsilon]\[Lambda]",
 Cell[BoxData[
  StyleBox[
   OverscriptBox["\[Alpha]", "'"],
   FontFamily->"Times"]],ExpressionUUID->
  "8411ef51-9cf9-48d6-ad67-4f0fad1a60a6"],
 "\[Beta]\[Epsilon]\[Tau]\[Epsilon], \[Delta]\[Omega]\[Rho]\[Epsilon]",
 Cell[BoxData[
  StyleBox[
   OverscriptBox["\[Alpha]", "`"],
   FontFamily->"Times"]],ExpressionUUID->
  "fa7157d4-992b-45ef-9b1d-4d71a0939f7c"],
 "\[Nu] \[Delta]",
 Cell[BoxData[
  StyleBox[
   OverscriptBox["o", "'"],
   FontFamily->"Times"]],ExpressionUUID->
  "58e12e2c-1123-42a4-8422-e378d1f59fbb"],
 "\[Tau]\[Epsilon]."
}], "Text",
 TextAlignment->Center,
 TextJustification->0,
 FontFamily->"Helvetica",
 FontSize->24,
 FontColor->GrayLevel[
  1],ExpressionUUID->"873d17d5-d20d-454f-9abb-c61f78b0b6bd"],

Cell[CellGroupData[{

Cell[TextData[StyleBox[" 1  Instructions",
 FontWeight->"Bold"]], "Section",
 ShowGroupOpener->True,
 FontSize->24,
 FontColor->RGBColor[
  0, 0, 1],ExpressionUUID->"173c2924-6d97-4a8d-a555-e9aae66fa09a"],

Cell[CellGroupData[{

Cell["  1.0  Introduction", "Subsection",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"2b324f19-b4f9-480b-a233-3efa58047f54"],

Cell[TextData[{
 StyleBox["\t",
  FontWeight->"Bold"],
 "This package allows calculations in Riemannian Geometry by defining all \
basic tensors and tensor operations. Tensors are represented as nested lists \
of their components in a particular frame (default = coordinate frame). \
Functions are defined for Raising/Lowering indices, Contracting (multiple) \
indices on one (or between two) tensors, for Covariant and Lie \
Differentiation and for classifying the Weyl and Ricci tensors. One can also \
use standard ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions like ",
 StyleBox["Dot",
  FontFamily->"Courier"],
 " or ",
 StyleBox["Outer",
  FontFamily->"Courier"],
 " (giving tensor products), and ",
 StyleBox["Transpose",
  FontFamily->"Courier"],
 " (index rearrangement) to create new (lists representing) tensors. "
}], "Text",
 FontSize->16,ExpressionUUID->"4c8972a6-079f-4079-9879-4b2f18827fb8"],

Cell[TextData[{
 "\tGiven a metric and a set of coordinates, the main routine in the package \
computes explicit expressions for all common Riemannian Geometry tensors \
(Riemann, Ricci, Einstein, Weyl) and tests if the space belongs to any of the \
following categories: ",
 StyleBox["Flat",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Conformally Flat",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Ricci Flat",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Einstein Space",
  FontSlant->"Italic"],
 " or ",
 StyleBox["Space of Constant Curvature",
  FontSlant->"Italic"],
 ". Each tensor is stored as a nested list under an appropriate global name. \
One can optionally specify a frame (if different from the coordinate frame) \
with respect to which tensor components are to be computed. "
}], "Text",
 FontSize->16,ExpressionUUID->"69fb5a1d-8a3a-460d-9255-7d430e99623f"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"8e4e2d16-e356-49f4-a4d7-0562ee64125a"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"11d8edbd-1893-4f70-a064-7e3c4ef6567e"],
 "\tThe Riemann and Ricci tensor sign conventions used are:  ",
 Cell[BoxData[
  TagBox[
   SubscriptBox["V", 
    RowBox[{"b", ";", "c", ";", "d"}]],
   DisplayForm]],ExpressionUUID->"ca7cc13a-0049-43b3-a574-3780e94d32d5"],
 " - ",
 Cell[BoxData[
  TagBox[
   SubscriptBox["V", 
    RowBox[{"b", ";", "d", ";", "c"}]],
   DisplayForm]],ExpressionUUID->"68eeb83b-9474-48d4-b052-c8618385b70f"],
 " = ",
 Cell[BoxData[
  SubscriptBox["V", "a"]],ExpressionUUID->
  "a74cce34-12b7-4ff0-9966-25fca1f673fe"],
 StyleBox[" ",
  FontSize->12],
 Cell[BoxData[
  TagBox[
   SubscriptBox[
    SuperscriptBox["R", "a"], "bcd"],
   DisplayForm]],ExpressionUUID->"34caa812-7952-4b34-9beb-070f7d01ac4b"],
 " and ",
 Cell[BoxData[
  SubscriptBox["R", "ab"]],ExpressionUUID->
  "edc13696-b30c-407e-97e1-bbdb2c1dd573"],
 " = ",
 Cell[BoxData[
  TagBox[
   SubscriptBox[
    SuperscriptBox["R", "s"], "asb"],
   DisplayForm]],ExpressionUUID->"26c8710f-10db-48f8-a5c9-2df7b935b8cb"],
 ", so that Einstein's equations are ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["R", "ab"], "-", 
    RowBox[{
     FractionBox["1", "2"], "R", " ", 
     SubscriptBox["g", "ab"]}]}], "=", 
   RowBox[{
    RowBox[{"+", "\[Kappa]"}], " ", 
    SubscriptBox["T", "ab"]}]}]],ExpressionUUID->
  "d80cce7c-2262-47e7-93a3-0ba07ecea3f9"],
 " (",
 Cell[BoxData[
  RowBox[{"\[Kappa]", "=", 
   RowBox[{"8", " ", "\[Pi]", " ", 
    RowBox[{"G", "/", 
     SuperscriptBox["c", "4"]}]}]}]],ExpressionUUID->
  "c940e74b-f682-4ffe-845e-0606a8c5284e"],
 ")."
}], "Text",
 FontSize->16,ExpressionUUID->"2c670a48-25e0-4fd7-9369-054957ac0082"]
}, Closed]],

Cell[CellGroupData[{

Cell["  1.1  Basic Input /Output & Notation", "Subsection",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"6caee4e7-dbdf-4e38-bac3-2e8699d611ab"],

Cell[TextData[{
 StyleBox["\t",
  FontWeight->"Bold"],
 "To define the geometry, begin by computing all basic Riemannian Geometry \
tensors for a particular metric. To do this:\n",
 StyleBox["\t ",
  FontWeight->"Bold"],
 "(0) In a new notebook, evaluate the initialization code: ",
 StyleBox["<<EDCRGTCcode.m",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "\n\t (1) Define a list symbols (coordinate names) and give it a name -- say \
",
 StyleBox["xIN",
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["=",
  FontFamily->"Courier",
  FontSize->18],
 StyleBox["{t,r,\[Theta],\[Phi]};",
  FontFamily->"Courier"],
 "\n\t (2) Define a symmetric matrix (list of lists) of functions of the \
coordinates (the metric) and give it a name -- say \n",
 StyleBox["gIN",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["={{1-2M/r,0,0,0},{0,-1/(1-2M/r),0,0},{0,0,-r^2,0},{0,0,0,-(r^2 \
Sin[\[Theta]]^2)}};",
  FontFamily->"Courier"],
 "\n\t(3) Assign appropriate simplification rules to the global list ",
 StyleBox["simpRules",
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold"],
 " as needed (see Examples and Usage Tips). For example: ",
 StyleBox["simpRules={",
  FontFamily->"Courier"],
 Cell[BoxData[
  StyleBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "\[Theta]", "]"}], "^", "2"}], "+", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "^", "2"}]}], "->", "1"}],
   FontFamily->"Courier"]],ExpressionUUID->
  "9f8be087-7df0-4e0b-8439-539fd8c0e8cc"],
 StyleBox["};",
  FontFamily->"Courier"],
 "\n\t(4) Evaluate ",
 StyleBox["RGtensors[gIN,xIN]",
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold"]
}], "Text",
 FontSize->16,ExpressionUUID->"5f209b81-a7b6-4560-967c-b30ccadb1815"],

Cell[CellGroupData[{

Cell[TextData[{
 "\t",
 StyleBox["RGtensors",
  FontWeight->"Bold"],
 "  computes all common Riemannian Geometry tensors, printing messages along \
the way. It also tests if the space is ",
 StyleBox["Flat,",
  FontSlant->"Italic"],
 " ",
 StyleBox["Conformally Flat",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Ricci Flat",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Einstein Space",
  FontSlant->"Italic"],
 " or ",
 StyleBox["Space of Constant Curvature",
  FontSlant->"Italic"],
 " and, if yes, prints corresponding messages. When it is finished, the \
following \"tensors\" -- nested lists -- are stored in memory and can be used \
in further calculations (the letters U, d  in the tensor names serve as \
mnemonic devices for the position -- ",
 StyleBox["Up",
  FontSlant->"Italic"],
 " or ",
 StyleBox["down",
  FontSlant->"Italic"],
 " -- of the relevant indices) :"
}], "Text",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"68bf135f-0e63-4ca9-9f3a-6c16c774fa8f"],

Cell[TextData[{
 "\t",
 StyleBox["gdd",
  FontFamily->"Courier"],
 " (covariant form of the metric tensor), with components gdd[[a,b]] = ",
 Cell[BoxData[
  SubscriptBox["g", "ab"]],ExpressionUUID->
  "5c370781-9274-472c-8bce-7aec3ed44944"]
}], "Text",
 FontSize->16,ExpressionUUID->"18e13e01-555f-4c6e-91cb-19935052484f"],

Cell[TextData[{
 "\t",
 StyleBox["gUU",
  FontFamily->"Courier"],
 " (contravariant form of the metric tensor), with components gUU[[a,b]] = ",
 Cell[BoxData[
  SuperscriptBox["g", "ab"]],ExpressionUUID->
  "de728131-b198-4a5e-8696-7e87354f23ee"]
}], "Text",
 FontSize->16,ExpressionUUID->"47be14e5-260f-41b5-bd36-4ab48f10f48d"],

Cell[TextData[{
 "\t",
 StyleBox["GUdd",
  FontFamily->"Courier"],
 " (Christoffel symbols of the 2nd kind), with components GUdd[[a,b,c]] = ",
 Cell[BoxData[
  TagBox[
   SubsuperscriptBox["\[CapitalGamma]", "bc", "a"],
   DisplayForm]],ExpressionUUID->"e769a8ce-423a-4b09-a23a-0a97212271fa"]
}], "Text",
 FontSize->16,ExpressionUUID->"9f05d15d-1a7e-4ab6-b139-6ec1544670f6"],

Cell[TextData[{
 "\t",
 StyleBox["Rdddd",
  FontFamily->"Courier"],
 " (covariant form of the Riemann tensor), with components Rdddd[[a,b,c,d]] = \
",
 Cell[BoxData[
  TagBox[
   SubscriptBox["R", "abcd"],
   DisplayForm]],ExpressionUUID->"f6931190-40eb-4ada-b952-e99ec7874e3a"]
}], "Text",
 FontSize->16,ExpressionUUID->"3780f30b-e153-437d-89b3-3ed073daf029"],

Cell[TextData[{
 "\t",
 StyleBox["RUddd",
  FontFamily->"Courier"],
 " (mixed form of the Riemann tensor), with components RUddd[[a,b,c,d]] = ",
 Cell[BoxData[
  TagBox[
   SubscriptBox[
    SuperscriptBox["R", "a"], "bcd"],
   DisplayForm]],ExpressionUUID->"419e28e7-36c4-4886-95e0-39a67cc3c9be"]
}], "Text",
 FontSize->16,ExpressionUUID->"1b41e437-9be5-455f-bfe6-7014cd463f88"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"112bbba7-4e30-42b8-bb0a-7e51d74b039a"],
 "\t",
 StyleBox["Rdd",
  FontFamily->"Courier"],
 " (covariant form of the Ricci tensor), with components Rdd[[a,b]] = ",
 Cell[BoxData[
  SubscriptBox["R", "ab"]],ExpressionUUID->
  "7527250a-ffdb-4c74-a2b9-69102e6bfe7c"],
 " \[Congruent] ",
 Cell[BoxData[
  TagBox[
   SubscriptBox[
    SuperscriptBox["R", "s"], "asb"],
   DisplayForm]],ExpressionUUID->"20d8ee07-6a99-4939-ba37-b9ae3acb1b44"]
}], "Text",
 FontSize->16,ExpressionUUID->"9972d9ed-e4c5-4de4-9df0-cbaf8f52e1bf"],

Cell[TextData[{
 "\t",
 StyleBox["EUd",
  FontFamily->"Courier"],
 " (mixed form of the Einstein tensor), with components EUd[[a,b]] = ",
 Cell[BoxData[
  TagBox[
   SubscriptBox[
    SuperscriptBox["E", "a"], "b"],
   DisplayForm]],ExpressionUUID->"4872f340-1140-43e1-a8b5-397b610de8ae"],
 " \[Congruent] ",
 Cell[BoxData[
  TagBox[
   SubscriptBox[
    SuperscriptBox["R", "a"], "b"],
   DisplayForm]],ExpressionUUID->"8ca874c9-3193-4971-b9c4-291f3443d37e"],
 "- ",
 StyleBox["R/2",
  FontFamily->"Courier"],
 " ",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["\[Delta]", "a"], "b"]],ExpressionUUID->
  "d83ab06b-0ef7-408b-aeb8-1543f69ecb38"]
}], "Text",
 FontSize->16,ExpressionUUID->"eedf1b2b-5ac2-4884-b9c3-b5aa3ec0ccab"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"11bff91c-3478-4f8d-bcdb-e2032d9a1b28"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"9f565c53-25f7-4a6a-8154-baff152bc7a1"],
 "\t",
 StyleBox["R",
  FontFamily->"Courier"],
 " is the curvature scalar    (",
 StyleBox["Important: Do not use the symbol R in coordinates or metric!",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ")"
}], "Text",
 FontSize->16,ExpressionUUID->"2bb2efa8-a043-4f9c-8043-0e2250e5bea7"],

Cell[TextData[{
 "\t",
 StyleBox["Wdddd",
  FontFamily->"Courier"],
 " (covariant form of the Weyl tensor), with components Wdddd[[a,b,c,d]] = ",
 Cell[BoxData[
  SubscriptBox["W", "abcd"]],ExpressionUUID->
  "a70093fc-f959-4b66-a9a1-c74d79f000fa"]
}], "Text",
 FontSize->16,ExpressionUUID->"ac57db93-a796-4e9c-8bca-ae7433ded89f"]
}, Closed]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"73866271-6541-45b0-b680-3fdfdfcc56cd"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"5dbfdcb7-1391-4df5-a249-1d4039ef5db3"],
 "\tFinally, ",
 StyleBox["RGtensors",
  FontWeight->"Bold"],
 " defines the following global variables: (i) ",
 StyleBox["coordList",
  FontFamily->"Courier"],
 " contains the coordinates defined in (1) above, (ii) ",
 StyleBox["detg",
  FontFamily->"Courier"],
 " is the determinant of the metric, (iii) ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 " stores the dimension of the space and (iv) ",
 StyleBox["LineElement",
  FontFamily->"Courier"],
 " stores, of course, the line element! Tensor components refer to the \
coordinate frame and are numbered ",
 StyleBox["1,...,Dim",
  FontFamily->"Courier"],
 ", rather than ",
 StyleBox["0,...,Dim-1",
  FontFamily->"Courier"],
 ", so that the {i,j...k} component of a tensor is the [[i,j...k]] part of \
the corresponding nested list. See section 5, \"",
 StyleBox["Calculating Tensor Components in an Arbitrary Frame",
  FontSlant->"Italic"],
 "\", on how to do calculations in an arbitrary frame. "
}], "Text",
 FontSize->16,ExpressionUUID->"e5b3baba-41da-4518-bcf3-2096c7e90d85"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"c1c228a5-c8a8-41f9-a6be-0871139f664c"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"716c70a1-c6a1-4008-a25e-e3f7b3584001"],
 "\t",
 StyleBox["Note",
  FontSlant->"Italic"],
 ": One can choose to skip the most time consuming computations: RUddd, Wdddd \
or EUd. This can be achieved by calling ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 "  with an optional extra argument -- a list of three numbers ",
 StyleBox["{i,j,k}",
  FontFamily->"Courier"],
 ". When the first number is 0, RUddd is not computed; when the second number \
is 0, Wdddd is not computed; and when the third number is 0, EUd is not \
computed. Thus ",
 StyleBox["RGtensors[gIN,xIN,{1,0,0}]",
  FontFamily->"Courier"],
 "  will compute RUddd but not Wdddd or EUd (See Examples 7 and 8). ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " prints warning messages when some tensors are not computed. When EUd is \
not computed, the tests for ",
 StyleBox["Einstein Space",
  FontSlant->"Italic"],
 " and ",
 StyleBox["Space of Constant Curvature",
  FontSlant->"Italic"],
 " are not performed. For compatibility with previous versions of RGTC, the \
optional extra argument can consist of only two numbers corresponding to \
RUddd and Wdddd. Thus ",
 StyleBox["RGtensors[gIN,xIN,{1,0}]",
  FontFamily->"Courier"],
 " is equivalent to ",
 StyleBox["RGtensors[gIN,xIN,{1,0,1}]",
  FontFamily->"Courier"],
 "."
}], "Text",
 FontSize->16,ExpressionUUID->"0d551833-618c-413f-b08d-64e5e8b7137e"],

Cell[CellGroupData[{

Cell["\t1.1.1  Totally antisymmetric symbol / tensor", "Subsubsection",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"0e534907-8848-4087-bfa8-a7b970096715"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"d1ce9ae3-d050-4c3c-b99d-c09b7330009d"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"d68aa92e-3d0c-4502-b972-900ea8e0c393"],
 "\t Definitions for the totally antisymmetric symbol ",
 Cell[BoxData[
  SubscriptBox["\[CurlyEpsilon]", 
   RowBox[{
    RowBox[{"a1", "..."}], "an"}]]],ExpressionUUID->
  "54ab0df6-130d-43b8-be5e-78e8645783ff"],
 " and tensor  ",
 Cell[BoxData[
  SubscriptBox["\[Eta]", 
   RowBox[{
    RowBox[{"a1", "..."}], "an"}]]],ExpressionUUID->
  "6ebc5fa0-a844-4361-93d7-731b2c95a671"],
 " are provided, but the tensor is not evaluated unless called by the user. \
As the number of indices on these objects equals the dimension of the \
mannifold, the U/d notation cannot be used. Instead, the following global \
names are used:"
}], "Text",
 FontSize->16,ExpressionUUID->"a59513f9-7c51-4b43-a546-e76fce43ae08"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"d0ed674b-7269-4f9f-9972-4b3434371662"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"08052899-6070-4301-a8fd-d07a18b4d295"],
 "\t ",
 StyleBox["epsilon",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a ",
 StyleBox["function",
  FontSlant->"Italic"],
 " that takes ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 " integers as arguments and returns one of { 0, 1, -1} - the sign of the \
permutation of the arguments. For example, in 5 dimensions,"
}], "Text",
 FontSize->16,ExpressionUUID->"3e4b7901-2c3d-405e-ae78-271120c697a7"],

Cell[TextData[{
 "\t",
 StyleBox["epsilon[1,2,3,4,5]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" ",
  FontWeight->"Bold"],
 "returns 1,  ",
 StyleBox["epsilon[1,3,2,4,5]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" ",
  FontWeight->"Bold"],
 "returns -1, and  ",
 StyleBox["epsilon[1,2,2,4,5]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" ",
  FontWeight->"Bold"],
 "returns 0."
}], "Text",
 FontSize->16,ExpressionUUID->"719c43b6-1ad9-4a4f-845d-c6f829573e51"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"e4505245-2fc2-4495-87b0-8abe0e37d55b"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"8148ec8a-bf70-4a52-80f0-18f8a7f13e51"],
 "\t",
 StyleBox["eta[]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " can take 0 to ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 " arguments and returns the ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "-rank antisymmetric tensor with raised indices at the position(s) indicated \
by the argument(s). Thus ",
 StyleBox["eta[]",
  FontFamily->"Courier"],
 " is the totally covariant antisymmetric tensor, with components"
}], "Text",
 FontSize->16,ExpressionUUID->"9a81196d-fdbf-46dd-8263-bec2986157c0"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"69a6a545-44d8-4dde-9fc3-116fb855407b"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"dc994884-2389-429b-a9d4-189805ccc21c"],
 "\t",
 StyleBox["eta[][[a1,a2,...,an]]=",
  FontFamily->"Courier"],
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"\[LeftBracketingBar]", "detg", "\[RightBracketingBar]"}], ")"}], 
   
   RowBox[{"1", "/", "2"}]]],ExpressionUUID->
  "7bf0cde8-a37f-4910-a085-b57271dd99d5"],
 StyleBox["epsilon[a1,a2,...,an]",
  FontFamily->"Courier"],
 ", "
}], "Text",
 FontSize->16,ExpressionUUID->"1d378a62-742f-4d30-b712-622170e94e08"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"b3f44843-a638-4767-bbbb-beeb7e73eaae"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"b1fd23be-45d3-43e9-8d24-9a1a39aa66b2"],
 "while"
}], "Text",
 FontSize->16,ExpressionUUID->"932ceba4-13ce-4423-99df-dabfee9f8d76"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"7fd3b7eb-659a-47c9-9a67-8a45c4fe0a3d"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"b9d3a111-4b0f-432b-a06e-af876cd7894e"],
 "\t",
 StyleBox["eta[2,3][[a1,a2,...,an]]=",
  FontFamily->"Courier"],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"\[LeftBracketingBar]", "detg", "\[RightBracketingBar]"}], ")"}], 
    RowBox[{"1", "/", "2"}]], 
   SuperscriptBox["g", 
    RowBox[{"a2", " ", "b2"}]]}]],ExpressionUUID->
  "3c229198-ed0a-425e-a7bd-265d95feaa63"],
 Cell[BoxData[
  SuperscriptBox["g", 
   RowBox[{"a3", " ", "b3"}]]],ExpressionUUID->
  "5caa6ce4-86b7-4e09-8608-945a8a0f9ddf"],
 StyleBox["epsilon[a1,b2,b3,..,an]",
  FontFamily->"Courier"],
 "."
}], "Text",
 FontSize->16,ExpressionUUID->"56e76f6b-150d-4644-bc65-3d2eb67e69eb"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"ee6a1415-5998-4dc0-b511-11d856559001"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"b0c90c67-2e3d-4428-8e87-26d4e1015428"],
 "\t",
 StyleBox["Warning",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ": The evaluation of ",
 StyleBox["eta[]",
  FontFamily->"Courier"],
 " tensors (",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "-fold nested lists) is ",
 StyleBox["very",
  FontSlant->"Italic"],
 " time consuming in high dimensions as the number of components grows as ",
 Cell[BoxData[
  SuperscriptBox["Dim", "Dim"]],ExpressionUUID->
  "da39a714-ef14-45a3-9229-63b379c2931b"],
 ". It also requires large amounts of memory. For example, for the simple \
case of a conformally flat metric, the {Time, Storage} requirements for \
computing ",
 StyleBox["each",
  FontSlant->"Italic"],
 " ",
 StyleBox["eta[]",
  FontFamily->"Courier"],
 " grow as follows: ",
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"9ca4cd38-28f0-4a65-b7df-76c2019b55ad"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"24c05a1c-406e-44cf-bb39-603352a1caa7"],
 "{~1 sec, <1 MB} for ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "=6, {~20 sec, ~7 MB} for ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "=7, and {> 10 min, >120 MB} for ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "=8! Thus, calculations with ",
 StyleBox["eta[]",
  FontFamily->"Courier"],
 " should not be attempted if ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 ">7. Fortunately, for ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "=4 the requirements are quite modest, even for complicated metrics."
}], "Text",
 FontSize->16,ExpressionUUID->"feb250c6-0dc5-4864-af65-c9721ed52b1a"]
}, Open  ]],

Cell[TextData[{
 "\n",
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"0e0ede58-a07f-42ad-9d91-c5048752b455"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"b0529de6-f9d9-402e-a098-d0a29503161b"],
 "\tOnce the basic tensors have been computed, one can use the functions \
defined in the following sections to perform further calculations."
}], "Text",
 FontSize->16,ExpressionUUID->"4c2f5789-22bd-4eeb-b883-c6b8022c1d81"]
}, Closed]],

Cell[CellGroupData[{

Cell["  1.2  Manipulation of tensor indices & tensor products", "Subsection",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"68d12292-51e5-4176-a124-fe361bc980eb"],

Cell[TextData[{
 "\tThe ",
 StyleBox["first",
  FontSlant->"Italic"],
 " or ",
 StyleBox["last",
  FontSlant->"Italic"],
 " index of a tensor can be raised / lowered by inner (",
 StyleBox["Dot",
  FontWeight->"Bold"],
 ") multiplication with gUU / gdd:"
}], "Text",
 FontSize->16,ExpressionUUID->"cb46d9f3-1b39-4412-80a0-4da3d42a81f1"],

Cell[TextData[{
 "\t     ",
 StyleBox["Edd=gdd.EUd",
  FontFamily->"Courier"],
 " has components Edd[[a,b]] = ",
 Cell[BoxData[
  SubscriptBox["E", "ab"]],ExpressionUUID->
  "c94fb3ac-2055-4256-be7c-702d2a95e288"]
}], "Text",
 FontSize->16,ExpressionUUID->"3f1b374e-6f88-4b08-92d5-d6fb9cb9e33b"],

Cell[TextData[{
 "\t     ",
 StyleBox["WdddU=Wdddd.gUU",
  FontFamily->"Courier"],
 " has components WdddU[[a,b,c,d]] = ",
 Cell[BoxData[
  TagBox[
   SuperscriptBox[
    SubscriptBox["W", "abc"], "d"],
   DisplayForm]],ExpressionUUID->"e426fc08-374c-4e8f-a198-ed75ae51e1bf"],
 ".",
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"f94defc6-49ed-4a53-9cd6-4b421745fceb"]
}], "Text",
 FontSize->16,ExpressionUUID->"39063825-66a8-4f7c-b89d-e35dce99956e"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"67d0a63c-3a0a-4f5f-8f13-9914ccf2cf9a"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"03de61d2-a047-4fc4-a00d-cf67c0b1dee2"],
 "\tTo manipulate other indices the following functions have been defined:"
}], "Text",
 FontSize->16,ExpressionUUID->"0bc7bd6b-01dd-4b4d-8032-8692f1a93dad"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"32339c03-a7fa-4f7d-96c9-75f724a994e2"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"bf661c03-ea9f-44db-bf1a-f84c7d02908b"],
 "\t     ",
 StyleBox["Lower[x_,ni__]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ":: lowers the index (indices) at position(s) ",
 StyleBox["ni",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " (assumed U) of the nested list ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " using the matrix  gdd."
}], "Text",
 FontSize->16,ExpressionUUID->"bc68b52f-2e6d-44eb-a1c7-8e558ad6ad0a"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"2f2af690-f009-4209-bed4-f6ad264bb3e0"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"d7df2d5a-1f87-42c6-bc5f-9b09713d5401"],
 "\t     ",
 StyleBox["Raise[x_,ni__]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ":: raises the index (indices) at position(s) ",
 StyleBox["ni",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " (assumed d) of the nested list ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " using the matrix  gUU."
}], "Text",
 FontSize->16,ExpressionUUID->"b54ebef1-ad6d-4874-ab4c-1bea8720758d"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"6b6ed11d-10b0-43cf-a898-3235ac6fe812"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"0a280931-3280-4259-a1d6-d14b0809e9de"],
 "\tFor example, the mixed Riemann tensor with  components ",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox[
    SubscriptBox[
     SuperscriptBox["R", "a"], "b"], "c"], "d"]],ExpressionUUID->
  "44371698-16ed-4203-b223-00c4f87a8ab6"],
 "  is  ",
 StyleBox["RUdUd=Raise[RUddd,3]",
  FontFamily->"Courier"],
 ", ",
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"4aa210e3-30ae-4326-bfec-1a29723241d6"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"6cf77aea-b6bc-486a-9ea2-81d1f41eaa62"],
 "while  RUUUd",
 StyleBox["=Raise[RUddd,2,3]",
  FontFamily->"Courier"],
 "  has components ",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "abc"], "d"]],ExpressionUUID->
  "af7ac6e7-7b61-4fde-8b01-4fe9c935edf1"],
 "."
}], "Text",
 FontSize->16,ExpressionUUID->"071cc2a5-0ff5-4ded-8469-db6a193a7be3"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"a26fe32b-6b43-429f-98c8-ff6d2de96c1b"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"8bcdf1c0-e15e-4a4a-9bf9-0bd0048790c9"],
 "\t",
 StyleBox["Note",
  FontSlant->"Italic"],
 ": The functions ",
 StyleBox["Raise",
  FontWeight->"Bold"],
 " / ",
 StyleBox["Lower",
  FontWeight->"Bold"],
 " apply the rules in ",
 StyleBox["simpRules",
  FontWeight->"Bold"],
 " and factor the expressions obtained. Thus ",
 StyleBox["Raise[RUddd,4]",
  FontFamily->"Courier"],
 " is equivalent but not identical to ",
 StyleBox["RUddd.gUU",
  FontFamily->"Courier"],
 ". "
}], "Text",
 FontSize->16,ExpressionUUID->"eb136a01-5be6-478e-9ec4-0fb532bf3ac5"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"72855f31-c1d0-4bf1-8988-ca466af96223"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"3c962fe9-a1fe-4d4c-8cf7-041900838ecd"],
 "\tTensor products are obtained by using the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ",
 StyleBox["Outer",
  FontWeight->"Bold"],
 ". For example,"
}], "Text",
 FontSize->16,ExpressionUUID->"ead68687-1dca-46f1-9cff-56896a36c7fb"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"d53a4193-6263-4d03-87ce-4a815adb33b7"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"994d5210-463d-49c9-8eea-a07d8cd9e630"],
 "\t     ",
 StyleBox["gg=Outer[Times,gdd,gdd];",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 4th rank (d-type) tensor with components ",
 StyleBox["gg[[a,b,c,d]]=",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 Cell[BoxData[
  RowBox[{" ", 
   SubscriptBox["g", "ab"]}]],
  FontWeight->"Bold",ExpressionUUID->"fe7b8d4f-745a-4c73-bf56-c67252a3b197"],
 Cell[BoxData[
  SubscriptBox["g", "cd"]],
  FontWeight->"Bold",ExpressionUUID->"e0ab3042-9354-47f7-bc0b-6716beddea47"],
 "."
}], "Text",
 FontSize->16,ExpressionUUID->"e83236e5-8e85-4017-88eb-8a07932b83a1"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"ba0d4ac9-f630-4330-9436-6ab29204771e"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"21d9f127-6f56-4cbd-be90-99cafebfe036"],
 "\tUsing the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ",
 StyleBox["Transpose",
  FontWeight->"Bold"],
 ",  one can then define the tensor: ",
 StyleBox["gxg",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "=",
 StyleBox["gg-Transpose[gg,{1,3,2,4}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[",",
  FontVariations->{"CompatibilityType"->0}],
 " ",
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"d28f48f2-e9a2-463e-9260-36fcdd453625"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"244786d7-451d-4aaa-96de-3c8b21578004"],
 "which has components  ",
 StyleBox["gxg[[a,b,c,d]]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" = ",
  FontWeight->"Bold"],
 Cell[BoxData[
  SubscriptBox["g", "ab"]],
  FontWeight->"Bold",ExpressionUUID->"0d0726cc-7dbb-49ba-a4a0-48a6481afe47"],
 Cell[BoxData[
  SubscriptBox["g", 
   RowBox[{"cd", " "}]]],
  FontWeight->"Bold",ExpressionUUID->"8401d16f-a151-4eaa-bb49-092c0e72e820"],
 StyleBox["-",
  FontWeight->"Bold"],
 Cell[BoxData[
  RowBox[{" ", 
   SubscriptBox["g", "ac"]}]],
  FontWeight->"Bold",ExpressionUUID->"d4ef75f8-a2bb-4bd1-8ba2-a63b51a2a204"],
 Cell[BoxData[
  SubscriptBox["g", "bd"]],
  FontWeight->"Bold",ExpressionUUID->"0f11a05d-efc3-4411-8c19-d250b30d5615"],
 ".\n"
}], "Text",
 FontSize->16,ExpressionUUID->"75baf6eb-3e43-45d1-a60a-d25b66f40262"]
}, Closed]],

Cell[CellGroupData[{

Cell["  1.3  Contraction of tensor indices", "Subsection",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"f60eec5e-56ea-4898-918b-1bf4a751fe7f"],

Cell[TextData[{
 "\[FilledSmallCircle]\tThe function  ",
 StyleBox["Contract[x_,{i1_,j1_},{i2_,j2_},..]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  takes as arguments an nth rank tensor ",
 StyleBox["x",
  FontWeight->"Bold"],
 ", and one or more lists of  pairs of numbers, indicating the positions of \
the indices to be contracted. It returns a tensor of rank ",
 StyleBox["n-2k",
  FontSlant->"Italic"],
 ", where ",
 StyleBox["k",
  FontSlant->"Italic"],
 " is the number of index-pair lists. ",
 StyleBox["It is assumed that the two numbers in each list refer to one U and \
one d type index, in any order",
  FontSlant->"Italic"],
 ".  Examples (the Einstein summation convention holds):"
}], "Text",
 FontSize->16,ExpressionUUID->"8ada4136-3fc1-4de6-8fa4-13a13b9a60ae"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"bc046fdb-c061-4418-843b-5b4874f761fc"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"574a3824-5d7e-4983-9655-1985674f3471"],
 "\t(a) ",
 StyleBox["Contract[GUdd,{1,3}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  gives a d-type vector with components ",
 Cell[BoxData[
  TagBox[
   SubsuperscriptBox["\[CapitalGamma]", "ba", "a"],
   DisplayForm]],ExpressionUUID->"6e63f06d-03c3-4025-90e0-d4b5196c51b9"],
 "."
}], "Text",
 FontSize->16,ExpressionUUID->"5fb3fc67-e161-4f42-bc21-919661cb1910"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"cdb04578-83fc-4bee-aa6d-50068f92665e"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"380e034b-255d-4952-8f44-1618cfd1bd5b"],
 "\t(b) ",
 StyleBox["Contract[RUddd,{1,3}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  gives Rdd."
}], "Text",
 FontSize->16,ExpressionUUID->"7e360fa6-3f45-4ed2-982d-450fad317033"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"70d598e0-1e70-4099-aded-4660533feb8b"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"51a904c6-257c-49dc-9757-db9bd449c21e"],
 "\t(c) ",
 StyleBox["Contract[Outer[Times,RUddd,RUddd],{1,7},{4,5}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  produces a dddd tensor with components ",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "s"], "abt"]],ExpressionUUID->
  "0fede1fb-bb85-489b-82e8-1c6e3dd19b57"],
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "t"], "csd"]],ExpressionUUID->
  "90d16acc-c916-4345-a61c-4f2667556bfe"],
 "."
}], "Text",
 FontSize->16,ExpressionUUID->"859dd086-a6a1-4807-9d8c-b736ac2e486a"],

Cell[TextData[{
 "\t",
 StyleBox["Note1",
  FontSlant->"Italic"],
 ": Even though the last result can be obtained by calling ",
 StyleBox["Contract",
  FontFamily->"Courier"],
 " twice, each time with a single pair of indices, it is ",
 StyleBox["much",
  FontSlant->"Italic"],
 " more efficient to perform multiple contractions simultaneously, as \
above.",
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"282c1532-c516-41ee-a376-c7514b44c390"]
}], "Text",
 FontSize->16,ExpressionUUID->"d3cce596-762f-4f2d-a405-5510deaa6d28"],

Cell[TextData[{
 "\t",
 StyleBox["Note2",
  FontSlant->"Italic"],
 ": The result of (c) can also be obtained as  ",
 StyleBox["Contract[RUddd.RUddd,{1,5}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", since the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ",
 StyleBox["Dot",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " performs the ",
 StyleBox["{4,5}",
  FontFamily->"Courier"],
 " contraction of the outer product (last index of first tensor with first \
index of second tensor) giving a 6th rank tensor.",
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"3a701ddf-7eec-407e-b7bf-6345e6dd8e59"]
}], "Text",
 FontSize->16,ExpressionUUID->"eabf8842-9fd1-4279-ad9a-7a5e0b8626a2"],

Cell[TextData[{
 "\[FilledSmallCircle]\tThe function ",
 StyleBox["multiDot[x_,y_,{i1_,j1_},{i2_,j2_},..]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is similar to ",
 StyleBox["Contract",
  FontFamily->"Courier"],
 ", and generalizes the built-in function ",
 StyleBox["Dot",
  FontFamily->"Courier"],
 ".  It takes as arguments ",
 StyleBox["two",
  FontSlant->"Italic"],
 " tensors -- ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", ",
 StyleBox["y",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " -- and one or more lists of  pairs of numbers.  For each pair of numbers \
",
 StyleBox["{i,j}",
  FontFamily->"Courier"],
 ", it contracts the ",
 StyleBox["i",
  FontWeight->"Bold"],
 "th index of the ",
 StyleBox["first",
  FontSlant->"Italic"],
 " tensor (",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ") with the ",
 StyleBox["j",
  FontWeight->"Bold"],
 "th index of the ",
 StyleBox["second",
  FontSlant->"Italic"],
 " tensor (",
 StyleBox["y",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "),  returning a tensor of rank ",
 StyleBox["m+n-2k",
  FontSlant->"Italic"],
 ", where ",
 StyleBox["m",
  FontSlant->"Italic"],
 ", ",
 StyleBox["n",
  FontSlant->"Italic"],
 " are the ranks of ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", ",
 StyleBox["y",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", respectively, and ",
 StyleBox["k",
  FontSlant->"Italic"],
 " is the number of index pairs. Again, it is assumed that the indices at ",
 StyleBox["{i,j}",
  FontFamily->"Courier"],
 " are of opposite (U/d) types. Using ",
 StyleBox["multiDot",
  FontFamily->"Courier"],
 ", the result of example (c) above can also be obtained as  ",
 StyleBox["multiDot[RUddd,RUddd,{1,3},{4,1}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ".",
 Cell[BoxData[
  FormBox["", TextForm]], "",ExpressionUUID->
  "cf42ed04-2451-4742-9bf4-9f38bb17d67c"],
 Cell[BoxData[
  FormBox["", TextForm]], "",ExpressionUUID->
  "931b1191-162f-4cc0-a498-c55bee3a7c8a"]
}], "Text",
 FontSize->16,ExpressionUUID->"c1433082-d37f-4f12-b578-4550fe5d0872"],

Cell[TextData[{
 StyleBox["\tNote1:",
  FontSlant->"Italic"],
 " When contracting a product of two tensors, as in example (c), one should \
always use ",
 StyleBox["multiDot",
  FontFamily->"Courier"],
 " to perform the contractions, thus avoiding the outer product calculation, \
which is very time / memory consuming. See also Example 1a in section 3 and \
Example 4b in Section 5.1",
 Cell[BoxData[
  FormBox["", TextForm]], 
  "\.02\[YAcute]\t\[OSlash]\.03\.08\[CapitalCCedilla]`\.03\.08\
\[CapitalCCedilla]`",ExpressionUUID->"8ad3f336-eea0-4630-ad9a-a313b9451888"]
}], "Text",
 FontSize->16,ExpressionUUID->"2e30bcb5-c96e-49c8-86fe-58c6f57a6e60"],

Cell[TextData[{
 StyleBox["\tNote2:",
  FontSlant->"Italic"],
 " One can use ",
 StyleBox["Contract",
  FontFamily->"Courier"],
 " and ",
 StyleBox["multiDot",
  FontFamily->"Courier"],
 " to contract nested lists with unequal index dimensions (provided, of \
course, that the indices to be contracted have the same dimension); thus, if \
A has dimensions {2, 3, 3, 4} and B {3, 2, 4}, ",
 StyleBox["Contract",
  FontFamily->"Courier"],
 "[A, {2, 3}] will return a tensor with dimensions {2, 4} and ",
 StyleBox["multiDot",
  FontFamily->"Courier"],
 "[A, B, {1, 2}, {3, 1}] will return a tensor with dimensions {3, 4, 4}.",
 Cell[BoxData[
  FormBox["", TextForm]], 
  "\.02\[YAcute]\t\[OSlash]\.03\.08\[CapitalCCedilla]`\.03\.08\
\[CapitalCCedilla]`",ExpressionUUID->"891024b9-54fd-4b6f-9a0d-c0cee504fd5c"]
}], "Text",
 FontSize->16,ExpressionUUID->"3d2fa420-c2f3-4c54-9c44-2bfa509aac53"]
}, Closed]],

Cell[CellGroupData[{

Cell["  1.4  Covariant differentiation of tensors", "Subsection",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"08bf26da-9c5d-441d-a0ac-426b2a1c0aa5"],

Cell["\<\
\tThe following functions, involving differentiations of tensors, are defined \
in RGTC: \
\>", "Text",
 FontSize->16,ExpressionUUID->"e2e22da1-3418-4930-8e4b-fe0ef75f78ac"],

Cell[CellGroupData[{

Cell[TextData[{
 "\t (i) The function  ",
 StyleBox["covD[x_,{i___}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  takes two arguments -- an nth rank tensor, ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", and a list of numbers indicating the positions of the ",
 StyleBox["contravariant",
  FontSlant->"Italic"],
 "  (U) components of ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " -- and produces an ",
 StyleBox["n+1",
  FontFamily->"Courier",
  FontSlant->"Italic"],
 " rank tensor: the covariant derivative of ",
 StyleBox["x",
  FontWeight->"Bold"],
 ". ",
 StyleBox["The last index is the differentiation index (d type)",
  FontSlant->"Italic"],
 ". If ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " has only d-type components, the second argument (empty list) can be \
omitted. Examples:"
}], "Text",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"a31f900b-a568-444b-8abd-50aa8869db97"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"ed9df5c1-5936-4ae4-91c4-52645818f1b9"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"94d3fc21-059d-4108-a905-4e292b9e3be3"],
 "\t     ",
 StyleBox["covD[Rdd]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 3rd rank (ddd type) tensor with components ",
 Cell[BoxData[
  TagBox[
   TagBox[
    SubscriptBox["R", 
     RowBox[{"ab", ";", "c"}]],
    DisplayForm],
   DisplayForm]],ExpressionUUID->"7425a2bb-eb17-4fd7-b004-06fab6edb6be"],
 "."
}], "Text",
 FontSize->16,ExpressionUUID->"a66f50f2-fe66-4f2d-b228-4ab07e1f8412"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"2cc0a611-c29b-49a2-bb8c-c087fe94e779"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"b0fd4675-bb1b-475b-80cf-6a45511b51c8"],
 "\t     ",
 StyleBox["covD[RUddd,{1}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 5th rank (Udddd type) tensor with components ",
 Cell[BoxData[
  TagBox[
   TagBox[
    SubscriptBox[
     SuperscriptBox["R", "a"], 
     RowBox[{"bcd", ";", "e"}]],
    DisplayForm],
   DisplayForm]],ExpressionUUID->"24791ff4-bb72-4196-a77b-bda99d62f811"],
 "."
}], "Text",
 FontSize->16,ExpressionUUID->"b1933f76-e5a6-4d5d-8511-49d0b6b3451b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"4ed5e164-02b6-426c-bb6e-73cc039dc382"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"d0c16f2f-af00-45c7-970d-b300f873f3df"],
 "\t(ii) The function ",
 StyleBox["covDiv[x_,{i___,{s_}}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " acting on an nth rank tensor ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " with contravariant indices at positions {i..., s} returns an ",
 StyleBox["n-1",
  FontFamily->"Courier",
  FontSlant->"Italic"],
 " rank tensor: the covariant ",
 StyleBox["divergence",
  FontSlant->"Italic"],
 " of ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " with respect to the contravariant index at position ",
 StyleBox["s",
  FontSlant->"Italic"],
 ". If there is only one contravariant index, the second argument can be \
written simply {s} rather than {{s}}. Examples (the Einstein summation \
convention holds):"
}], "Text",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"7820a9a8-932c-47ae-a809-2a828e939880"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"1a1f208a-3719-4c2a-b10e-7fcb8f4d9d1b"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"8888110b-6a52-4194-8d2c-f424af3034a5"],
 "\t     ",
 StyleBox["covDiv[RUddd,{1}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 3rd rank (ddd type) tensor with components ",
 Cell[BoxData[
  TagBox[
   TagBox[
    SubscriptBox[
     SuperscriptBox["R", "s"], 
     RowBox[{"abc", ";", "s"}]],
    DisplayForm],
   DisplayForm]],ExpressionUUID->"d90551d1-2bbb-490d-9362-f0b2956165c3"],
 "."
}], "Text",
 FontSize->16,ExpressionUUID->"a1bceec7-a767-4112-91cf-240095778dfc"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"6bab5ffc-9de2-483f-8ef9-f18881bd1400"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"68c575f0-1c05-4e17-947c-c470bfb6928f"],
 "\t     ",
 StyleBox["covDiv[RUdUd,{1,{3}}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 3rd rank (Udd type) tensor with components ",
 Cell[BoxData[
  TagBox[
   TagBox[
    SubscriptBox[
     SuperscriptBox[
      SubscriptBox[
       SuperscriptBox["R", "a"], "b"], "s"], 
     RowBox[{"c", ";", "s"}]],
    DisplayForm],
   DisplayForm]],ExpressionUUID->"2c4874d8-5d12-48ed-8691-396b4edd1319"],
 "."
}], "Text",
 FontSize->16,ExpressionUUID->"c3774d73-94cf-4614-8617-3fdd31baf72d"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"e919a294-af4a-4792-8d32-927ea6684784"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"079f06e6-bdb1-4296-ae29-ad7031bc4df7"],
 "\t",
 StyleBox["Note1",
  FontSlant->"Italic"],
 ": It is ",
 StyleBox["much",
  FontSlant->"Italic"],
 " more efficient to use ",
 StyleBox["covDiv",
  FontFamily->"Courier"],
 "  than to use ",
 StyleBox["covD",
  FontFamily->"Courier"],
 "  followed by ",
 StyleBox["Contract",
  FontFamily->"Courier"],
 "."
}], "Text",
 FontSize->16,ExpressionUUID->"15da7955-0c93-4dac-9fa2-6167e3abbeee"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"4b203626-14da-4b93-839f-87d59be41c87"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"3968acb3-f460-4a07-92e6-8d453c7c6051"],
 "\t",
 StyleBox["Note2",
  FontSlant->"Italic"],
 ": The functions ",
 StyleBox["covD",
  FontFamily->"Courier"],
 "  and ",
 StyleBox["covDiv",
  FontFamily->"Courier"],
 "  can be very slow on high-rank tensors in high dimensions. However, they \
remember their values, so calling them again with the same arguments takes no \
time. "
}], "Text",
 FontSize->16,ExpressionUUID->"95d3bd87-c09e-4625-b991-983f2c00a476"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "\t(iii)  The function  ",
 StyleBox["LieD[h_,x_,{i___}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " computes the Lie derivative of the tensor ",
 StyleBox["x",
  FontWeight->"Bold"],
 ", having contravariant indices at index positions ",
 StyleBox["i__",
  FontWeight->"Bold"],
 ", with respect to the contravariant (U type) vector ",
 StyleBox["h",
  FontWeight->"Bold"],
 ". The tensor ",
 StyleBox["x",
  FontWeight->"Bold"],
 " can be a tensor-valued p-form, for example the curvature 2-form ",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "a"], "b"]],ExpressionUUID->
  "0a798b67-9855-4747-9845-a4d92caa767c"],
 "=",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "a"], "bcd"]],ExpressionUUID->
  "2d81e89f-f125-4579-b9aa-3140a32b2bd8"],
 "d[",
 Cell[BoxData[
  SuperscriptBox["x", "c"]],ExpressionUUID->
  "d46987f0-800b-4595-8180-923dc46d4710"],
 "]\[Wedge]d[",
 Cell[BoxData[
  SuperscriptBox["x", "d"]],ExpressionUUID->
  "e227ea5f-1412-4bf4-a0b7-83ad519e0c5b"],
 "]. For totally covariant tensors ",
 StyleBox["x ",
  FontWeight->"Bold"],
 "(or scalars), the last argument (empty list) can be omitted. The result of ",
 StyleBox["LieD",
  FontWeight->"Bold"],
 " is a tensor of the same rank (and type) as ",
 StyleBox["x",
  FontWeight->"Bold"],
 ". As with ",
 StyleBox["covD",
  FontFamily->"Courier"],
 "  and ",
 StyleBox["covDiv",
  FontFamily->"Courier"],
 ",  ",
 StyleBox["LieD",
  FontFamily->"Courier"],
 " remembers its values. Examples:"
}], "Text",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"0bf673b3-36cc-4bd2-99a1-a3e5a8171415"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"bcfe2806-2137-4c7c-ade7-14a2a14f11a2"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"8136f053-bd60-4212-a1cd-32f27832613c"],
 "\t     ",
 StyleBox["LieD[{h1,h2,..,hn},gdd]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 2nd rank (dd type) tensor with components ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    TagBox["",
     DisplayForm], 
    SuperscriptBox["h", "s"], 
    SubscriptBox["g", 
     RowBox[{"ab", ",", "s"}]]}], "+", 
   RowBox[{
    TagBox[
     TagBox[
      SubscriptBox[
       SuperscriptBox["h", "s"], 
       RowBox[{",", "a"}]],
      DisplayForm],
     DisplayForm], 
    SubscriptBox["g", "sb"]}], "+", 
   RowBox[{
    TagBox[
     TagBox[
      SubscriptBox[
       SuperscriptBox["h", "s"], 
       RowBox[{",", "b"}]],
      DisplayForm],
     DisplayForm], 
    SubscriptBox["g", "as"]}]}]],ExpressionUUID->
  "026a43ee-a6cf-4ee6-a727-1e64c4907c9c"],
 "."
}], "Text",
 FontSize->16,ExpressionUUID->"c09563a3-175c-44b4-a6c1-03698228b4f1"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"e4636432-4b5c-4e54-b746-c9fc2aac9321"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"bd11c54d-0596-4de2-b34a-acbad4e7cb5c"],
 "\t     ",
 StyleBox["LieD[{h1,h2,..,hn},RUddd,{1}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 4th rank (Uddd type) tensor with components ",
 Cell[BoxData[
  TagBox[
   TagBox[
    RowBox[{
     SuperscriptBox["h", "s"], 
     SubscriptBox[
      SuperscriptBox["R", "a"], 
      RowBox[{"bcd", ",", "s"}]]}],
    DisplayForm],
   DisplayForm]],ExpressionUUID->"756942f1-ed64-4fcc-a12b-73be11569b67"],
 "+",
 Cell[BoxData[
  TagBox[
   TagBox[
    SubscriptBox[
     SuperscriptBox["h", "s"], 
     RowBox[{",", "b"}]],
    DisplayForm],
   DisplayForm]],ExpressionUUID->"d85b35b6-559f-452e-9052-4ff75568a684"],
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "a"], "scd"]],ExpressionUUID->
  "d2fc8c57-fd2b-45b0-b661-51cd7dce6dd2"],
 "+",
 Cell[BoxData[
  RowBox[{
   TagBox[
    TagBox[
     SubscriptBox[
      SuperscriptBox["h", "s"], 
      RowBox[{",", "c"}]],
     DisplayForm],
    DisplayForm], 
   SubscriptBox[
    SuperscriptBox["R", "a"], "bsd"]}]],ExpressionUUID->
  "45c14e16-6c76-4065-b571-75ab08e0949b"],
 "+",
 Cell[BoxData[
  TagBox[
   TagBox[
    SubscriptBox[
     SuperscriptBox["h", "s"], 
     RowBox[{",", "d"}]],
    DisplayForm],
   DisplayForm]],ExpressionUUID->"dcf03f67-b156-4578-929a-9b0be20bc802"],
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "a"], "bcs"]],ExpressionUUID->
  "f5392eb7-9d07-46ae-ad44-006a8f86c435"],
 StyleBox["- ",
  FontFamily->"Geneva"],
 Cell[BoxData[
  TagBox[
   TagBox[
    RowBox[{
     SubscriptBox[
      SuperscriptBox["h", "a"], 
      RowBox[{",", "s"}]], 
     SubscriptBox[
      SuperscriptBox["R", "s"], "bcd"]}],
    DisplayForm],
   DisplayForm]],ExpressionUUID->"1621e533-d8cc-49ec-a9f0-fb56e7044daa"],
 "."
}], "Text",
 FontSize->16,ExpressionUUID->"7ebdcda5-073b-4da0-9913-eed447bf297b"],

Cell[TextData[{
 "\tThe function  ",
 StyleBox["LieDcartan",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["[",
  FontWeight->"Bold"],
 StyleBox["vector_,form_",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["]",
  FontWeight->"Bold"],
 ", introduced in ",
 ButtonBox["EDC 3.8.5",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/~sbonano/EDC/"], None}],
 ", computes the Lie derivative of the differential form expression ",
 StyleBox["form",
  FontWeight->"Bold"],
 " w.r.t. the ",
 StyleBox["vector",
  FontWeight->"Bold"],
 " using the Cartan identity.  It differs from ",
 StyleBox["LieD",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " in that it does not treat lists of forms as components of a tensor. See \
the ",
 ButtonBox["EDCmanual.nb",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/~sbonano/EDC/"], None}],
 " (section 2.5) for details."
}], "Text",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"e9ae95a4-e0e7-4ffb-81ce-3f2d062b2ebe"]
}, Open  ]],

Cell[TextData[{
 "\t(iv) The function  ",
 StyleBox["Laplacian[x_,{i___}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " computes the Laplacian (",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox[
    RowBox[{"=", "x"}], 
    RowBox[{";", "s"}]], 
   RowBox[{";", "s"}]]],ExpressionUUID->
  "5a3daaab-184b-4cf6-81a1-cf10a1703797"],
 ") of the tensor ",
 StyleBox["x",
  FontWeight->"Bold"],
 ", having contravariant indices at index positions ",
 StyleBox["i__",
  FontWeight->"Bold"],
 ". Again, for totally covariant tensors ",
 StyleBox["x",
  FontWeight->"Bold"],
 " (or scalars), the last argument (empty list) can be omitted. The result of \
",
 StyleBox["Laplacian",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a tensor of the same rank (and type) as ",
 StyleBox["x",
  FontWeight->"Bold"],
 ". "
}], "Text",
 FontSize->16,ExpressionUUID->"20aced06-5c1a-4b6d-8c46-5ee843d661b4"],

Cell[TextData[{
 "\t(v) The function  ",
 StyleBox["Grad2Norm[x__]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " takes either 1 or 2  ",
 StyleBox["scalar",
  FontSlant->"Italic"],
 " functions as arguments and computes the square norm of the gradient of ",
 StyleBox["x",
  FontFamily->"Courier"],
 " (inner product): ",
 StyleBox["Grad2Norm[x]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "= ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["g", "ab"], 
   SubscriptBox["x", 
    RowBox[{",", "a"}]], 
   SubscriptBox["x", 
    RowBox[{",", "b"}]]}]],ExpressionUUID->
  "dc19cd54-508b-429a-90c9-2b7b804711a7"],
 StyleBox[" ",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "and  ",
 StyleBox["Grad2Norm[x,y]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "= ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["g", "ab"], 
   SubscriptBox["x", 
    RowBox[{",", "a"}]], 
   SubscriptBox["y", 
    RowBox[{",", "b"}]]}]],ExpressionUUID->
  "88fe5beb-1fa7-4dfa-8701-8c904c5c80d7"],
 "."
}], "Text",
 FontSize->16,ExpressionUUID->"a6b7f3a8-ba90-45cf-806d-a5ebc95a9615"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"ed2f73e9-1a9a-458f-bc84-52ace41f23ad"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"fee0b6bc-ae7e-4aa1-9b13-ec01d3ac4875"],
 "\t(vi) Using ",
 StyleBox["covD",
  FontFamily->"Courier"],
 " and ",
 StyleBox["covDiv",
  FontFamily->"Courier"],
 ",  the function ",
 StyleBox["Bianchi[n_]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", for n = 0, 1, 2, computes the full, once, twice contracted Bianchi \
identities and returns a list containing any non-vanishing terms. This list \
is normally the empty list, except when the simplification rules used imply \
relations among the 3rd derivatives of the metric functions (see Example 5). \
"
}], "Text",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"f39e662e-6c23-45cc-b88d-f6b94c24dda1"],

Cell[TextData[{
 "\tEvaluation of the Bianchi Identities takes long: for the metrics in the \
examples, the time needed to evaluate ",
 StyleBox["Bianchi[1]",
  FontFamily->"Courier"],
 " is ~ 1 - 15 times the time taken by ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " to compute all basic tensors. ",
 StyleBox["Bianchi[0]",
  FontFamily->"Courier"],
 " takes considerably longer. (For the Bondi metric the times are ~ 12 min, 6 \
min, 7 sec). "
}], "Text",
 FontSize->16,ExpressionUUID->"4ad6d70a-4fd4-4ddb-8ff9-5c9eeb52f2da"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["  1.5  Index of global names / variables", "Subsection",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"b3fc218f-744e-458a-bd02-e2905241cb99"],

Cell[TextData[{
 "\t",
 StyleBox["It is essential that, in choosing coordinates and metric \
functions, one avoids using the symbols listed in this subsection, as they \
are defined by (or have special meanings in) RGTC. In particular, the  \
single-letter symbols R, d, e, as well as the greek letters used in the spin \
coefficient formalism, must be avoided-- see subsection 4.0.",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[
  0, 0, 1],ExpressionUUID->"109c1e99-f680-430d-aafe-974131b206be"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"9e4845a0-2bc3-45aa-b076-6e13ad9095cf"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"16732e85-c4ec-4369-99bb-74868999bf1f"],
 "\t(i) ",
 StyleBox["Riemannian Geometry tensors / scalars",
  FontSlant->"Italic"],
 " "
}], "Subsubsection",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"fbe4dd2f-1b43-4d96-a70f-76b5e61e5e1e"],

Cell[TextData[{
 "\t",
 StyleBox["gdd, gUU, GUdd, Rdddd, RUddd, Rdd, EUd, R, Wdddd, detg\t\t",
  FontWeight->"Bold"],
 "(section 1.1)\n\t",
 StyleBox["epsilon, eta\t\t\t\t\t\t\t\t",
  FontWeight->"Bold"],
 "(section 1.1.1)\n\t",
 StyleBox["\[Omega]Ud \t\t\t\t\t\t\t\t\t",
  FontWeight->"Bold"],
 "(section 5.1)\n\t",
 StyleBox["\[Alpha],\[Beta],",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["...,  ",
  FontWeight->"Bold"],
 StyleBox["\[GothicCapitalD][_],\[CapitalDelta][_]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["..., \[CapitalPsi][i], \[CapitalPhi][i, j],",
  FontWeight->"Bold"],
 " ",
 StyleBox["\[CapitalLambda]\t\t\t\t",
  FontWeight->"Bold"],
 "(section 5.1.3)"
}], "Text",
 FontSize->16,ExpressionUUID->"6767cfe3-c5df-4c67-900f-04e51f9788e8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"8d25ece9-5a44-4b36-b2b2-1abb5a7bee3c"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"57dd8b8f-752c-4b97-9022-50b224cb15e2"],
 "\t(ii) ",
 StyleBox["Tensor operations / functions",
  FontSlant->"Italic"]
}], "Subsubsection",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"52c7bcf0-749e-442c-898f-4e41fa314e3f"],

Cell[TextData[{
 " \t",
 StyleBox["RGtensors\t\t\t\t\t\t\t     ",
  FontWeight->"Bold"],
 "(section 1.1, 5.1, 5.2)\n\t",
 StyleBox["Raise, Lower, Outer, Transpose",
  FontWeight->"Bold"],
 "\t\t\t\t\t(section 1.2) \n\t",
 StyleBox["Contract, Dot, multiDot",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t(section 1.3) \n\t",
 StyleBox["covD, covDiv, LieD, Laplacian, Grad2Norm, Bianchi",
  FontWeight->"Bold"],
 "\t\t(section 1.4)\n\t",
 StyleBox["HStar",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t\t\t\t(section 5.1.2)\n\t",
 StyleBox["Classify, Plebanski",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t\t(section 7)"
}], "Text",
 FontSize->16,ExpressionUUID->"954316ed-4edc-4669-8738-5d1d24aeeee8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"093a4ef3-69b1-4741-8183-91808ac5a736"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"4e8a08a6-e413-4ecb-adf6-37947ef7f9b1"],
 "\t(iii) ",
 StyleBox["Other global variables",
  FontSlant->"Italic"]
}], "Subsubsection",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"c2df9beb-d144-49db-9e07-c2b52900651f"],

Cell[TextData[{
 "\t",
 StyleBox["Dim, coordList, LineElement",
  FontWeight->"Bold"],
 "\t\t\t\t\t(section 1.1)\n\t",
 StyleBox["simpRules, TrigRules, HypTrigRules, varList",
  FontWeight->"Bold"],
 "\t\t\t(section 4.3)\n\t",
 StyleBox["e[], d[]",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t\t\t\t(section 5.1)\n\t",
 StyleBox["deList, dxRuleList",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t\t(section 5.2)"
}], "Text",
 FontSize->16,ExpressionUUID->"b1514241-27bd-4859-b52c-f36d2047bf87"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"66b72de8-90fd-4523-8445-f633ccb91a1d"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"63465852-b4aa-4a9f-bda3-24efd30e30ed"],
 "\t(iv) ",
 StyleBox["Auxiliary functions",
  FontSlant->"Italic"]
}], "Subsubsection",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"f89da904-0f7e-4a41-beb6-d15a1df443ff"],

Cell[TextData[{
 "\t",
 StyleBox["zeroQ, nonZeroN, nonZeroL, indepTerms, indepCoefs, FacSimp",
  FontWeight->"Bold"],
 "\t(section 4.2)\n\t",
 StyleBox["FuncRepRules\t\t\t\t\t\t\t    \t    ",
  FontWeight->"Bold"],
 "(section 4.4)\n\t",
 StyleBox["eTO$dx, Clear$dx",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t\t\t(section 5.1.1)\n\t",
 StyleBox["GenCoef, metric",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t\t\t(section 4.2)"
}], "Text",
 FontSize->16,ExpressionUUID->"5bf769a5-b844-4106-b65c-6606ba9c063e"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"01353cd9-5dd9-4097-b0a7-793e32a5dba3"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"c00a8966-f0a9-4dc2-acdb-6cf4971c5beb"],
 "\t(v) ",
 StyleBox["Functions / variables defined in ",
  FontSlant->"Italic"],
 StyleBox["EDC",
  FontWeight->"Bold",
  FontSlant->"Italic"]
}], "Subsubsection",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"197c7693-d138-480d-815a-20976cc3d5e6"],

Cell[TextData[{
 "  \te.g., ",
 StyleBox["Wedge",
  FontWeight->"Bold"],
 ", ",
 StyleBox["d[]",
  FontWeight->"Bold"],
 ", ",
 StyleBox["DeclareForms",
  FontWeight->"Bold"],
 ", ",
 StyleBox["Bar[], DirectSum",
  FontWeight->"Bold"],
 " etc.\t\tsee  ",
 ButtonBox["EDCmanual.nb",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/~sbonano/EDC/"], None}]
}], "Text",
 FontSize->16,ExpressionUUID->"d2a6fd66-b905-490c-a1ca-fbeccb4ed162"]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"50f03173-3361-4d2f-9286-341de95f095b"],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],ExpressionUUID->"f85b7e80-dae0-4580-a780-14a53485679b"],
 "\t",
 StyleBox["Important Note:",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontWeight->"Bold"],
 "As the behavior of ",
 StyleBox["RGtensors",
  FontWeight->"Bold"],
 " depends on the values of global variables like ",
 StyleBox["simpRules, deList, dxRuleList,",
  FontWeight->"Bold"],
 " one should normally restart the kernel to do calculations with a new \
metric."
}], "Text",
 FontSize->16,ExpressionUUID->"1da44339-3e30-4371-8e1d-245b4c76493c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["  1.6  Input Palettes", "Subsection",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"93f8b4b4-559e-4ec1-861f-3bffe108948b"],

Cell[TextData[{
 "\tThe notebooks ",
 StyleBox["OperatorPLT.nb",
  FontWeight->"Bold"],
 " and ",
 StyleBox["NPsymbolPLT.nb",
  FontWeight->"Bold"],
 " are input palettes. The first contains the more common functions/variables \
used in calculations, so they can be entered easily without misspellings, \
while the second contains the symbols for the Newman-Penrose variables nd \
operators (see section 5.1.3). "
}], "Text",
 FontSize->16,ExpressionUUID->"b1f6a197-ddd7-489d-a998-6a920557c034"]
}, Closed]],

Cell[TextData[{
 "\tIt is assumed that the user has a working knowledge of the basic ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " structures used in symbolic calculations -- in particular that he/she \
understands the properties and use of",
 StyleBox[" Lists, Patterns, Functions, Transformation Rules and Definitions",
  
  FontSlant->"Italic"],
 ".  Although not necessary for elementary evaluations, familiarity with \
these structures is needed to make full use of all features of RG&TC."
}], "Text",
 FontSize->16,ExpressionUUID->"ce903355-bd00-4c02-8142-530a0607a573"],

Cell[TextData[{
 StyleBox["\t",
  FontSize->14],
 StyleBox["The executable cells in this notebook must be evaluated ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["in the order they appear",
  FontSize->16,
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[", after placing the file",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox[" ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["EDCRGTCcode.m",
  FontFamily->"Courier",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox[" ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["in an appropriate directory. Also read subsection 4.0 before doing \
calculations with a new metric.",
  FontSize->16,
  FontWeight->"Bold"]
}], "Text",
 FontSize->18,
 FontColor->RGBColor[
  0, 0, 1],ExpressionUUID->"f33c8ce5-d142-4560-abbb-7716c76b7d93"]
}, Closed]],

Cell["", "Text",
 FontSize->10,
 FontColor->RGBColor[
  0, 0, 1],ExpressionUUID->"b65d8ee8-2f6d-4af3-8212-5637a54f4474"],

Cell[CellGroupData[{

Cell[TextData[StyleBox[" 2  RG&TC-Code",
 FontWeight->"Bold"]], "Section",
 ShowGroupOpener->True,
 FontSize->24,
 FontColor->RGBColor[
  0, 0, 1],ExpressionUUID->"ee6effb8-abac-448e-8d16-d04c591c5a02"],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7282158987663927`*^9, 
  3.728215899770545*^9}},ExpressionUUID->"ae28db5a-38c1-48a5-ab27-\
40648f80d51d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "EDCRGTCcode.m"}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"a99268d3-baa0-4575-a11a-7af576bbc269"],

Cell[BoxData[
 TemplateBox[{
  "SetDelayed","write",
   "\"Tag \\!\\(\\*RowBox[{\\\"Classify\\\"}]\\) in \
\\!\\(\\*RowBox[{\\\"Classify\\\", \\\"[\\\", \\\"x_\\\", \\\"]\\\"}]\\) is \
Protected.\"",2,0,1,28309442899304742612,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA+KezUzuzB5vHJW212eD6IeP1+SDaLeYzXqJQNqs6pE7
iHa6GP4mBUg/m/LQgNPzjaNQ1JmrN4C0y6mnL0G0e8/5njtA+sd9lmsguuX9
goZ7QNqmRI/JM+uN443HWWEgOso0px1Eb5Bl11sDpHVOfri2pvyN40LPN49A
tEsyi+EpIJ3v2rMFRJf5n9x7HUj/C7tQ21zxxrEva419K5BeECiRC6Knta7/
eRFI/1GYxXAJSL/h2PRocSXQXo8fzUuAtNsqhw8g2uqD2O1jQPpZ2yvzE0B6
y4EKqYVVbxy9+1TuLwXSEefZW44C6S/S8+a/AdLM5ssiPwLpww/rXim1vHEs
Sub6BqIBon2ihw==
  "],ExpressionUUID->"df763ac3-9753-40a6-a39f-5fff943cfe00"]
}, Open  ]],

Cell[TextData[{
 "\tThe file ",
 StyleBox["EDCRGTCcode.m",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  must be placed in one of the directories that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " looks at when searching for extra packages (e.g., /Applications/",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "/AddOns/AutoLoad). Such directories can be found by evaluating the command ",
 StyleBox["$Path",
  FontWeight->"Bold"],
 ":"
}], "Text",
 FontSize->16,ExpressionUUID->"e883cdef-f3f8-443e-b8e4-2d5f2af27028"],

Cell[BoxData["$Path"], "Input",ExpressionUUID->"cc6976d9-2e40-43ea-81fe-f25eb0f7084b"],

Cell[TextData[{
 "\t",
 StyleBox["EDCRGTCcode.m",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  is the ",
 StyleBox["combined",
  FontSlant->"Italic"],
 " EDC and RGTC code, allowing calculations with differential forms, symbolic \
matrices, etc. (See the  ",
 ButtonBox["EDCmanual.nb",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/~sbonano/EDC/"], None}],
 ")."
}], "Text",
 FontSize->16,ExpressionUUID->"aa546552-0d1c-48ef-ab6b-1d813fda1443"],

Cell[TextData[{
 "\tEvaluation of ",
 StyleBox["EDCRGTCcode.m",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  erases all previous results. Thus it must be evaluated before any  \
calculations are carried out."
}], "Text",
 FontSize->16,ExpressionUUID->"469b5241-371d-4ff1-806b-8b5b94c61778"]
}, Closed]],

Cell["", "Text",
 FontSize->10,
 FontColor->RGBColor[
  0, 0, 1],ExpressionUUID->"b929167e-301b-47e0-bb06-fd8b7e56756f"],

Cell[" 3  Examples", "Section",
 ShowGroupOpener->True,
 CellChangeTimes->{
  3.746188220792528*^9, {3.8208405989246635`*^9, 3.820840602654911*^9}},
 FontSize->24,
 FontColor->RGBColor[
  0, 0, 1],ExpressionUUID->"d4db6884-e79e-430e-a3bc-05bcdb8f3307"],

Cell[CellGroupData[{

Cell[" Example 1: Robertson-Walker metric ", "Subsection",
 ShowGroupOpener->True,
 CellChangeTimes->{
  3.7957887123348975`*^9, {3.820905035358779*^9, 3.8209050365895686`*^9}},
 FontSize->16,ExpressionUUID->"960d3d59-44b4-4599-a928-fb011bcb1f83"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7957884892695203`*^9, 3.7957884896965046`*^9}, {
   3.7957888231212535`*^9, 3.7957888273777*^9}, 
   3.814023523182371*^9},ExpressionUUID->"8b295497-70f6-42f8-b3ab-\
461017426410"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "FLRW", " ", "metric", " ", "with", " ", "cosmic", " ", "time", " ", "t"}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"g", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"]}], "}"}]}], "}"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.7957884946445484`*^9, 3.7957885084800067`*^9}, {
  3.795788598933481*^9, 3.795788599106676*^9}, {3.795788814624313*^9, 
  3.7957888557666817`*^9}, {3.814023526202338*^9, 3.814023531122895*^9}, {
  3.8140235744822187`*^9, 3.81402357698308*^9}, {3.814024489933658*^9, 
  3.814024495453538*^9}, {3.820840646694264*^9, 3.8208406553702164`*^9}, {
  3.8208413313346343`*^9, 3.820841357924497*^9}, {3.821870872276498*^9, 
  3.8218708904945507`*^9}},ExpressionUUID->"06525bfd-0c76-4938-b208-\
b2b6e7606d6b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RGtensors", "[", 
  RowBox[{"g", ",", "xCoord"}], "]"}]], "Input",ExpressionUUID->"3cede667-\
5d72-4da7-83cf-93f9f60f6442"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", "1"}], "0", "0", "0"},
       {"0", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], "0", "0"},
       {"0", "0", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], "0"},
       {"0", "0", "0", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{-1, 0, 0, 0}, {0, $CellContext`a[$CellContext`t]^2, 0, 0}, {
     0, 0, $CellContext`a[$CellContext`t]^2, 0}, {
     0, 0, 0, $CellContext`a[$CellContext`t]^2}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.8218730306525693`*^9, 3.821942491037942*^9, 
  3.8219452813352327`*^9, 3.8223894601687503`*^9, 3.8223992286920705`*^9, 
  3.8224640361796784`*^9, 3.8225441259710126`*^9, 3.8225538074867945`*^9, 
  3.827373918671507*^9},ExpressionUUID->"8d375a40-4915-4d10-a2e1-\
608e83889138"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"LineElement = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{"d", "[", "t", "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "x", "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "y", "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "z", "]"}], "2"]}]}],
    Short[#, 32]& ]}],
  SequenceForm["LineElement = ", 
   Short[-$CellContext`d[$CellContext`t]^2 + $CellContext`a[$CellContext`t]^2 \
$CellContext`d[$CellContext`x]^2 + $CellContext`a[$CellContext`t]^2 \
$CellContext`d[$CellContext`y]^2 + $CellContext`a[$CellContext`t]^2 \
$CellContext`d[$CellContext`z]^2, 32]],
  Editable->False]], "Print",
 CellChangeTimes->{3.8218730306525693`*^9, 3.821942491037942*^9, 
  3.8219452813352327`*^9, 3.8223894601687503`*^9, 3.8223992286920705`*^9, 
  3.8224640361796784`*^9, 3.8225441259710126`*^9, 3.8225538074867945`*^9, 
  3.8273739187248783`*^9},ExpressionUUID->"94d7ff4e-1a1d-40c6-b6b0-\
2d03f0583518"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", "1"}], "0", "0", "0"},
       {"0", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]], "0", "0"},
       {"0", "0", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]], "0"},
       {"0", "0", "0", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{-1, 0, 0, 0}, {
     0, $CellContext`a[$CellContext`t]^(-2), 0, 0}, {
     0, 0, $CellContext`a[$CellContext`t]^(-2), 0}, {
     0, 0, 0, $CellContext`a[$CellContext`t]^(-2)}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.8218730306525693`*^9, 3.821942491037942*^9, 
  3.8219452813352327`*^9, 3.8223894601687503`*^9, 3.8223992286920705`*^9, 
  3.8224640361796784`*^9, 3.8225441259710126`*^9, 3.8225538074867945`*^9, 
  3.8273739187248783`*^9},ExpressionUUID->"7384de08-f328-4a91-8bea-\
139649606a95"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0., " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8218730306525693`*^9, 3.821942491037942*^9, 
  3.8219452813352327`*^9, 3.8223894601687503`*^9, 3.8223992286920705`*^9, 
  3.8224640361796784`*^9, 3.8225441259710126`*^9, 3.8225538074867945`*^9, 
  3.8273739187405043`*^9},ExpressionUUID->"a6bb9dcd-fb26-40c3-a834-\
22999c615456"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0., " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8218730306525693`*^9, 3.821942491037942*^9, 
  3.8219452813352327`*^9, 3.8223894601687503`*^9, 3.8223992286920705`*^9, 
  3.8224640361796784`*^9, 3.8225441259710126`*^9, 3.8225538074867945`*^9, 
  3.8273739187405043`*^9},ExpressionUUID->"92be932e-f87e-4b7b-baf9-\
82274d43013f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0., " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8218730306525693`*^9, 3.821942491037942*^9, 
  3.8219452813352327`*^9, 3.8223894601687503`*^9, 3.8223992286920705`*^9, 
  3.8224640361796784`*^9, 3.8225441259710126`*^9, 3.8225538074867945`*^9, 
  3.8273739187405043`*^9},ExpressionUUID->"165f6d45-b765-43f1-831d-\
baf07a7e2472"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.016000000000000014`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.016000000000000014`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8218730306525693`*^9, 3.821942491037942*^9, 
  3.8219452813352327`*^9, 3.8223894601687503`*^9, 3.8223992286920705`*^9, 
  3.8224640361796784`*^9, 3.8225441259710126`*^9, 3.8225538074867945`*^9, 
  3.8273739187405043`*^9},ExpressionUUID->"f21b06ee-62e6-46c5-aa58-\
1e9672c14bab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0., " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8218730306525693`*^9, 3.821942491037942*^9, 
  3.8219452813352327`*^9, 3.8223894601687503`*^9, 3.8223992286920705`*^9, 
  3.8224640361796784`*^9, 3.8225441259710126`*^9, 3.8225538074867945`*^9, 
  3.8273739187405043`*^9},ExpressionUUID->"05aa453a-aeca-4662-9634-\
742fc54e8d91"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0., " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8218730306525693`*^9, 3.821942491037942*^9, 
  3.8219452813352327`*^9, 3.8223894601687503`*^9, 3.8223992286920705`*^9, 
  3.8224640361796784`*^9, 3.8225441259710126`*^9, 3.8225538074867945`*^9, 
  3.8273739187405043`*^9},ExpressionUUID->"9e34f33e-7daf-47e4-855d-\
76600199e357"],

Cell[BoxData[
 StyleBox["\<\"Conformally Flat\"\>",
  StripOnInput->False,
  FontSize->20,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Print",
 CellChangeTimes->{3.8218730306525693`*^9, 3.821942491037942*^9, 
  3.8219452813352327`*^9, 3.8223894601687503`*^9, 3.8223992286920705`*^9, 
  3.8224640361796784`*^9, 3.8225441259710126`*^9, 3.8225538074867945`*^9, 
  3.8273739187561255`*^9},ExpressionUUID->"06bf413c-5978-4e9d-a85b-\
1c04b70093bb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0., " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8218730306525693`*^9, 3.821942491037942*^9, 
  3.8219452813352327`*^9, 3.8223894601687503`*^9, 3.8223992286920705`*^9, 
  3.8224640361796784`*^9, 3.8225441259710126`*^9, 3.8225538074867945`*^9, 
  3.827373918771781*^9},ExpressionUUID->"2ccc7cfe-80b0-4f25-b2d5-\
ff12f97ad9d5"],

Cell[BoxData["\<\"All tasks completed in 0.03125 seconds\"\>"], "Print",
 CellChangeTimes->{3.8218730306525693`*^9, 3.821942491037942*^9, 
  3.8219452813352327`*^9, 3.8223894601687503`*^9, 3.8223992286920705`*^9, 
  3.8224640361796784`*^9, 3.8225441259710126`*^9, 3.8225538074867945`*^9, 
  3.827373918771781*^9},ExpressionUUID->"68919bc5-32e9-4b00-b83c-\
6f31193bca80"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Convert", " ", "derivatives", " ", "of", " ", "a", 
    RowBox[{"(", "t", ")"}], " ", "to", " ", "Hubble", " ", "parameter"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"a2H", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"a", "'"}], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], " ", 
        RowBox[{"a", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"a", "[", "t", "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"H", "'"}], "[", "t", "]"}], "+", 
          RowBox[{
           RowBox[{"H", "[", "t", "]"}], "^", "2"}]}], ")"}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["a", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"a", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "3"], "+", 
          RowBox[{"3", " ", 
           RowBox[{"H", "[", "t", "]"}], " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}]}], "}"}]}],
    ";"}]}]], "Input",
 CellChangeTimes->{{3.7957888705273724`*^9, 3.795788885816942*^9}, {
   3.795848682649475*^9, 3.7958486828445816`*^9}, {3.795849183678172*^9, 
   3.795849202776514*^9}, {3.814023544352985*^9, 3.8140235576121492`*^9}, 
   3.820900806123784*^9},ExpressionUUID->"f144990b-57e6-49c4-94cf-\
2acdb48ad19a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "Christoffel", " ", "symbols", " ", 
    SubscriptBox[
     SuperscriptBox["\[CapitalGamma]", "a"], "bc"]}], " ", "*)"}], " ", 
  "\[IndentingNewLine]", 
  RowBox[{"GUdd", "/.", "a2H"}]}]], "Input",
 CellChangeTimes->{{3.795788553626259*^9, 3.7957885893537955`*^9}, {
  3.7958483792080126`*^9, 3.795848391551792*^9}, {3.7958492225252314`*^9, 
  3.7958492298502107`*^9}},ExpressionUUID->"e04c1855-65c0-4878-93ef-\
59df489f91af"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"H", "[", "t", "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"H", "[", "t", "]"}]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"H", "[", "t", "]"}]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"H", "[", "t", "]"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"H", "[", "t", "]"}], ",", "0", ",", "0", ",", "0"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"H", "[", "t", "]"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"H", "[", "t", "]"}], ",", "0", ",", "0", ",", "0"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{"H", "[", "t", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"H", "[", "t", "]"}], ",", "0", ",", "0", ",", "0"}], "}"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8138215022693205`*^9, {3.8140235610123243`*^9, 3.8140235854725094`*^9}, 
   3.8140245035835857`*^9, 3.820840662305709*^9, 3.8209008927690334`*^9, 
   3.8214409784136353`*^9, 
   3.8273739696014605`*^9},ExpressionUUID->"c9b7f7a7-34d5-489a-b03a-\
b1c80da29e3f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"temporal", " ", "part", " ", "0"}], "\[Rule]", "1"}], ",", " ", 
    
    RowBox[{
     RowBox[{"spatial", " ", "part", " ", "i"}], "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "4"}], "}"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
    "\"\<\!\(\*SubscriptBox[SuperscriptBox[\(\[CapitalGamma]\), \(0\)], \
\(00\)]\)\>\"", "->", 
     RowBox[{"GUdd", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1", ",", "1"}], "]"}], "]"}]}], "/.", "a2H"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "\"\<\!\(\*SubscriptBox[SuperscriptBox[\(\[CapitalGamma]\), \(0\)], \
\(11\)]\)\>\"", "->", 
     RowBox[{"GUdd", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2", ",", "2"}], "]"}], "]"}]}], "/.", "a2H"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "\"\<\!\(\*SubscriptBox[SuperscriptBox[\(\[CapitalGamma]\), \(1\)], \
\(00\)]\)\>\"", "->", 
     RowBox[{"GUdd", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "1", ",", "1"}], "]"}], "]"}]}], "/.", 
    "a2H"}]}]}]], "Input",
 CellChangeTimes->{{3.7958492461957674`*^9, 3.795849306884078*^9}, {
  3.820900973421489*^9, 
  3.820900993235179*^9}},ExpressionUUID->"f7605d14-a658-4fec-8f63-\
8655082f1127"],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[SuperscriptBox[\\(\[CapitalGamma]\\), \
\\(0\\)], \\(00\\)]\\)\"\>", "\[Rule]", "0"}]], "Output",
 CellChangeTimes->{3.813821504309453*^9, 3.8140235879326243`*^9, 
  3.8140245048064537`*^9, 3.8208406652263217`*^9, 3.8209009540312614`*^9, 
  3.8209009986367493`*^9, 3.8214409798604946`*^9, 
  3.827373971156862*^9},ExpressionUUID->"3510e300-56ab-4021-b54d-\
0b7510a563e4"],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[SuperscriptBox[\\(\[CapitalGamma]\\), \
\\(0\\)], \\(11\\)]\\)\"\>", "\[Rule]", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"a", "[", "t", "]"}], "2"], " ", 
   RowBox[{"H", "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{3.813821504309453*^9, 3.8140235879326243`*^9, 
  3.8140245048064537`*^9, 3.8208406652263217`*^9, 3.8209009540312614`*^9, 
  3.8209009986367493`*^9, 3.8214409798604946`*^9, 
  3.827373971156862*^9},ExpressionUUID->"e39ddd92-102c-4056-9638-\
c23992ded6bc"],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[SuperscriptBox[\\(\[CapitalGamma]\\), \
\\(1\\)], \\(00\\)]\\)\"\>", "\[Rule]", "0"}]], "Output",
 CellChangeTimes->{3.813821504309453*^9, 3.8140235879326243`*^9, 
  3.8140245048064537`*^9, 3.8208406652263217`*^9, 3.8209009540312614`*^9, 
  3.8209009986367493`*^9, 3.8214409798604946`*^9, 
  3.8273739711724825`*^9},ExpressionUUID->"75bd6264-e28b-43b8-8040-\
ddbdc28b1b31"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "Riemann", " ", "tensor", " ", 
    SubscriptBox[
     SuperscriptBox["R", "a"], "bcd"]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"RUddd", "/.", "a2H"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7958484116472626`*^9, 
  3.7958484560799074`*^9}},ExpressionUUID->"3d0d9396-a6f2-4e5e-acc7-\
2e61c566926a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"H", "[", "t", "]"}], "2"], "+", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], ",", "0", 
         ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"H", "[", "t", "]"}], "2"], "+", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], ",", "0", 
         ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"H", "[", "t", "]"}], "2"], "+", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], ",", 
         "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"H", "[", "t", "]"}], "2"], "+", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], ",", "0", 
         ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"H", "[", "t", "]"}], "2"], "+", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"H", "[", "t", "]"}], "2"], "+", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], ",", "0", 
         ",", "0", ",", "0"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], ",", "0", ",", "0"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox[
            RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], ",", "0", ",", "0", 
         ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], ",", "0", ",", "0"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], ",", "0", ",", "0"}], 
        "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], ",", "0"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox[
            RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], ",", "0", ",", "0", 
         ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], ",", "0", ",", "0"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], ",", "0"}], "}"}]}], "}"}]}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox[
            RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], ",", "0", ",", "0", 
         ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], ",", "0", ",", "0"}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], ",", "0"}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8138215062447166`*^9, 3.814023598952242*^9, 
  3.8140245063282146`*^9, 3.820840669619601*^9, 3.820901019147688*^9, 
  3.821440981479373*^9, 
  3.8273739733380857`*^9},ExpressionUUID->"d13c7b4d-2a41-4f6a-bf49-\
e130a3ed6940"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "Ricci", " ", "tensor", " ", 
    SubscriptBox["R", 
     RowBox[{"\[Mu]\[Nu]", " "}]]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Rdd", "/.", "a2H"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.795788619992107*^9, 3.7957886304967117`*^9}, {
  3.7957889021410503`*^9, 3.795788903471607*^9}, {3.7958483938896437`*^9, 
  3.795848406667574*^9}, {3.795848459949572*^9, 
  3.795848466634951*^9}},ExpressionUUID->"cee50043-606f-4cef-be98-\
86564c267161"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"H", "[", "t", "]"}], "2"], "+", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], ",", "0", ",",
      "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], ",", "0", ",",
      "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8138204484516587`*^9, 3.813821508269944*^9, 
  3.814023601822488*^9, 3.8208406753652735`*^9, 3.8214409897175407`*^9, 
  3.8273739760820456`*^9},ExpressionUUID->"beae9bb3-ecee-4097-b3c0-\
a2e5893b46cd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Rdd", "/.", "a2H"}], "//", "FullSimplify"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.820901086931591*^9, 
  3.820901107602955*^9}},ExpressionUUID->"692866ed-fd5b-41d3-b09d-\
e58e231775bc"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"H", "[", "t", "]"}], "2"], "+", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], "0", "0", 
      "0"},
     {"0", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], "0", "0"},
     {"0", "0", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], "0"},
     {"0", "0", "0", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.8209010918534403`*^9, 3.820901108218418*^9}, 
   3.821440991333888*^9, 
   3.8273739774595575`*^9},ExpressionUUID->"f6db7a6d-e90e-4726-9b82-\
edc54075a770"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\"\<\!\(\*SubscriptBox[\(R\), \(00\)]\)\>\"", "->", 
    RowBox[{"Rdd", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "/.", "a2H"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.82090105580919*^9, 
  3.8209010789391947`*^9}},ExpressionUUID->"480d6932-b1ff-41e0-a45f-\
df2c968321c9"],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(R\\), \\(00\\)]\\)\"\>", "\[Rule]", 
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"], "+", 
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.820901060930891*^9, 3.820901080052938*^9}, 
   3.821440992642218*^9, 
   3.8273739793163357`*^9},ExpressionUUID->"438493ea-f30e-4c2e-8042-\
78ce09a9f8df"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "Einstein", " ", "tensor", " ", 
    SubscriptBox[
     SuperscriptBox["G", "\[Mu]"], "\[Nu]"]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"EUd", "/.", "a2H"}], "//", "FullSimplify"}], "//", 
   "MatrixForm"}]}]], "Input",
 CellChangeTimes->{{3.795788540848342*^9, 3.795788543071092*^9}, {
  3.795788634306631*^9, 3.795788639670427*^9}, {3.7958484728005075`*^9, 
  3.7958484784286933`*^9}, {3.7958488876456127`*^9, 
  3.7958488981572123`*^9}},ExpressionUUID->"201a8a4e-485d-4837-9a27-\
62a765db8ed1"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "0", "0", "0"},
     {"0", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], "0", "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], "0"},
     {"0", "0", "0", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.8140236058834076`*^9, 3.820840680123805*^9, 
  3.821440994573333*^9, 
  3.8273739802198133`*^9},ExpressionUUID->"9f3dd966-d6b6-4c07-9b48-\
b2ea21b40f2e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Raise", "/", "lower"}], " ", "indices", " ", "and", " ", 
     "check", " ", 
     SubscriptBox[
      SuperscriptBox["G", "\[Mu]"], "\[Nu]"]}], "=", 
    RowBox[{
     SubscriptBox[
      SuperscriptBox["R", "\[Mu]"], "\[Nu]"], "-", 
     RowBox[{
      RowBox[{"1", "/", "2"}], " ", 
      SubscriptBox[
       SuperscriptBox["\[Delta]", "\[Mu]"], "\[Nu]"], " ", "R"}]}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Delta]ij", "=", 
     RowBox[{"Lower", "[", 
      RowBox[{"gUU", ",", 
       RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Raise", "[", 
        RowBox[{"Rdd", ",", 
         RowBox[{"{", "1", "}"}]}], "]"}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[Delta]ij", " ", "R"}]}], ")"}], "-", 
     "EUd"}], "//", "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.795848905674266*^9, 3.795849060402215*^9}, {
  3.7958493527302704`*^9, 
  3.795849389301156*^9}},ExpressionUUID->"b7238b5e-7be3-46d2-90b2-\
64900ce0756c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8140236145623245`*^9, 3.8208406825775185`*^9, 
  3.8214410027889547`*^9, 
  3.8273739814968233`*^9},ExpressionUUID->"c2ef05f3-47d8-4da9-a3df-\
1d5c37ac8314"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Taking", " ", "covariant", " ", "derivatives", " ", 
     SubscriptBox["R", 
      RowBox[{"\[Mu]\[Nu]", ";", "\[Sigma]"}]]}], " ", ",", " ", 
    RowBox[{
     SubscriptBox[
      SuperscriptBox["G", "\[Mu]"], 
      RowBox[{"\[Nu]", ";", "\[Mu]"}]], "=", 
     RowBox[{"0", " ", 
      RowBox[{"(", 
       RowBox[{"Bianchi", " ", "identity"}], ")"}]}]}], ",", " ", 
    RowBox[{"\[Square]", "\[Phi]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(R\), \(\[Mu]\[Nu]; \[Sigma]\)]\)\>\"", 
      "\[Rule]", 
      RowBox[{"covD", "[", "Rdd", "]"}]}], "/.", "a2H"}], "//", 
    "FullSimplify"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
     "\"\<\!\(\*SubscriptBox[SuperscriptBox[\(G\), \(\[Mu]\)], \(\[Nu]; \[Mu]\
\)]\)\>\"", "\[Rule]", 
      RowBox[{"covDiv", "[", 
       RowBox[{"EUd", ",", 
        RowBox[{"{", "1", "}"}]}], "]"}]}], "/.", "a2H"}], "//", 
    "FullSimplify"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\"\<\[Square]\[Phi]\>\"", "\[Rule]", 
       RowBox[{"Laplacian", "[", 
        RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}], "/.", "a2H"}], "//", 
     "FullSimplify"}], "//", "Expand"}]}]}]], "Input",
 CellChangeTimes->{{3.7958484958006*^9, 3.7958486476733418`*^9}, {
   3.795848698548162*^9, 3.7958487843088083`*^9}, {3.79584907208491*^9, 
   3.7958490878413196`*^9}, {3.795849403678233*^9, 3.7958494254287524`*^9}, 
   3.8140236295632253`*^9},ExpressionUUID->"06fb4256-ff0d-4289-9ef6-\
420d3c38ebd1"],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(R\\), \\(\[Mu]\[Nu]; \[Sigma]\\)]\\)\"\
\>", "\[Rule]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"H", "[", "t", "]"}], " ", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], ",", "0", 
        ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"H", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], ",", "0", ",", "0"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"H", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], ",", "0"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"H", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"H", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], ",", "0", ",", "0"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            RowBox[{"H", "[", "t", "]"}], " ", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], ",", "0", 
        ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"H", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], ",", "0"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            RowBox[{"H", "[", "t", "]"}], " ", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], ",", "0", 
        ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"H", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            RowBox[{"H", "[", "t", "]"}], " ", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], ",", "0", 
        ",", "0", ",", "0"}], "}"}]}], "}"}]}], "}"}]}]], "Output",
 CellChangeTimes->{
  3.8138204567760124`*^9, 3.81382151155949*^9, {3.8140236254128294`*^9, 
   3.814023630042655*^9}, 3.8208406871947002`*^9, 3.8214410062734356`*^9, 
   3.827373983236643*^9},ExpressionUUID->"b5695827-fb89-4bfa-9fed-\
ad537dd343db"],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[SuperscriptBox[\\(G\\), \\(\[Mu]\\)], \\(\
\[Nu]; \[Mu]\\)]\\)\"\>", "\[Rule]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}]], "Output",
 CellChangeTimes->{
  3.8138204567760124`*^9, 3.81382151155949*^9, {3.8140236254128294`*^9, 
   3.814023630042655*^9}, 3.8208406871947002`*^9, 3.8214410062734356`*^9, 
   3.827373983252228*^9},ExpressionUUID->"67d0e963-9ec4-4c87-a5f9-\
812c50490f7a"],

Cell[BoxData[
 RowBox[{"\<\"\[Square]\[Phi]\"\>", "\[Rule]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "-", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.8138204567760124`*^9, 3.81382151155949*^9, {3.8140236254128294`*^9, 
   3.814023630042655*^9}, 3.8208406871947002`*^9, 3.8214410062734356`*^9, 
   3.8273739833052983`*^9},ExpressionUUID->"7f46773f-cff7-4a35-941b-\
10ff1ebf80ee"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"kU", "=", 
   RowBox[{"{", 
    RowBox[{"k0", ",", "kx", ",", "ky", ",", "kz"}], "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.814023750912918*^9, 3.8140237596671305`*^9}, 
   3.814023860212307*^9, {3.814024068182773*^9, 3.8140240868224845`*^9}, 
   3.814024125533591*^9, {3.81402417627347*^9, 3.814024178223675*^9}, {
   3.8140242187937512`*^9, 3.814024219602784*^9}, {3.814024392623291*^9, 
   3.8140244117632027`*^9}},ExpressionUUID->"617f5b54-a9bf-44d4-850f-\
e5d6213c1ae2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kd", "=", 
  RowBox[{"Lower", "[", 
   RowBox[{"kU", ",", 
    RowBox[{"{", "1", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8140242238733635`*^9, 
  3.814024227893157*^9}},ExpressionUUID->"acac5274-9c6b-45e0-8f52-\
1083131148fe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "k0"}], ",", 
   RowBox[{"kx", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}], ",", 
   RowBox[{"ky", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}], ",", 
   RowBox[{"kz", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.814024228662958*^9, {3.81402439535822*^9, 3.814024412927166*^9}, 
   3.814024527473707*^9, 3.8208406918766613`*^9, 3.820901618684494*^9, 
   3.821441013338323*^9, 
   3.8273739879443865`*^9},ExpressionUUID->"ed237cc5-240d-4493-8e04-\
5a63bf31fd00"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    SuperscriptBox["k", "2"], "=", 
    RowBox[{
     SubscriptBox["k", "\[Mu]"], 
     SuperscriptBox["k", "\[Mu]"]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"multiDot", "[", 
   RowBox[{"kd", ",", "kU", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8140246544987698`*^9, 3.8140246548836517`*^9}, {
  3.820901571960391*^9, 
  3.8209016106495094`*^9}},ExpressionUUID->"d6978ab3-1e4c-49be-8521-\
f45ac120dfd7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox["k0", "2"]}], "+", 
  RowBox[{
   SuperscriptBox["kx", "2"], " ", 
   SuperscriptBox[
    RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   SuperscriptBox["ky", "2"], " ", 
   SuperscriptBox[
    RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   SuperscriptBox["kz", "2"], " ", 
   SuperscriptBox[
    RowBox[{"a", "[", "t", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{
  3.814024655443501*^9, {3.820840693164214*^9, 3.8208407121937065`*^9}, 
   3.8209016216324244`*^9, 3.82144101425807*^9, 
   3.8273739895220375`*^9},ExpressionUUID->"ee428f28-869f-4dcc-b0a9-\
0d484c95398f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7958488538855724`*^9, 
  3.7958488558967204`*^9}},ExpressionUUID->"758213cf-93f9-481b-a063-\
98af91581e02"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
 Example 2: Robertson-Walker metric & 1st order Perturbation Equations of Ma \
& Bertschinger \
\>", "Subsection",
 ShowGroupOpener->True,
 CellChangeTimes->{
  3.7270913637732935`*^9, {3.727091975190765*^9, 3.727091976981346*^9}, {
   3.7276770338559055`*^9, 3.727677034974039*^9}, {3.7456656575780177`*^9, 
   3.7456656669235115`*^9}, {3.7459049192595687`*^9, 3.745904923654994*^9}, {
   3.74626900332701*^9, 3.7462690077722235`*^9}, {3.748254887967632*^9, 
   3.7482548886580267`*^9}, 3.7482549238577576`*^9, {3.7957887173741655`*^9, 
   3.795788728376336*^9}, 3.7957916545717726`*^9, {3.796821648571991*^9, 
   3.796821650355611*^9}, {3.8209050246046405`*^9, 3.8209050445976477`*^9}},
 FontSize->16,ExpressionUUID->"fa39f474-d804-480f-abfa-a53fd6c58997"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"We", " ", "use", " ", "conformal", " ", "time", " ", "d\[Tau]"}],
     "=", 
    RowBox[{"dt", "/", 
     RowBox[{"a", "[", "t", "]"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"xCoord", "=", 
    RowBox[{"{", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "}"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.728208295702733*^9, 3.7282082964053755`*^9}, {
  3.728209981015273*^9, 3.7282099890734415`*^9}, {3.795788795881201*^9, 
  3.795788796418894*^9}, {3.82090507250893*^9, 
  3.820905093702516*^9}},ExpressionUUID->"bd803918-bbfd-4631-b1bb-\
c284e6aaa812"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "The", " ", "FLRW", " ", "metric", " ", "in", " ", "Conformal", " ", 
   "Newtonian", " ", "gauge", " ", "with", " ", "conformal", " ", "time"}], 
  " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7270919836499414`*^9, 3.7270920067741146`*^9}, {
  3.7957887557635584`*^9, 3.7957887579782143`*^9}, {3.7957889418872614`*^9, 
  3.795788951790079*^9}, {3.820841337864688*^9, 
  3.8208413388647037`*^9}},ExpressionUUID->"03a2a5b0-db96-4d79-a30f-\
a2b3b1dd0fe3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "[", "\[Tau]", "]"}], "^", "2"}], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"2", "\[Epsilon]", " ", 
            RowBox[{"\[CapitalPsi]", "[", 
             RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
          ")"}]}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", "\[Epsilon]", " ", 
           RowBox[{"\[CapitalPhi]", "[", 
            RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
         ")"}], ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", "\[Epsilon]", " ", 
           RowBox[{"\[CapitalPhi]", "[", 
            RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
         ")"}], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", "\[Epsilon]", " ", 
           RowBox[{"\[CapitalPhi]", "[", 
            RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
         ")"}]}], "}"}]}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7270920164553432`*^9, 3.727092037173853*^9}, {
   3.7271057467640066`*^9, 3.727105769726654*^9}, {3.727105801886936*^9, 
   3.727105806150839*^9}, {3.728210001606763*^9, 3.7282100152536163`*^9}, {
   3.7282851340788965`*^9, 3.728285136891513*^9}, 3.795788802402437*^9, {
   3.7957889381239157`*^9, 3.795788963746776*^9}, {3.795789116683758*^9, 
   3.7957891219967804`*^9}, {3.795791296652253*^9, 3.7957913038424764`*^9}, {
   3.7958518211388054`*^9, 
   3.795851829154239*^9}},ExpressionUUID->"1b40145d-a902-4da4-af9f-\
08ac0060645a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RGtensors", "[", 
  RowBox[{"g", ",", "xCoord"}], "]"}]], "Input",ExpressionUUID->"5b3b1dc9-\
c0a7-4c10-87bb-abb57568533b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"2", " ", "\[Epsilon]", " ", 
            RowBox[{"\[CapitalPsi]", "[", 
             RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
          ")"}]}], "0", "0", "0"},
       {"0", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "\[Epsilon]", " ", 
            RowBox[{"\[CapitalPhi]", "[", 
             RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
          ")"}]}], "0", "0"},
       {"0", "0", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "\[Epsilon]", " ", 
            RowBox[{"\[CapitalPhi]", "[", 
             RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
          ")"}]}], "0"},
       {"0", "0", "0", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "\[Epsilon]", " ", 
            RowBox[{"\[CapitalPhi]", "[", 
             RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
          ")"}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{$CellContext`a[$CellContext`\[Tau]]^2 (-1 - 
       2 $CellContext`\[Epsilon] $CellContext`\[CapitalPsi][$CellContext`\
\[Tau], $CellContext`x, $CellContext`y, $CellContext`z]), 0, 0, 0}, {
     0, $CellContext`a[$CellContext`\[Tau]]^2 (1 - 
       2 $CellContext`\[Epsilon] $CellContext`\[CapitalPhi][$CellContext`\
\[Tau], $CellContext`x, $CellContext`y, $CellContext`z]), 0, 0}, {
     0, 0, $CellContext`a[$CellContext`\[Tau]]^2 (1 - 
       2 $CellContext`\[Epsilon] $CellContext`\[CapitalPhi][$CellContext`\
\[Tau], $CellContext`x, $CellContext`y, $CellContext`z]), 0}, {
     0, 0, 0, $CellContext`a[$CellContext`\[Tau]]^2 (1 - 
       2 $CellContext`\[Epsilon] $CellContext`\[CapitalPhi][$CellContext`\
\[Tau], $CellContext`x, $CellContext`y, $CellContext`z])}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7958518351175003`*^9, 3.7958521242063427`*^9, 
  3.795852157588422*^9, 3.7960441534191933`*^9, 3.796044351301025*^9, 
  3.7963882316722927`*^9, 3.7968216804047236`*^9, 3.820840730327905*^9, 
  3.820901907661791*^9, 3.820928499260507*^9, 3.821441032743012*^9, 
  3.8273740025149117`*^9},ExpressionUUID->"00a41a98-6aa7-400f-9bfb-\
306820ca074f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"LineElement = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"a", "[", "\[Tau]", "]"}], "2"]}], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "x", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"\[CapitalPhi]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
       ")"}]}], "-", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "y", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"\[CapitalPhi]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
       ")"}]}], "-", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "z", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"\[CapitalPhi]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
       ")"}]}], "-", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "\[Tau]", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"\[CapitalPsi]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
       ")"}]}]}],
    Short[#, 32]& ]}],
  SequenceForm["LineElement = ", 
   Short[-$CellContext`a[$CellContext`\[Tau]]^2 \
$CellContext`d[$CellContext`x]^2 (-1 + 
      2 $CellContext`\[Epsilon] \
$CellContext`\[CapitalPhi][$CellContext`\[Tau], $CellContext`x, \
$CellContext`y, $CellContext`z]) - $CellContext`a[$CellContext`\[Tau]]^2 \
$CellContext`d[$CellContext`y]^2 (-1 + 
     2 $CellContext`\[Epsilon] \
$CellContext`\[CapitalPhi][$CellContext`\[Tau], $CellContext`x, \
$CellContext`y, $CellContext`z]) - $CellContext`a[$CellContext`\[Tau]]^2 \
$CellContext`d[$CellContext`z]^2 (-1 + 
     2 $CellContext`\[Epsilon] \
$CellContext`\[CapitalPhi][$CellContext`\[Tau], $CellContext`x, \
$CellContext`y, $CellContext`z]) - $CellContext`a[$CellContext`\[Tau]]^2 \
$CellContext`d[$CellContext`\[Tau]]^2 (1 + 
     2 $CellContext`\[Epsilon] \
$CellContext`\[CapitalPsi][$CellContext`\[Tau], $CellContext`x, \
$CellContext`y, $CellContext`z]), 32]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7958518351175003`*^9, 3.7958521242063427`*^9, 
  3.795852157588422*^9, 3.7960441534191933`*^9, 3.796044351301025*^9, 
  3.7963882316722927`*^9, 3.7968216804047236`*^9, 3.820840730327905*^9, 
  3.820901907661791*^9, 3.820928499260507*^9, 3.821441032743012*^9, 
  3.8273740025305333`*^9},ExpressionUUID->"fc5ae938-f3a5-4895-90a3-\
4e78743f36b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", "\[Epsilon]", " ", 
              RowBox[{"\[CapitalPsi]", "[", 
               RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
            ")"}]}]]}], "0", "0", "0"},
       {"0", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "\[Epsilon]", " ", 
              RowBox[{"\[CapitalPhi]", "[", 
               RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
            ")"}]}]]}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "\[Epsilon]", " ", 
              RowBox[{"\[CapitalPhi]", "[", 
               RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
            ")"}]}]]}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "\[Epsilon]", " ", 
              RowBox[{"\[CapitalPhi]", "[", 
               RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
            ")"}]}]]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{-$CellContext`a[$CellContext`\[Tau]]^(-2)/(1 + 
      2 $CellContext`\[Epsilon] \
$CellContext`\[CapitalPsi][$CellContext`\[Tau], $CellContext`x, \
$CellContext`y, $CellContext`z]), 0, 0, 0}, {
     0, -$CellContext`a[$CellContext`\[Tau]]^(-2)/(-1 + 
      2 $CellContext`\[Epsilon] \
$CellContext`\[CapitalPhi][$CellContext`\[Tau], $CellContext`x, \
$CellContext`y, $CellContext`z]), 0, 0}, {
     0, 0, -$CellContext`a[$CellContext`\[Tau]]^(-2)/(-1 + 
      2 $CellContext`\[Epsilon] \
$CellContext`\[CapitalPhi][$CellContext`\[Tau], $CellContext`x, \
$CellContext`y, $CellContext`z]), 0}, {
     0, 0, 0, -$CellContext`a[$CellContext`\[Tau]]^(-2)/(-1 + 
      2 $CellContext`\[Epsilon] \
$CellContext`\[CapitalPhi][$CellContext`\[Tau], $CellContext`x, \
$CellContext`y, $CellContext`z])}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7958518351175003`*^9, 3.7958521242063427`*^9, 
  3.795852157588422*^9, 3.7960441534191933`*^9, 3.796044351301025*^9, 
  3.7963882316722927`*^9, 3.7968216804047236`*^9, 3.820840730327905*^9, 
  3.820901907661791*^9, 3.820928499260507*^9, 3.821441032743012*^9, 
  3.827374002552696*^9},ExpressionUUID->"b0eb3bca-cbfc-4ab6-8b01-\
cc4797d056ad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0., " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7958518351175003`*^9, 3.7958521242063427`*^9, 
  3.795852157588422*^9, 3.7960441534191933`*^9, 3.796044351301025*^9, 
  3.7963882316722927`*^9, 3.7968216804047236`*^9, 3.820840730327905*^9, 
  3.820901907661791*^9, 3.820928499260507*^9, 3.821441032743012*^9, 
  3.827374002552696*^9},ExpressionUUID->"d12e66b3-d69b-4c29-8db5-\
69870908ea23"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.016000000000000014`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.016000000000000014`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7958518351175003`*^9, 3.7958521242063427`*^9, 
  3.795852157588422*^9, 3.7960441534191933`*^9, 3.796044351301025*^9, 
  3.7963882316722927`*^9, 3.7968216804047236`*^9, 3.820840730327905*^9, 
  3.820901907661791*^9, 3.820928499260507*^9, 3.821441032743012*^9, 
  3.827374002552696*^9},ExpressionUUID->"b509c52c-09e2-4305-a8ea-\
78067e1cd938"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", "0.125`",
    "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.125, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7958518351175003`*^9, 3.7958521242063427`*^9, 
  3.795852157588422*^9, 3.7960441534191933`*^9, 3.796044351301025*^9, 
  3.7963882316722927`*^9, 3.7968216804047236`*^9, 3.820840730327905*^9, 
  3.820901907661791*^9, 3.820928499260507*^9, 3.821441032743012*^9, 
  3.8273740026998053`*^9},ExpressionUUID->"772a2493-5e46-4c45-a180-\
ae310b941d08"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.20299999999999985`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.20299999999999985`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7958518351175003`*^9, 3.7958521242063427`*^9, 
  3.795852157588422*^9, 3.7960441534191933`*^9, 3.796044351301025*^9, 
  3.7963882316722927`*^9, 3.7968216804047236`*^9, 3.820840730327905*^9, 
  3.820901907661791*^9, 3.820928499260507*^9, 3.821441032743012*^9, 
  3.827374002915959*^9},ExpressionUUID->"f8a0458f-22ad-4f38-9fd5-\
839abf53f365"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.29700000000000015`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.29700000000000015`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7958518351175003`*^9, 3.7958521242063427`*^9, 
  3.795852157588422*^9, 3.7960441534191933`*^9, 3.796044351301025*^9, 
  3.7963882316722927`*^9, 3.7968216804047236`*^9, 3.820840730327905*^9, 
  3.820901907661791*^9, 3.820928499260507*^9, 3.821441032743012*^9, 
  3.8273740032167435`*^9},ExpressionUUID->"1d32130e-6562-4a43-9bcc-\
0add744f8b0f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "0.7810000000000004`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0.7810000000000004, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7958518351175003`*^9, 3.7958521242063427`*^9, 
  3.795852157588422*^9, 3.7960441534191933`*^9, 3.796044351301025*^9, 
  3.7963882316722927`*^9, 3.7968216804047236`*^9, 3.820840730327905*^9, 
  3.820901907661791*^9, 3.820928499260507*^9, 3.821441032743012*^9, 
  3.8273740041344867`*^9},ExpressionUUID->"4b46bd46-7f2a-4053-b5ba-\
83b916b29569"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", "0.266`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0.266, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7958518351175003`*^9, 3.7958521242063427`*^9, 
  3.795852157588422*^9, 3.7960441534191933`*^9, 3.796044351301025*^9, 
  3.7963882316722927`*^9, 3.7968216804047236`*^9, 3.820840730327905*^9, 
  3.820901907661791*^9, 3.820928499260507*^9, 3.821441032743012*^9, 
  3.8273740044039793`*^9},ExpressionUUID->"739fb512-4682-44b4-a935-\
9ec8eec30258"],

Cell[BoxData["\<\"All tasks completed in 1.70313 seconds\"\>"], "Print",
 CellChangeTimes->{3.7958518351175003`*^9, 3.7958521242063427`*^9, 
  3.795852157588422*^9, 3.7960441534191933`*^9, 3.796044351301025*^9, 
  3.7963882316722927`*^9, 3.7968216804047236`*^9, 3.820840730327905*^9, 
  3.820901907661791*^9, 3.820928499260507*^9, 3.821441032743012*^9, 
  3.8273740044039793`*^9},ExpressionUUID->"9d21f570-c78b-4e4f-b01a-\
a556caa42cf3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Testing", " ", "the", " ", "metric", " ", "and", " ", "Cronecker", " ", 
    "\[Delta]ij"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Raise", "[", 
    RowBox[{"gdd", ",", 
     RowBox[{"{", "1", "}"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Lower", "[", 
    RowBox[{"gUU", ",", 
     RowBox[{"{", "1", "}"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"\[Delta]Ud", "=", 
    RowBox[{"IdentityMatrix", "[", "4", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Delta]ij", "=", 
     RowBox[{"IdentityMatrix", "[", "3", "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7277825039451513`*^9, 3.7277825200839076`*^9}, {
  3.7278550409146614`*^9, 3.7278550683175163`*^9}, {3.728226515349077*^9, 
  3.728226549260151*^9}},ExpressionUUID->"4a4c67a8-b7fc-49bb-a8b6-\
ddf8974efe4f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.795852057359955*^9, 3.795852128074436*^9, 
  3.795852161537625*^9, 3.7960441591025743`*^9, 3.7960443574215283`*^9, 
  3.796388234618388*^9, 3.7968216867770023`*^9, 3.8208407337595997`*^9, 
  3.820901921725462*^9, 3.8209285062019105`*^9, 3.8214410349931717`*^9, 
  3.8273740045041876`*^9},ExpressionUUID->"5b6d3c1c-e8c7-4b5a-b604-\
636b5d174bb7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.795852057359955*^9, 3.795852128074436*^9, 
  3.795852161537625*^9, 3.7960441591025743`*^9, 3.7960443574215283`*^9, 
  3.796388234618388*^9, 3.7968216867770023`*^9, 3.8208407337595997`*^9, 
  3.820901921725462*^9, 3.8209285062019105`*^9, 3.8214410349931717`*^9, 
  3.8273740045041876`*^9},ExpressionUUID->"764fd5fc-e074-48f1-9b7b-\
801f84e78e99"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.795852057359955*^9, 3.795852128074436*^9, 
  3.795852161537625*^9, 3.7960441591025743`*^9, 3.7960443574215283`*^9, 
  3.796388234618388*^9, 3.7968216867770023`*^9, 3.8208407337595997`*^9, 
  3.820901921725462*^9, 3.8209285062019105`*^9, 3.8214410349931717`*^9, 
  3.8273740045198116`*^9},ExpressionUUID->"16dbde58-a8c4-457f-aad3-\
7db9da94ac05"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Delta]Ud", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.820901945528552*^9, 
  3.820901948082981*^9}},ExpressionUUID->"73eee0d8-5312-40a8-ac98-\
4b07ade2b22d"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0", "0"},
     {"0", "1", "0", "0"},
     {"0", "0", "1", "0"},
     {"0", "0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.820901948440364*^9, 3.820928507754012*^9, 
  3.821441036693362*^9, 
  3.8273740063723927`*^9},ExpressionUUID->"2ca34280-fac2-4a94-8223-\
731e476e5378"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Delta]ij", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.8209019384642897`*^9, 
  3.820901940885193*^9}},ExpressionUUID->"88e4f444-2e0c-49d2-98d0-\
5a135dd4e07f"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0"},
     {"0", "1", "0"},
     {"0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.82090194159787*^9, 3.8209285089191017`*^9, 
  3.8214410378772964`*^9, 
  3.8273740073130064`*^9},ExpressionUUID->"e24a0b81-c016-4fe4-83dc-\
b2813d9477f0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Approximation", " ", "rules"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"approx", ",", "ApproxSimplify", ",", "ApproxFullSimplify"}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a2H", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
         RowBox[{"a", "[", "\[Tau]", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "\[Tau]", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"a", "[", "\[Tau]", "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"H", "'"}], "[", "\[Tau]", "]"}], "+", 
           RowBox[{
            RowBox[{"H", "[", "\[Tau]", "]"}], "^", "2"}]}], ")"}]}]}]}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zeroorder", "=", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]", "\[Rule]", "0"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"thetadef", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"kx", " ", 
         RowBox[{"ux", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "X_"}], 
        "+", 
        RowBox[{"ky", " ", 
         RowBox[{"uy", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
         "X_"}], "+", 
        RowBox[{"kz", " ", 
         RowBox[{"uz", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
         "X_"}]}], "\[Rule]", 
       RowBox[{"X", " ", 
        FractionBox[
         RowBox[{"\[Theta]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "I"]}]}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"thetadef1", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"kx", " ", 
         RowBox[{
          SuperscriptBox["ux", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
         "X_"}], "+", 
        RowBox[{"ky", " ", 
         RowBox[{
          SuperscriptBox["uy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
         "X_"}], "+", 
        RowBox[{"kz", " ", 
         RowBox[{
          SuperscriptBox["uz", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
         "X_"}]}], "\[Rule]", 
       RowBox[{"X", " ", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[Theta]", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "I"]}]}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"k2def", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["kx", "2"], " ", "f_"}], "+", 
        RowBox[{
         SuperscriptBox["ky", "2"], " ", "f_"}], "+", 
        RowBox[{
         SuperscriptBox["kz", "2"], "f_"}]}], "->", 
       RowBox[{
        RowBox[{"k", "^", "2"}], " ", "f"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fourierderiv", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"n1_", ",", "n2_", ",", "n3_", ",", "n4_"}], "]"}], "[", 
         "\[CapitalPhi]_", "]"}], "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"I", " ", "kx"}], ")"}], "^", "n2"}], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"I", " ", "ky"}], ")"}], "^", "n3"}], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"I", " ", "kz"}], ")"}], "^", "n4"}], " ", 
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"n1", ",", "0", ",", "0", ",", "0"}], "]"}], "[", 
          "\[CapitalPhi]", "]"}], "[", 
         RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], "}"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApproxSimplify", "[", "x_", "]"}], ":=", 
    RowBox[{"Expand", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{"x", ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
     "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApproxFullSimplify", "[", "x_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ApproxSimplify", "[", "x", "]"}], "/.", "fourierderiv"}], "//.",
        "thetadef"}], "//.", "k2def"}], "//.", "thetadef1"}]}]}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQvUJXYk/gsdeO5bcF94LolOt2P38BaXOJl39B9L7D
Vfz/gfQl4z1CIHrCwVATEL1np5gliN6yxdYJRF9IuesCoicKP7vPePy1o79n
8yMQ7cI79SWIVqpOeAWin93W/QSiuxauANM7TdeV8J577fipnq8URN+3jOgG
0RfKl4Dp3YWpM5+4v3H8ZRyyEEQ3RS5XYvJ441jR/hNMi0XZGYNomX0+YDrG
5W04M5A+sNorCkRHJ6alguhp4W5ZIPq0j0IeiPYRyQTTbBlzDROB9NyVMpYg
WstewR5EVz145gqic277Xb/j+cYxwyQSTAMAYWCZ4Q==
  
  "],ExpressionUUID->"fc8980dd-572a-4ea2-871d-a3b63ab9418e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Test", " ", "the", " ", 
    RowBox[{"approximation", ":", " ", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"1", "+", 
         RowBox[{"2", "\[CapitalPsi]"}]}]], "\[TildeEqual]", 
       RowBox[{"1", "-", 
        RowBox[{"2", "\[CapitalPsi]"}], "+"}]}], "..."}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gUU", "//", "FullSimplify"}], "//", "MatrixForm"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"gUU", "//", "ApproxFullSimplify"}], "//", "FullSimplify"}], "//",
     "MatrixForm"}]}]}]], "Input",
 CellChangeTimes->{{3.7958495345857687`*^9, 3.795849612234436*^9}, {
  3.7960442369597054`*^9, 3.7960442649385934`*^9}, {3.7960443656297855`*^9, 
  3.796044378440735*^9}},ExpressionUUID->"86567fbd-c4bc-44d5-b3d2-\
b80a8f11409b"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"2", " ", "\[Epsilon]", " ", 
            RowBox[{"\[CapitalPsi]", "[", 
             RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
          ")"}]}]]}], "0", "0", "0"},
     {"0", 
      FractionBox["1", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "\[Epsilon]", " ", 
           RowBox[{"\[CapitalPhi]", "[", 
            RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
         ")"}]}]], "0", "0"},
     {"0", "0", 
      FractionBox["1", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "\[Epsilon]", " ", 
           RowBox[{"\[CapitalPhi]", "[", 
            RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
         ")"}]}]], "0"},
     {"0", "0", "0", 
      FractionBox["1", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "\[Epsilon]", " ", 
           RowBox[{"\[CapitalPhi]", "[", 
            RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
         ")"}]}]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.795852131022897*^9, 3.7958521633476224`*^9, {3.796044228762392*^9, 
   3.7960442654644337`*^9}, {3.79604437191004*^9, 3.796044379029221*^9}, 
   3.7968216961309643`*^9, 3.8208407389745297`*^9, 3.8209020841665745`*^9, 
   3.8209285127905235`*^9, 3.821441041915209*^9, 
   3.827374012739504*^9},ExpressionUUID->"89f3179d-fd22-47c5-aca1-\
c88ded39c4d9"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"\[CapitalPsi]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
       SuperscriptBox[
        RowBox[{"a", "[", "\[Tau]", "]"}], "2"]], "0", "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"\[CapitalPhi]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
       SuperscriptBox[
        RowBox[{"a", "[", "\[Tau]", "]"}], "2"]], "0", "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"\[CapitalPhi]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
       SuperscriptBox[
        RowBox[{"a", "[", "\[Tau]", "]"}], "2"]], "0"},
     {"0", "0", "0", 
      FractionBox[
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"\[CapitalPhi]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
       SuperscriptBox[
        RowBox[{"a", "[", "\[Tau]", "]"}], "2"]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.795852131022897*^9, 3.7958521633476224`*^9, {3.796044228762392*^9, 
   3.7960442654644337`*^9}, {3.79604437191004*^9, 3.796044379029221*^9}, 
   3.7968216961309643`*^9, 3.8208407389745297`*^9, 3.8209020841665745`*^9, 
   3.8209285127905235`*^9, 3.821441041915209*^9, 
   3.8273740127551284`*^9},ExpressionUUID->"4a0a7bf8-40f1-4620-b79d-\
b0106d7bce03"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    FractionBox["1", 
     SqrtBox[
      RowBox[{"-", "g"}]]], "=", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "g"}], ")"}], 
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}]]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"-", 
         RowBox[{"Det", "[", "gdd", "]"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Epsilon]", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
    "PowerExpand"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7963891286889067`*^9, 3.7963891919330096`*^9}, {
  3.7963892458187895`*^9, 3.7963892594017973`*^9}, {3.820902103321301*^9, 
  3.8209021073434095`*^9}},ExpressionUUID->"b5bd3ca8-64dc-44df-bfd7-\
68d03e404b50"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"a", "[", "\[Tau]", "]"}], "4"]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], " ",
      "\[Epsilon]"}], 
    SuperscriptBox[
     RowBox[{"a", "[", "\[Tau]", "]"}], "4"]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "2"],
    SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 2, 1],
    Editable->False]}],
  SeriesData[$CellContext`\[Epsilon], 
   0, {$CellContext`a[$CellContext`\[Tau]]^(-4), $CellContext`a[$CellContext`\
\[Tau]]^(-4) (
     3 $CellContext`\[CapitalPhi][$CellContext`\[Tau], $CellContext`x, \
$CellContext`y, $CellContext`z] - $CellContext`\[CapitalPsi][$CellContext`\
\[Tau], $CellContext`x, $CellContext`y, $CellContext`z])}, 0, 2, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.796389144313054*^9, 3.7963891928207817`*^9}, 
   3.796821699897955*^9, 3.8208407411641407`*^9, 3.820902113121024*^9, 
   3.820928529087119*^9, 3.8214410438984294`*^9, 
   3.827374015988697*^9},ExpressionUUID->"500f2e25-ea6b-4cd8-99b0-\
ba56e6624811"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"--", 
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", " ", "The"}]}]}]}], " ", "perturbation", " ", "of", " ", 
   "the", " ", "Ricci", " ", 
   RowBox[{"scalar", " ", "--"}], 
   RowBox[{"--", 
    RowBox[{"--", "-"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7281278031861353`*^9, 
  3.7281278157551117`*^9}},ExpressionUUID->"c9344d7b-a4b8-42af-876c-\
96ac55d95339"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   SubscriptBox[
    SuperscriptBox["\[CapitalGamma]", "0"], "00"], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"GUdd", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "1"}], "]"}], "]"}], "/.", "a2H"}], "//", 
   "ApproxFullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7957895461462464`*^9, 3.795789570687512*^9}, {
  3.795791074656602*^9, 
  3.7957911111053915`*^9}},ExpressionUUID->"90818ef1-04ef-4b35-b40b-\
0985befaa4f6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "[", "\[Tau]", "]"}], "+", 
  RowBox[{"\[Epsilon]", " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPsi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.8273740382783213`*^9},ExpressionUUID->"808cb14f-753e-4d2f-91dd-\
f23d6a9ff915"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   SubscriptBox[
    SuperscriptBox["\[CapitalGamma]", "0"], 
    RowBox[{"0", "k"}]], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"GUdd", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"2", ";;", "4"}]}], "]"}], "]"}], "/.", "a2H"}], "//", 
   "ApproxFullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7957895837643614`*^9, 3.795789584513623*^9}, {
  3.795791116883051*^9, 
  3.79579112121311*^9}},ExpressionUUID->"ff744f14-8881-4044-a0c5-\
2e3d3401ae66"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", "kx", " ", "\[Epsilon]", " ", 
    RowBox[{"\[CapitalPsi]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], ",", 
   RowBox[{"\[ImaginaryI]", " ", "ky", " ", "\[Epsilon]", " ", 
    RowBox[{"\[CapitalPsi]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], ",", 
   RowBox[{"\[ImaginaryI]", " ", "kz", " ", "\[Epsilon]", " ", 
    RowBox[{"\[CapitalPsi]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.8273740372731514`*^9},ExpressionUUID->"7df654c0-0efc-47b4-8362-\
e13185dc0eed"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   SubscriptBox[
    SuperscriptBox["\[CapitalGamma]", "i"], "00"], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"GUdd", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", "4"}], ",", "1", ",", "1"}], "]"}], "]"}], "/.", 
    "a2H"}], "//", "ApproxFullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.795789620170047*^9, 3.795789632726535*^9}, {
  3.7957911235289526`*^9, 
  3.7957911277756643`*^9}},ExpressionUUID->"eb984dab-1cef-41d5-b72b-\
b9201250e01b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", "kx", " ", "\[Epsilon]", " ", 
    RowBox[{"\[CapitalPsi]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], ",", 
   RowBox[{"\[ImaginaryI]", " ", "ky", " ", "\[Epsilon]", " ", 
    RowBox[{"\[CapitalPsi]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], ",", 
   RowBox[{"\[ImaginaryI]", " ", "kz", " ", "\[Epsilon]", " ", 
    RowBox[{"\[CapitalPsi]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.796044389015094*^9, 3.8208407520764656`*^9, 
  3.820902162462093*^9, 
  3.821441222049867*^9},ExpressionUUID->"f549de37-4485-4ecd-9e95-\
aa2fc9c32e93"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   SubscriptBox[
    SuperscriptBox["\[CapitalGamma]", "\[Alpha]"], 
    RowBox[{"0", "\[Alpha]"}]], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"GUdd", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "1", ",", "i"}], "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}], "/.", "a2H"}], "//",
    "ApproxFullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7957911498307004`*^9, 
  3.795791154607732*^9}},ExpressionUUID->"592db7d8-1297-4696-8cd2-\
3967e9dffcc9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", " ", 
   RowBox[{"H", "[", "\[Tau]", "]"}]}], "-", 
  RowBox[{"3", " ", "\[Epsilon]", " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPhi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{"\[Epsilon]", " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPsi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.7960443923421583`*^9, 3.82084075213443*^9, 
  3.8209021741614676`*^9, 3.82144122320581*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"bf5bb0e6-1a46-463f-b6c6-b3737856b636"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   SubscriptBox[
    SuperscriptBox["\[CapitalGamma]", "\[Alpha]"], "i\[Alpha]"], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"GUdd", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", 
         RowBox[{"2", ";;", "4"}], ",", "i"}], "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}], "/.", "a2H"}], "//",
    "ApproxFullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7957896627295685`*^9, 3.79578970399302*^9}, {
  3.7957911301226325`*^9, 3.7957911307018566`*^9}, {3.7957911609953814`*^9, 
  3.795791165363169*^9}},ExpressionUUID->"528cc183-000a-4fba-beb7-\
6ced103ed7f6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", "kx", " ", "\[Epsilon]", 
     " ", 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "kx", " ", "\[Epsilon]", " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", "ky", " ", "\[Epsilon]", 
     " ", 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "ky", " ", "\[Epsilon]", " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", "kz", " ", "\[Epsilon]", 
     " ", 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "kz", " ", "\[Epsilon]", " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7960443996414433`*^9, 3.8208407521861773`*^9, 
  3.8209021816958375`*^9, 3.8214412773404417`*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"f3af9cd2-4c10-41b0-ae24-327f7807d166"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   SubscriptBox["R", "00"], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Rdd", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], "/.", "a2H"}], "//", 
   "ApproxFullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.795790631509272*^9, 3.7957906496646833`*^9}, {
  3.7957911702294436`*^9, 
  3.7957911757174187`*^9}},ExpressionUUID->"162c3115-ca9c-4576-ba05-\
f1e92da5110e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["k", "2"]}], " ", "\[Epsilon]", " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "\[Tau]", "]"}]}], "+", 
  RowBox[{"3", " ", "\[Epsilon]", " ", 
   RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPhi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{"3", " ", "\[Epsilon]", " ", 
   RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPsi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{"3", " ", "\[Epsilon]", " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPhi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.7960444032579746`*^9, 
  3.8208407522391367`*^9},ExpressionUUID->"097ba427-3101-453b-b447-\
f9c2d817791c"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   SubscriptBox["R", 
    RowBox[{"0", "i"}]], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Rdd", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", 
       RowBox[{"2", ";;", "4"}]}], "]"}], "]"}], "/.", "a2H"}], "//", 
   "ApproxFullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7957906702791348`*^9, 3.795790674950568*^9}, {
  3.795791181210617*^9, 
  3.7957911843597*^9}},ExpressionUUID->"239eca5a-6e9b-4fcd-94b8-7df4626c6b52"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "kx", " ", "\[Epsilon]", " ", 
     RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "kx", " ", "\[Epsilon]", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "ky", " ", "\[Epsilon]", " ", 
     RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "ky", " ", "\[Epsilon]", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "kz", " ", "\[Epsilon]", " ", 
     RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "kz", " ", "\[Epsilon]", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.79604440928216*^9, 
  3.82084075229411*^9},ExpressionUUID->"302986a3-97d5-46de-9add-1357d8e3cf8a"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    SubscriptBox["R", "ij"], ",", " ", 
    SubscriptBox["R", 
     RowBox[{"1", ",", "2"}]]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Rdd", "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "3"}], "]"}], "]"}], "/.", "a2H"}], "//", 
   "ApproxFullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.795790696174182*^9, 3.795790699433267*^9}, {
  3.795791187011641*^9, 3.795791195005848*^9}, {3.820902311536745*^9, 
  3.820902316591345*^9}},ExpressionUUID->"6ec639ca-045b-4663-9b20-\
c1ae687dc312"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "kx"}], " ", "ky", " ", "\[Epsilon]", " ", 
   RowBox[{"\[CapitalPhi]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{"kx", " ", "ky", " ", "\[Epsilon]", " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.7960444120755243`*^9, 
  3.8208407523442025`*^9},ExpressionUUID->"8040d046-d31e-4a73-9e94-\
f320d5b5297a"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   SubscriptBox["R", "ii"], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Rdd", "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "2"}], "]"}], "]"}], "/.", "a2H"}], "//", 
   "ApproxFullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.795790707935381*^9, 3.7957907089308643`*^9}, {
  3.795791197007609*^9, 
  3.7957912004308205`*^9}},ExpressionUUID->"a7f4d4bd-d595-4ac1-a771-\
520189140943"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "\[Tau]", "]"}], "2"]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["kx", "2"], " ", "\[Epsilon]", " ", 
   RowBox[{"\[CapitalPhi]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["ky", "2"], " ", "\[Epsilon]", " ", 
   RowBox[{"\[CapitalPhi]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["kz", "2"], " ", "\[Epsilon]", " ", 
   RowBox[{"\[CapitalPhi]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"4", " ", "\[Epsilon]", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "\[Tau]", "]"}], "2"], " ", 
   RowBox[{"\[CapitalPhi]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["kx", "2"], " ", "\[Epsilon]", " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"4", " ", "\[Epsilon]", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "\[Tau]", "]"}], "2"], " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["H", "\[Prime]",
    MultilineFunction->None], "[", "\[Tau]", "]"}], "-", 
  RowBox[{"2", " ", "\[Epsilon]", " ", 
   RowBox[{"\[CapitalPhi]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "\[Tau]", "]"}]}], "-", 
  RowBox[{"2", " ", "\[Epsilon]", " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "\[Tau]", "]"}]}], "-", 
  RowBox[{"5", " ", "\[Epsilon]", " ", 
   RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPhi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"\[Epsilon]", " ", 
   RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPsi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"\[Epsilon]", " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPhi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.796044413919177*^9, 
  3.820840752398052*^9},ExpressionUUID->"f78b32b5-871a-476b-be43-\
1fe6bd433887"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["zeroorder"], "Input",ExpressionUUID->"b0c5d5da-03cf-4d5a-b333-1932e0b08af4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[Epsilon]", "\[Rule]", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.8209023390036335`*^9, 
  3.821441281821916*^9},ExpressionUUID->"29ba3ead-4306-49b1-a728-\
9e0538c45c65"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "R", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"R0", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"R", "/.", "zeroorder"}], "/.", "a2H"}], "//", "Expand"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"dR", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"R", "-", "R0"}], "/.", "a2H"}], "//", "Simplify"}], "//", 
     "ApproxFullSimplify"}]}]}]}]], "Input",
 CellChangeTimes->{{3.795791048032462*^9, 3.79579105369847*^9}, {
  3.7957912052176676`*^9, 
  3.795791207938018*^9}},ExpressionUUID->"96a375cc-d97f-443e-a901-\
640c93f088ac"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"6", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "\[Tau]", "]"}], "2"]}], 
   SuperscriptBox[
    RowBox[{"a", "[", "\[Tau]", "]"}], "2"]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "\[Tau]", "]"}]}], 
   SuperscriptBox[
    RowBox[{"a", "[", "\[Tau]", "]"}], "2"]]}]], "Output",
 CellChangeTimes->{3.7958520622764664`*^9, 3.795852171198976*^9, 
  3.7960444175765147`*^9, 3.820840752449427*^9, 3.820902349265112*^9, 
  3.820928538003661*^9, 3.8214412853310337`*^9, 
  3.827374049687107*^9},ExpressionUUID->"062d172e-d084-4341-8bcb-\
573d8fe41c2d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"4", " ", 
     SuperscriptBox["k", "2"], " ", "\[Epsilon]", " ", 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
    SuperscriptBox[
     RowBox[{"a", "[", "\[Tau]", "]"}], "2"]]}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["k", "2"], " ", "\[Epsilon]", " ", 
    RowBox[{"\[CapitalPsi]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   SuperscriptBox[
    RowBox[{"a", "[", "\[Tau]", "]"}], "2"]], "-", 
  FractionBox[
   RowBox[{"12", " ", "\[Epsilon]", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "\[Tau]", "]"}], "2"], " ", 
    RowBox[{"\[CapitalPsi]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   SuperscriptBox[
    RowBox[{"a", "[", "\[Tau]", "]"}], "2"]], "-", 
  FractionBox[
   RowBox[{"12", " ", "\[Epsilon]", " ", 
    RowBox[{"\[CapitalPsi]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "\[Tau]", "]"}]}], 
   SuperscriptBox[
    RowBox[{"a", "[", "\[Tau]", "]"}], "2"]], "-", 
  FractionBox[
   RowBox[{"18", " ", "\[Epsilon]", " ", 
    RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[CapitalPhi]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   SuperscriptBox[
    RowBox[{"a", "[", "\[Tau]", "]"}], "2"]], "-", 
  FractionBox[
   RowBox[{"6", " ", "\[Epsilon]", " ", 
    RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[CapitalPsi]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   SuperscriptBox[
    RowBox[{"a", "[", "\[Tau]", "]"}], "2"]], "-", 
  FractionBox[
   RowBox[{"6", " ", "\[Epsilon]", " ", 
    RowBox[{
     SuperscriptBox["\[CapitalPhi]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   SuperscriptBox[
    RowBox[{"a", "[", "\[Tau]", "]"}], "2"]]}]], "Output",
 CellChangeTimes->{3.7958520622764664`*^9, 3.795852171198976*^9, 
  3.7960444175765147`*^9, 3.820840752449427*^9, 3.820902349265112*^9, 
  3.820928538003661*^9, 3.8214412853310337`*^9, 
  3.827374050110141*^9},ExpressionUUID->"5862b0da-31c5-455d-9268-\
001087aad2ac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Print", "[", 
  RowBox[{"\"\<\[Delta]R = \>\"", ",", 
   RowBox[{"dR", "/.", 
    RowBox[{"\[Epsilon]", "\[Rule]", "1"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.796044438521914*^9, 3.7960444388850737`*^9}, {
  3.8209023800788307`*^9, 
  3.820902382593619*^9}},ExpressionUUID->"300955a5-db3c-4266-8d43-\
0e2e862b6392"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\[Delta]R = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["k", "2"], " ", 
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
      SuperscriptBox[
       RowBox[{"a", "[", "\[Tau]", "]"}], "2"]]}], "+", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     SuperscriptBox[
      RowBox[{"a", "[", "\[Tau]", "]"}], "2"]], "-", 
    FractionBox[
     RowBox[{"12", " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "\[Tau]", "]"}], "2"], " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     SuperscriptBox[
      RowBox[{"a", "[", "\[Tau]", "]"}], "2"]], "-", 
    FractionBox[
     RowBox[{"12", " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "\[Tau]", "]"}]}], 
     SuperscriptBox[
      RowBox[{"a", "[", "\[Tau]", "]"}], "2"]], "-", 
    FractionBox[
     RowBox[{"18", " ", 
      RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CapitalPhi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     SuperscriptBox[
      RowBox[{"a", "[", "\[Tau]", "]"}], "2"]], "-", 
    FractionBox[
     RowBox[{"6", " ", 
      RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CapitalPsi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     SuperscriptBox[
      RowBox[{"a", "[", "\[Tau]", "]"}], "2"]], "-", 
    FractionBox[
     RowBox[{"6", " ", 
      RowBox[{
       SuperscriptBox["\[CapitalPhi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     SuperscriptBox[
      RowBox[{"a", "[", "\[Tau]", "]"}], "2"]]}]}],
  SequenceForm[
  "\[Delta]R = ", (-4) $CellContext`k^2 \
$CellContext`a[$CellContext`\[Tau]]^(-2) \
$CellContext`\[CapitalPhi][$CellContext`\[Tau], $CellContext`x, \
$CellContext`y, $CellContext`z] + 
   2 $CellContext`k^2 $CellContext`a[$CellContext`\[Tau]]^(-2) $CellContext`\
\[CapitalPsi][$CellContext`\[Tau], $CellContext`x, $CellContext`y, \
$CellContext`z] - 
   12 $CellContext`a[$CellContext`\[Tau]]^(-2) $CellContext`H[$CellContext`\
\[Tau]]^2 $CellContext`\[CapitalPsi][$CellContext`\[Tau], $CellContext`x, \
$CellContext`y, $CellContext`z] - 
   12 $CellContext`a[$CellContext`\[Tau]]^(-2) \
$CellContext`\[CapitalPsi][$CellContext`\[Tau], $CellContext`x, \
$CellContext`y, $CellContext`z] 
   Derivative[1][$CellContext`H][$CellContext`\[Tau]] - 
   18 $CellContext`a[$CellContext`\[Tau]]^(-2) $CellContext`H[$CellContext`\
\[Tau]] Derivative[
    1, 0, 0, 0][$CellContext`\[CapitalPhi]][$CellContext`\[Tau], \
$CellContext`x, $CellContext`y, $CellContext`z] - 
   6 $CellContext`a[$CellContext`\[Tau]]^(-2) $CellContext`H[$CellContext`\
\[Tau]] Derivative[
    1, 0, 0, 0][$CellContext`\[CapitalPsi]][$CellContext`\[Tau], \
$CellContext`x, $CellContext`y, $CellContext`z] - 
   6 $CellContext`a[$CellContext`\[Tau]]^(-2) 
   Derivative[
    2, 0, 0, 0][$CellContext`\[CapitalPhi]][$CellContext`\[Tau], \
$CellContext`x, $CellContext`y, $CellContext`z]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7958522108191223`*^9, {3.7960444289920025`*^9, 3.7960444395144005`*^9}, 
   3.8208407528742332`*^9, {3.820902372057521*^9, 3.8209023831612473`*^9}, 
   3.8214412885471087`*^9, 
   3.827374052099635*^9},ExpressionUUID->"89c04bc6-c55a-4c0d-a047-\
fd828812dae9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", " ", "The"}]}]}]}], " ", "field", " ", 
    RowBox[{
     RowBox[{"equations", " ", "--"}], "--"}], 
    RowBox[{"--", "-"}]}], " ", "*)"}],
  FontSize->16]], "Input",
 CellChangeTimes->{{3.7281278226987658`*^9, 3.7281278259947844`*^9}, {
  3.7459050183607664`*^9, 3.7459050215914683`*^9}, {3.795789475828*^9, 
  3.7957894762513924`*^9}},ExpressionUUID->"6593738b-6c18-4010-a85e-\
5536c21f6547"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dxU", "=", 
   RowBox[{"d\[Tau]", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"\[Epsilon]", " ", "ux"}], ",", 
      RowBox[{"\[Epsilon]", " ", "uy"}], ",", 
      RowBox[{"\[Epsilon]", " ", "uz"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ds2", "=", 
   RowBox[{"dxU", ".", "gdd", ".", "dxU"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.796813885603899*^9, 3.796814001982521*^9}, {
  3.7968140645372133`*^9, 3.7968140653934045`*^9}, {3.7968141151703773`*^9, 
  3.796814172303623*^9}, {3.7968211264362526`*^9, 
  3.7968211503679748`*^9}},ExpressionUUID->"cc22990c-3d6c-4cf0-8f8a-\
6e152140262a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{
    SqrtBox[
     RowBox[{"-", "ds2"}]], ",", 
    RowBox[{"{", 
     RowBox[{"\[Epsilon]", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
  "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.796821155558964*^9, 3.796821196726224*^9}, {
  3.796821236682398*^9, 
  3.796821242539401*^9}},ExpressionUUID->"a9729b4c-e5f9-4fe8-be54-\
18c537adcd1a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"d\[Tau]", " ", 
    RowBox[{"a", "[", "\[Tau]", "]"}]}], "+", 
   RowBox[{"d\[Tau]", " ", 
    RowBox[{"a", "[", "\[Tau]", "]"}], " ", 
    RowBox[{"\[CapitalPsi]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
    "\[Epsilon]"}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "2"],
    SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 2, 1],
    Editable->False]}],
  SeriesData[$CellContext`\[Epsilon], 
   0, {$CellContext`d\[Tau] $CellContext`a[$CellContext`\[Tau]], \
($CellContext`d\[Tau] $CellContext`a[$CellContext`\[Tau]]) $CellContext`\
\[CapitalPsi][$CellContext`\[Tau], $CellContext`x, $CellContext`y, \
$CellContext`z]}, 0, 2, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7968211563925776`*^9, 3.7968211970745664`*^9}, {
   3.7968212382763615`*^9, 3.796821242922346*^9}, 3.7968217119681697`*^9, 
   3.8208407530243216`*^9, 3.8209285639201016`*^9, 
   3.821441295853253*^9},ExpressionUUID->"f724650b-c9af-4b6f-93a7-\
9a4547be4192"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"uU", "=", 
   RowBox[{
    RowBox[{"Normal", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"D", "[", 
          RowBox[{"dxU", ",", "d\[Tau]"}], "]"}], 
         RowBox[{"D", "[", 
          RowBox[{
           SqrtBox[
            RowBox[{"-", "ds2"}]], ",", "d\[Tau]"}], "]"}]], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
     "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ux", "->", 
       RowBox[{"ux", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], ",", 
      RowBox[{"uy", "->", 
       RowBox[{"uy", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], ",", 
      RowBox[{"uz", "->", 
       RowBox[{"uz", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
     "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ud", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Lower", "[", 
      RowBox[{"uU", ",", 
       RowBox[{"{", "1", "}"}]}], "]"}], "//", "ApproxFullSimplify"}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"multiDot", "[", 
   RowBox[{"gdd", ",", "gUU", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "2"}], "}"}]}], "]"}], "//", 
  "ApproxFullSimplify"}], "\n", 
 RowBox[{
  RowBox[{"multiDot", "[", 
   RowBox[{"ud", ",", 
    RowBox[{"Raise", "[", 
     RowBox[{"ud", ",", "1"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}]}], "]"}], "//", 
  "ApproxFullSimplify"}]}], "Input",
 CellChangeTimes->{{3.727606296583336*^9, 3.7276063837188673`*^9}, {
   3.7276095368072815`*^9, 3.7276095387573977`*^9}, {3.727609592597869*^9, 
   3.727609594613058*^9}, {3.727609998534825*^9, 3.7276100044374943`*^9}, {
   3.7276107116062193`*^9, 3.72761071489071*^9}, {3.727611323365918*^9, 
   3.727611331121824*^9}, {3.728201768110634*^9, 3.7282019033228693`*^9}, {
   3.7282028965806694`*^9, 3.7282028997531395`*^9}, {3.7282070594328594`*^9, 
   3.728207081717841*^9}, {3.7282102015594845`*^9, 3.728210231845944*^9}, {
   3.7282152460027637`*^9, 3.728215272161863*^9}, {3.7329414283171034`*^9, 
   3.7329414326142397`*^9}, {3.7329414635826178`*^9, 3.732941468958413*^9}, {
   3.7484477861361685`*^9, 3.748447786582656*^9}, {3.7484484823244686`*^9, 
   3.7484484825475645`*^9}, {3.7957891717337637`*^9, 
   3.7957891828878355`*^9}, {3.7957892756581593`*^9, 3.795789286791492*^9}, {
   3.7958524865159855`*^9, 3.7958524925157804`*^9}, {3.7960444522023354`*^9, 
   3.7960444676446266`*^9}, {3.796814467030199*^9, 3.7968145014209113`*^9}, 
   3.7968213833755703`*^9},ExpressionUUID->"22f3e54c-3a85-4b6f-a4e7-\
da70a5c5b153"],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{3.796821713767449*^9, 3.8208407531373577`*^9, 
  3.8209285716452627`*^9, 
  3.8214413036902885`*^9},ExpressionUUID->"0f1de97d-4a9c-4c74-ba47-\
38f36fa663a2"],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{3.796821713767449*^9, 3.8208407531373577`*^9, 
  3.8209285716452627`*^9, 
  3.8214413036958065`*^9},ExpressionUUID->"f1f1bdfe-b6bb-4bb6-97ce-\
b5ab725e4b47"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Eq", ".", " ", 
       RowBox[{"(", "22", ")"}]}], " ", "of", " ", "M"}], "&"}], "B"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalSigma]mij", "=", 
     RowBox[{
      RowBox[{
       FractionBox["3", "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Rho]", "[", "\[Tau]", "]"}], "+", 
         RowBox[{"P", "[", "\[Tau]", "]"}]}], ")"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"\[Sigma]", "[", 
                RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], ",", 
               
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "2"}], 
                "}"}]}], "]"}], "-", 
             RowBox[{
              FractionBox["1", "3"], "\[Delta]ij", " ", 
              RowBox[{"Laplacian", "[", 
               RowBox[{
                RowBox[{"\[Sigma]", "[", 
                 RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}]}], ")"}],
            "//", "ApproxFullSimplify"}], "//", "FullSimplify"}], ")"}], "/", 
        
        RowBox[{"k", "^", "2"}]}]}], "/.", 
      RowBox[{
       SuperscriptBox["kx", "2"], "\[Rule]", 
       RowBox[{
        RowBox[{"k", "^", "2"}], "-", 
        SuperscriptBox["ky", "2"], "-", 
        SuperscriptBox["kz", "2"]}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalSigma]mUd", "=", 
     RowBox[{"PadLeft", "[", 
      RowBox[{"\[CapitalSigma]mij", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4"}], "}"}]}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQfcyjT4H9+GvHlSvFVUD0xIgaTRBtvPabFoi223Tc
AERPe7XTEESv+nVyMYhWMZy3FETvWjUxhANIr2//AKb/esvEgeglP5/Eg+gb
EmpZIPoRz9t8EO1Q19oJoss+c3WBaE2Nkqkguu3/zGkg+oqUxFwQ/ea3Bpie
IvZ/OYieqb17FYjue979D2wubxcDJ5Befnp2I4iukrkFpt8kbTo24+1rRz6R
TedAdNkmUYaZQDpk80NGEP3zW8YXEJ3YIvEdRGu/0N7/xP2NY9z6+gMgesLF
5ilPgbSBjcBUEP1Kc9VBEC0fJnkIRD+0sLgHos2yne+DaADC8qsU
  
  "],ExpressionUUID->"2aea9703-4dda-43af-8aa6-ff81d07b0fd2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c"}], "}"}], "\[Cross]", 
  RowBox[{"{", 
   RowBox[{"a1", ",", "b1", ",", "c1"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.8225535144500713`*^9, 
  3.8225535514386635`*^9}},ExpressionUUID->"5218cea2-30ea-4d67-917f-\
abaefd08e957"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "b1"}], " ", "c"}], "+", 
    RowBox[{"b", " ", "c1"}]}], ",", 
   RowBox[{
    RowBox[{"a1", " ", "c"}], "-", 
    RowBox[{"a", " ", "c1"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a1"}], " ", "b"}], "+", 
    RowBox[{"a", " ", "b1"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8225535323002977`*^9, 
  3.8225535528780746`*^9}},ExpressionUUID->"ca9502c2-ee0d-422d-8235-\
599e6b0a09dd"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "energy", " ", "momentum", " ", "tensor"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"TmUd", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Rho]", "[", "\[Tau]", "]"}], "+", 
              RowBox[{"\[Epsilon]", " ", 
               RowBox[{"\[Delta]\[Rho]", "[", 
                RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
              "+", 
              RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
              RowBox[{"\[Epsilon]", " ", 
               RowBox[{"\[Delta]P", "[", 
                RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
             ")"}], 
            RowBox[{"uU", "[", 
             RowBox[{"[", "m", "]"}], "]"}], 
            RowBox[{"ud", "[", 
             RowBox[{"[", "n", "]"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
              RowBox[{"\[Epsilon]", " ", 
               RowBox[{"\[Delta]P", "[", 
                RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
             ")"}], 
            RowBox[{"\[Delta]Ud", "[", 
             RowBox[{"[", 
              RowBox[{"m", ",", "n"}], "]"}], "]"}]}], "+", 
           RowBox[{"\[Epsilon]", " ", 
            RowBox[{"\[CapitalSigma]mUd", "[", 
             RowBox[{"[", 
              RowBox[{"m", ",", "n"}], "]"}], "]"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"m", ",", "1", ",", "4"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "4"}], "}"}]}], "]"}], "//", 
        "FullSimplify"}], "//", "ApproxFullSimplify"}], "//", 
      "ApproxFullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Tmdd", "=", 
     RowBox[{"Lower", "[", 
      RowBox[{"TmUd", ",", 
       RowBox[{"{", "1", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"kv", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"kx", ",", "ky", ",", "kz"}], "}"}], "/", "k"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7282105220306444`*^9, 3.728210528279722*^9}, {
   3.72821056978397*^9, 3.7282105842135286`*^9}, {3.728215748742786*^9, 
   3.7282157739265547`*^9}, {3.7282277238705873`*^9, 3.7282277344965115`*^9}, 
   3.732941446289823*^9, {3.74844786996275*^9, 3.748447884583949*^9}, 
   3.7484479455572577`*^9, {3.7484480134886007`*^9, 3.748448025993548*^9}, {
   3.79578932496313*^9, 3.7957893342433634`*^9}, {3.795791220108513*^9, 
   3.7957912289061055`*^9}, {3.7957913801440363`*^9, 3.795791387276099*^9}, {
   3.7960444966184177`*^9, 
   3.7960445088488655`*^9}},ExpressionUUID->"082be1fd-fd73-4dca-b3af-\
aadfc386c2f3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TmUd", "//", "FullSimplify"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.7958498053726563`*^9, 
  3.7958498164757347`*^9}},ExpressionUUID->"96fde3d8-3a54-4efa-8d82-\
0106ea6fc916"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Epsilon]"}], " ", 
        RowBox[{"\[Delta]\[Rho]", "[", 
         RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
       RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], 
      RowBox[{"\[Epsilon]", " ", 
       RowBox[{"ux", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
         RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}]}], 
      RowBox[{"\[Epsilon]", " ", 
       RowBox[{"uy", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
         RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}]}], 
      RowBox[{"\[Epsilon]", " ", 
       RowBox[{"uz", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
         RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}]}]},
     {
      RowBox[{
       RowBox[{"-", "\[Epsilon]"}], " ", 
       RowBox[{"ux", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
         RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"\[Delta]P", "[", 
         RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["k", "2"]}], "-", 
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ky", "2"], "+", 
              SuperscriptBox["kz", "2"]}], ")"}]}]}], ")"}], " ", 
         "\[Epsilon]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
           RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["k", "2"]}]]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", "kx", " ", "ky", " ", "\[Epsilon]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
           RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["k", "2"]}]]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", "kx", " ", "kz", " ", "\[Epsilon]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
           RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["k", "2"]}]]}]},
     {
      RowBox[{
       RowBox[{"-", "\[Epsilon]"}], " ", 
       RowBox[{"uy", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
         RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", "kx", " ", "ky", " ", "\[Epsilon]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
           RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["k", "2"]}]]}], 
      RowBox[{
       RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"\[Delta]P", "[", 
         RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["k", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["ky", "2"]}]}], ")"}], " ", "\[Epsilon]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
           RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["k", "2"]}]]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", "ky", " ", "kz", " ", "\[Epsilon]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
           RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["k", "2"]}]]}]},
     {
      RowBox[{
       RowBox[{"-", "\[Epsilon]"}], " ", 
       RowBox[{"uz", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
         RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", "kx", " ", "kz", " ", "\[Epsilon]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
           RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["k", "2"]}]]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", "ky", " ", "kz", " ", "\[Epsilon]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
           RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["k", "2"]}]]}], 
      RowBox[{
       RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"\[Delta]P", "[", 
         RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["k", "2"], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["kz", "2"]}]}], ")"}], " ", "\[Epsilon]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
           RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["k", "2"]}]]}]}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.7960445165291243`*^9, 3.7968217401170473`*^9, 
  3.8208407546689663`*^9, 3.8209285785007524`*^9, 
  3.8214413513483615`*^9},ExpressionUUID->"4cb41bfd-ec94-4649-91ef-\
8bdff33874a8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TmUd", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TmUd", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "2"}], "]"}], "]"}], "//", 
  "Factor"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TmUd", "[", 
   RowBox[{"[", 
    RowBox[{"2", ",", "1"}], "]"}], "]"}], "//", 
  "Factor"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "3"], 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{"TmUd", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "i"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2", ",", "4"}], "}"}]}], "]"}]}], "/.", 
    RowBox[{
     SuperscriptBox["kx", "2"], "\[Rule]", 
     RowBox[{
      RowBox[{"k", "^", "2"}], "-", 
      SuperscriptBox["ky", "2"], "-", 
      SuperscriptBox["kz", "2"]}]}]}], "//", "ApproxFullSimplify"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"TmUd", "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "3"}], "]"}], "]"}], "/.", 
   RowBox[{
    SuperscriptBox["kx", "2"], "\[Rule]", 
    RowBox[{
     RowBox[{"k", "^", "2"}], "-", 
     SuperscriptBox["ky", "2"], "-", 
     SuperscriptBox["kz", "2"]}]}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalSigma]mij", "-", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"TmUd", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "j"}], "]"}], "]"}], "-", 
      RowBox[{
       FractionBox[
        RowBox[{"\[Delta]Ud", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "3"], 
       RowBox[{"Tr", "[", 
        RowBox[{"TmUd", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"2", ";;", "4"}], ",", 
           RowBox[{"2", ";;", "4"}]}], "]"}], "]"}], "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2", ",", "4"}], "}"}]}], "]"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"kv", "[", 
             RowBox[{"[", "i", "]"}], "]"}], 
            RowBox[{"kv", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}], "-", 
           RowBox[{
            FractionBox["1", "3"], 
            RowBox[{"\[Delta]ij", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "j"}], "]"}], "]"}]}]}], ")"}], 
         RowBox[{"\[CapitalSigma]mij", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}]}], "//", 
     "FullSimplify"}], ")"}], "/.", 
   RowBox[{
    SuperscriptBox["kx", "2"], "\[Rule]", 
    RowBox[{
     RowBox[{"k", "^", "2"}], "-", 
     SuperscriptBox["ky", "2"], "-", 
     SuperscriptBox["kz", "2"]}]}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalSigma]mij", "//", "Tr"}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.7282157260577545`*^9, 3.7282157348151407`*^9}, {
  3.72821599042015*^9, 3.728216017926318*^9}, {3.7282327180497165`*^9, 
  3.728232786537921*^9}, {3.7282329038982887`*^9, 3.728232920124566*^9}, {
  3.728233042404564*^9, 3.7282331003867397`*^9}, {3.728280722845909*^9, 
  3.7282807283308706`*^9}, {3.7484478896171503`*^9, 
  3.748447912429358*^9}},ExpressionUUID->"d15753e3-49b9-4335-baab-\
cc07dc710d99"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "\[Epsilon]"}], " ", 
   RowBox[{"\[Delta]\[Rho]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}]], "Output",
 CellChangeTimes->{3.796044529004792*^9, 3.7968217427435827`*^9, 
  3.8208407547142644`*^9, 3.8209285805616198`*^9, 
  3.8214413578057575`*^9},ExpressionUUID->"a66be7fe-ac8b-4c21-9790-\
412fbefe2417"],

Cell[BoxData[
 RowBox[{"\[Epsilon]", " ", 
  RowBox[{"ux", "[", 
   RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
    RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.796044529004792*^9, 3.7968217427435827`*^9, 
  3.8208407547142644`*^9, 3.8209285805616198`*^9, 
  3.821441357812738*^9},ExpressionUUID->"6b7bcf9d-0a6d-44c2-b569-\
d981a24179fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "\[Epsilon]"}], " ", 
  RowBox[{"ux", "[", 
   RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
    RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.796044529004792*^9, 3.7968217427435827`*^9, 
  3.8208407547142644`*^9, 3.8209285805616198`*^9, 
  3.8214413578197217`*^9},ExpressionUUID->"c50571b6-4690-41d5-9b78-\
997b05703a34"],

Cell[BoxData[
 RowBox[{
  RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
  RowBox[{"\[Epsilon]", " ", 
   RowBox[{"\[Delta]P", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.796044529004792*^9, 3.7968217427435827`*^9, 
  3.8208407547142644`*^9, 3.8209285805616198`*^9, 
  3.821441357824708*^9},ExpressionUUID->"cc4153c9-4481-4472-82a9-\
f58e0fc5a9c1"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"3", " ", "kx", " ", "ky", " ", "\[Epsilon]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
      RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
    RowBox[{"\[Sigma]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   RowBox[{"2", " ", 
    SuperscriptBox["k", "2"]}]]}]], "Output",
 CellChangeTimes->{3.796044529004792*^9, 3.7968217427435827`*^9, 
  3.8208407547142644`*^9, 3.8209285805616198`*^9, 3.8214413578296947`*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"287c9fab-13b6-40fb-acee-02c4ac9673a4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["k", "2"]}], "-", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["ky", "2"], "+", 
            SuperscriptBox["kz", "2"]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
         RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
       RowBox[{"\[Sigma]", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["k", "2"]}]], ",", 
     FractionBox[
      RowBox[{"3", " ", "kx", " ", "ky", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
         RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
       RowBox[{"\[Sigma]", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["k", "2"]}]], ",", 
     FractionBox[
      RowBox[{"3", " ", "kx", " ", "kz", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
         RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
       RowBox[{"\[Sigma]", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["k", "2"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "kx", " ", "ky", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
         RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
       RowBox[{"\[Sigma]", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["k", "2"]}]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["k", "2"], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["ky", "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
          RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
        RowBox[{"\[Sigma]", "[", 
         RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["k", "2"]}]]}], ",", 
     FractionBox[
      RowBox[{"3", " ", "ky", " ", "kz", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
         RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
       RowBox[{"\[Sigma]", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["k", "2"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "kx", " ", "kz", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
         RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
       RowBox[{"\[Sigma]", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["k", "2"]}]], ",", 
     FractionBox[
      RowBox[{"3", " ", "ky", " ", "kz", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Epsilon]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
         RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
       RowBox[{"\[Sigma]", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["k", "2"]}]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["k", "2"], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["kz", "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Epsilon]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
          RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
        RowBox[{"\[Sigma]", "[", 
         RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["k", "2"]}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.796044529004792*^9, 3.7968217427435827`*^9, 
  3.8208407547142644`*^9, 3.8209285805616198`*^9, 3.821441357910476*^9},
 CellLabel->"Out[52]=",ExpressionUUID->"487a9c3b-28e3-464d-8c23-bf477cd17407"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
    RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
  RowBox[{"\[Sigma]", "[", 
   RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]], "Output",
 CellChangeTimes->{3.796044529004792*^9, 3.7968217427435827`*^9, 
  3.8208407547142644`*^9, 3.8209285805616198`*^9, 3.821441357990264*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"46ceaed9-17ff-400b-9f3a-f614cf92956e"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.796044529004792*^9, 3.7968217427435827`*^9, 
  3.8208407547142644`*^9, 3.8209285805616198`*^9, 3.8214413579932547`*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"5f1dc399-1eb6-4e69-86ed-e023122256d1"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "Einstein", " ", "equations"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FEdd", "[", 
    RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Lower", "[", 
      RowBox[{"EUd", ",", 
       RowBox[{"{", "1", "}"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"m", ",", "n"}], "]"}], "]"}], "-", 
    RowBox[{"8", "\[Pi]", " ", "G", " ", 
     RowBox[{"Tmdd", "[", 
      RowBox[{"[", 
       RowBox[{"m", ",", "n"}], "]"}], "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.7484477122231855`*^9, 3.7484477584016356`*^9}, 
   3.748447969054311*^9, {3.748448032535862*^9, 3.7484480479164977`*^9}, {
   3.7484486113916464`*^9, 3.748448616027882*^9}, 3.7957893573337817`*^9, {
   3.795849851594738*^9, 3.7958498587061787`*^9}, {3.7958523891060467`*^9, 
   3.795852431475956*^9}, {3.795852468951231*^9, 3.795852472630163*^9}, {
   3.796044544621989*^9, 3.7960445449525647`*^9}, 3.7960445829764366`*^9},
 CellLabel->"In[46]:=",ExpressionUUID->"5af9a251-7701-440b-906f-e0e040bc2ada"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"--", 
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", " ", "The"}]}]}]}], " ", "00", " ", "and", " ", "ij", " ", 
   RowBox[{"parts", " ", "--"}], 
   RowBox[{"--", 
    RowBox[{"--", "-"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7281279063638325`*^9, 3.7281279139468803`*^9}, {
  3.7958499759312305`*^9, 
  3.795849978131695*^9}},ExpressionUUID->"0b9dc60a-9782-416e-9f3d-\
aac524c674d7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Eq00", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"FEdd", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "/.", "a2H"}], "//", 
   "ApproxFullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"Eqij", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"FEdd", "[", 
       RowBox[{"2", ",", "3"}], "]"}], 
      RowBox[{"kx", " ", "ky"}]], "/.", "a2H"}], "//", "ApproxFullSimplify"}],
    "//", "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.7271005883290863`*^9, 3.727100591724481*^9}, {
  3.748448060716078*^9, 3.748448093681512*^9}, {3.7957893758322954`*^9, 
  3.795789376432171*^9}, {3.7958498783931274`*^9, 3.7958498790848465`*^9}, {
  3.796044636400628*^9, 3.7960446373758173`*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"8b77b810-7877-489e-bc40-ec720256be58"],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "\[Tau]", "]"}], "2"]}], "-", 
  RowBox[{"8", " ", "G", " ", "\[Pi]", " ", "\[Epsilon]", " ", 
   SuperscriptBox[
    RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
   RowBox[{"\[Delta]\[Rho]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
   RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["k", "2"], " ", "\[Epsilon]", " ", 
   RowBox[{"\[CapitalPhi]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"16", " ", "G", " ", "\[Pi]", " ", "\[Epsilon]", " ", 
   SuperscriptBox[
    RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
   RowBox[{"\[Rho]", "[", "\[Tau]", "]"}], " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"6", " ", "\[Epsilon]", " ", 
   RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPhi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7960446230015173`*^9, 3.7960446377557583`*^9}, 
   3.796821747838891*^9, 3.820840755064026*^9, 3.8209285845566587`*^9},
 CellLabel->"Out[47]=",ExpressionUUID->"514f6daf-5162-42d6-948b-a4900f401275"],

Cell[BoxData[
 RowBox[{"\[Epsilon]", " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     RowBox[{"12", " ", "G", " ", "\[Pi]", " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
        RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}], " ", 
      RowBox[{"\[Sigma]", "[", 
       RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     SuperscriptBox["k", "2"]], "-", 
    RowBox[{"\[CapitalPhi]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "+", 
    RowBox[{"\[CapitalPsi]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.7960446230015173`*^9, 3.7960446377557583`*^9}, 
   3.796821747838891*^9, 3.820840755064026*^9, 3.820928584625562*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"18add396-db3f-4626-b18f-7fcaddcf0cb6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", " ", "The"}]}]}]}], " ", "Friedmann", " ", 
    RowBox[{"equation", " ", "--"}], 
    RowBox[{"--", 
     RowBox[{"--", "-"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Eq00", "/.", "zeroorder"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.728128037275298*^9, 3.7281280395468645`*^9}, {
  3.79584994613253*^9, 3.7958499945285807`*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"ccdfab94-771f-4208-8ae8-c5b6fe66a4b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "\[Tau]", "]"}], "2"]}], "-", 
  RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
   RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}]}]], "Output",
 CellChangeTimes->{3.796044644104862*^9, 3.7968217504477396`*^9, 
  3.820840755184172*^9, 3.820928586533442*^9},
 CellLabel->"Out[49]=",ExpressionUUID->"ae24f4e9-44a3-4f45-b0d0-16680a2f2072"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Anisotropic", " ", "stress", " ", 
    RowBox[{"equation", "!"}], " ", 
    RowBox[{"It", "'"}], "s", " ", "just", " ", "the", " ", "difference", " ",
     "of", " ", "the", " ", "potentials"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", " ", 
     RowBox[{
      RowBox[{"Eqij", "\[Equal]", "0"}], ",", 
      RowBox[{"\[Sigma]", "[", 
       RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7958499008647375`*^9, 3.7958499704414177`*^9}, 
   3.8209285941411457`*^9},ExpressionUUID->"21908ccf-04c7-4184-951b-\
234bbc23bca5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Sigma]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "-", 
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}]}], 
    RowBox[{"12", " ", "G", " ", "\[Pi]", " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"P", "[", "\[Tau]", "]"}], "+", 
       RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}], ")"}]}]]}], "}"}]], "Output",\

 CellChangeTimes->{3.7960446474384775`*^9, 3.7968217521152596`*^9, 
  3.8208407552345204`*^9, 3.820928589120178*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"2a77e9f7-cdc2-4a36-9e14-95b456248515"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", " ", "The"}]}]}]}], " ", "continuity", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"equations", " ", "--"}], "--"}], "--"}], "--"}]}], "-"}], " ",
   "*)"}]], "Input",
 CellChangeTimes->{
  3.728128064348237*^9, 3.7282399499899187`*^9, {3.7484488576593175`*^9, 
   3.748448864323157*^9}, {3.7484511672777033`*^9, 
   3.748451182923294*^9}},ExpressionUUID->"9ccd0ecd-5038-4f0e-b24b-\
a422b59e5cea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"energcond", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"covDiv", "[", 
      RowBox[{"TmUd", ",", 
       RowBox[{"{", "1", "}"}]}], "]"}], "//", "Expand"}], "//", 
    "ApproxFullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.7484486578165584`*^9, {3.7957907643935986`*^9, 3.795790764895555*^9}},
 CellLabel->"In[51]:=",ExpressionUUID->"b80cf608-8aff-48db-8740-7652103ab84c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cons0", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"energcond", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "/.", "zeroorder"}], ")"}], 
         "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"\[Rho]", "'"}], "[", "\[Tau]", "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "/.", 
     RowBox[{
      RowBox[{"P", "[", "\[Tau]", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"w", "[", "\[Tau]", "]"}], " ", 
       RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}]}]}], "/.", "a2H"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.72823333326803*^9, 3.7282333736032867`*^9}, {
  3.748448668138236*^9, 3.7484486757671485`*^9}, {3.795790767410887*^9, 
  3.7957907865645647`*^9}, {3.7957914087635603`*^9, 3.7957914300541553`*^9}},
 CellLabel->"In[52]:=",ExpressionUUID->"5a87d6ed-5e14-43df-907b-059da88d964c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Rho]", "\[Prime]",
     MultilineFunction->None], "[", "\[Tau]", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"w", "[", "\[Tau]", "]"}]}], ")"}], " ", 
    RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7960446673541555`*^9, 3.7968217574618635`*^9, 
  3.8208407567041283`*^9, 3.82092860175202*^9},
 CellLabel->"Out[52]=",ExpressionUUID->"3ab09f6e-94b9-4281-a8b6-ecb86a47b845"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"en10", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"energcond", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"energcond", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "/.", "zeroorder"}], ")"}]}], "/.", 
    "a2H"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"en1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]", "'"}], "[", "\[Tau]", "]"}], "->", 
          RowBox[{"D", "[", 
           RowBox[{
            FractionBox[
             RowBox[{"\[Delta]\[Rho]", "[", 
              RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], 
             RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]], ",", "\[Tau]"}], 
           "]"}]}], "/.", "cons0"}], "/.", 
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{"en10", "\[Equal]", "0"}], ",", 
           RowBox[{
            SuperscriptBox["\[Delta]\[Rho]", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], 
         "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "/.", "a2H"}], "/.", 
      RowBox[{
       RowBox[{"P", "[", "\[Tau]", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"w", "[", "\[Tau]", "]"}], " ", 
        RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}]}]}], "/.", 
     RowBox[{
      RowBox[{"\[Delta]P", "[", 
       RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"cs2", "[", "\[Tau]", "]"}], 
       RowBox[{"\[Delta]\[Rho]", "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], "/.", 
    RowBox[{
     RowBox[{"\[Delta]\[Rho]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "->", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "*", 
      RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}]}]}], "//", 
   "Expand"}]}]}], "Input",
 CellChangeTimes->{{3.72823133576729*^9, 3.7282313508437486`*^9}, {
   3.7282313921395187`*^9, 3.728231399579141*^9}, {3.7282315176878395`*^9, 
   3.7282315512694097`*^9}, {3.7282315973091087`*^9, 3.728231653765546*^9}, 
   3.728231692653243*^9, {3.7282332407501764`*^9, 3.7282332476861534`*^9}, {
   3.728233380790492*^9, 3.728233385274924*^9}, {3.7484486893098097`*^9, 
   3.7484487105403423`*^9}, {3.7484502902639656`*^9, 
   3.7484502910988207`*^9}, {3.7484503299137435`*^9, 3.748450363539217*^9}, {
   3.7484509030201435`*^9, 3.748450903283244*^9}, {3.7484510114532037`*^9, 
   3.7484510120066547`*^9}, {3.7484510884971995`*^9, 3.748451132769088*^9}, {
   3.7957908034679837`*^9, 3.7957908359762406`*^9}, {3.795791456041782*^9, 
   3.795791482076646*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"db701f15-c07f-428f-b245-053d3395496a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["\[Delta]", "\[Prime]",
    MultilineFunction->None], "[", "\[Tau]", "]"}], "\[Rule]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    RowBox[{"cs2", "[", "\[Tau]", "]"}], " ", 
    RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
    RowBox[{"w", "[", "\[Tau]", "]"}], " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
   RowBox[{"\[Theta]", "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "-", 
   RowBox[{
    RowBox[{"w", "[", "\[Tau]", "]"}], " ", 
    RowBox[{"\[Theta]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{
     SuperscriptBox["\[CapitalPhi]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{"w", "[", "\[Tau]", "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[CapitalPhi]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}]], "Output",\

 CellChangeTimes->{3.796044670373355*^9, 3.7968217597494698`*^9, 
  3.8208407567743053`*^9, 
  3.8209286032107177`*^9},ExpressionUUID->"fe9f2bca-ad2f-4e02-8596-\
e71ad9a02cc5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"en2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"FullSimplify", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  FractionBox["1", 
                   RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]], 
                  RowBox[{"Div", "[", 
                   RowBox[{
                    RowBox[{"energcond", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ";;", "4"}], "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}], "/.",
                  "cons0"}], "/.", "a2H"}], "/.", 
               RowBox[{
                SuperscriptBox["kx", "2"], "\[Rule]", 
                RowBox[{
                 RowBox[{"k", "^", "2"}], "-", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["ky", "2"], "+", 
                   SuperscriptBox["kz", "2"]}], ")"}]}]}]}], "//", "Expand"}],
              "//", "FullSimplify"}], "//", "ApproxFullSimplify"}], "]"}], "/.", 
          RowBox[{
           RowBox[{"P", "[", "\[Tau]", "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"w", "[", "\[Tau]", "]"}], " ", 
            RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}]}]}], "/.", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"P", "[", "\[Tau]", "]"}], "\[Rule]", 
            RowBox[{
             RowBox[{"w", "[", "\[Tau]", "]"}], " ", 
             RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}]}], ",", "\[Tau]"}], 
          "]"}]}], "/.", 
        RowBox[{
         RowBox[{"\[Delta]P", "[", 
          RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
         
         RowBox[{
          RowBox[{"cs2", "[", "\[Tau]", "]"}], 
          RowBox[{"\[Delta]\[Rho]", "[", 
           RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], "/.",
        "cons0"}], "/.", "a2H"}], "//", "FullSimplify"}], "//", 
    "ApproxFullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"en2", "\[Equal]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["\[Theta]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "/.", 
   
   RowBox[{
    RowBox[{"\[Delta]\[Rho]", "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "->", 
    RowBox[{
     RowBox[{"\[Delta]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "*", 
     RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}]}]}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.748448738847443*^9, 3.748448771422245*^9}, {
  3.7484504047129393`*^9, 3.748450512121004*^9}, {3.7484505538839693`*^9, 
  3.748450664501816*^9}, {3.7484507037962103`*^9, 3.7484507411906157`*^9}, {
  3.7484507990595417`*^9, 3.7484508351490135`*^9}, {3.7484508950548325`*^9, 
  3.7484508953083677`*^9}, {3.7484509403623676`*^9, 3.7484509420490603`*^9}, {
  3.795790853865981*^9, 3.7957908682204533`*^9}, {3.795790906843994*^9, 
  3.7957909493176284`*^9}, {3.7957914917180405`*^9, 
  3.795791508103465*^9}},ExpressionUUID->"639df8da-905a-4ef1-96f8-\
cd0dd6224960"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Theta]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"1", "+", 
       RowBox[{"w", "[", "\[Tau]", "]"}]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"cs2", "[", "\[Tau]", "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"w", "[", "\[Tau]", "]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"w", "[", "\[Tau]", "]"}]}]}], ")"}], " ", 
           RowBox[{"\[Theta]", "[", 
            RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["k", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"\[Sigma]", "[", 
               RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
             RowBox[{"\[CapitalPsi]", "[", 
              RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
            ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"\[Theta]", "[", 
         RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["w", "\[Prime]",
          MultilineFunction->None], "[", "\[Tau]", "]"}]}]}], ")"}]}]}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{3.7960446767353144`*^9, 3.7968217656896095`*^9, 
  3.8208407586189833`*^9, 
  3.82092860675961*^9},ExpressionUUID->"849a2fa1-2533-4372-b2a1-5b41292c7ba7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "This", " ", "redefinition", " ", "of", " ", "the", " ", "velocity", " ", 
     
     RowBox[{"doesn", "'"}], "t", " ", "suffer", " ", "from", " ", 
     "singularities", " ", "when", " ", "w"}], "\[Rule]", 
    RowBox[{"-", "1"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "\[Theta]", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Theta]", "[", 
     RowBox[{"\[Tau]_", ",", "x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
    FractionBox[
     RowBox[{"V", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], 
     RowBox[{"1", "+", 
      RowBox[{"w", "[", "\[Tau]", "]"}]}]]}]}]}]], "Input",
 CellChangeTimes->{{3.795790882137324*^9, 3.7957908851139803`*^9}, {
  3.7957915153290963`*^9, 3.79579151626127*^9}, {3.79585003384195*^9, 
  3.795850061912711*^9}},ExpressionUUID->"82a248f0-6b1a-496b-a1c5-\
9c6c4987956b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"en2", "\[Equal]", "0"}], ",", 
       RowBox[{
        SuperscriptBox["V", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/.", 
    RowBox[{
     RowBox[{"\[Delta]\[Rho]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "->", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "*", 
      RowBox[{"\[Rho]", "[", "\[Tau]", "]"}]}]}]}], "//", "FullSimplify"}], "//",
   "Expand"}]], "Input",
 CellChangeTimes->{{3.728231876134303*^9, 3.7282318961833067`*^9}, {
  3.728280766673312*^9, 3.728280784504643*^9}, {3.7484506735125136`*^9, 
  3.74845068461707*^9}, {3.7484509599177313`*^9, 3.7484509719935627`*^9}, {
  3.7484510478632927`*^9, 3.7484510761241283`*^9}, {3.7957908864554234`*^9, 
  3.7957909021811705`*^9}, {3.7957915178456564`*^9, 
  3.7957915215239153`*^9}},ExpressionUUID->"63583de1-f203-4683-b615-\
bb4aab4df8ef"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["V", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"H", "[", "\[Tau]", "]"}]}], " ", 
     RowBox[{"V", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
     RowBox[{"V", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"w", "[", "\[Tau]", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"cs2", "[", "\[Tau]", "]"}], " ", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"\[Sigma]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"w", "[", "\[Tau]", "]"}], " ", 
     RowBox[{"\[Sigma]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"w", "[", "\[Tau]", "]"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"\[Tau]", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7960446866967077`*^9, 3.7968217695107384`*^9, 
  3.820840758794004*^9},ExpressionUUID->"1eec2078-4974-489c-ab6d-\
0c0b90b4701b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.728128098322069*^9, 
  3.7281281014358377`*^9}},ExpressionUUID->"820cd1d3-dea6-48b8-a6c9-\
6566bd0f6caf"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.745904999628686*^9, 
  3.745905001618862*^9}},ExpressionUUID->"69d7e86e-76a0-4030-88e2-\
29d2057fca2f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"--", 
   RowBox[{"--", 
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"-", 
          RowBox[{"--", 
           RowBox[{"--", 
            RowBox[{"--", 
             RowBox[{"--", 
              RowBox[{"--", 
               RowBox[{"--", 
                RowBox[{"--", 
                 RowBox[{"--", 
                  RowBox[{"--", 
                   RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{"--", 
                    RowBox[{
                    "--", "-"}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}\
]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7282340987660418`*^9, 
  3.728234100767259*^9}},ExpressionUUID->"626ace68-fd4b-40c1-9fe0-\
429900aa2e5b"],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7275177697880125`*^9, 
  3.7275177743514357`*^9}},ExpressionUUID->"64af0b94-a472-445b-8855-\
c20200ec1c45"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"end", " ", "examples"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8209049937831945`*^9, 
  3.820904999480379*^9}},ExpressionUUID->"5b74c4d6-37de-4227-b4b9-\
b25a5d28c258"]
},
CellGrouping->Manual,
WindowSize->{1059, 771},
WindowMargins->{{-6, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
Magnification:>1.4 Inherited,
FrontEndVersion->"11.2 for Microsoft Windows (64-bit) (September 10, 2017)",
StyleDefinitions->"Default.nb",
MacintoshSystemPageSetup -> \
"0040001804P000000aP2I0000003609To`83609T0@00001804P000000aP2I001\n\
0@00I00100000@0200000BL?00400000000000000000051`I6H0I00000000000\n\
00000000000000000000000000000000"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 177, 4, 40, "Input",ExpressionUUID->"46e16825-9137-474e-8a90-926dc5d4657e"],
Cell[CellGroupData[{
Cell[760, 28, 489, 16, 185, "Text",ExpressionUUID->"93712e9f-463d-418a-aa7e-ede3df646b0f"],
Cell[1252, 46, 201, 5, 446, "Text",ExpressionUUID->"5d38bb7e-caba-4a3a-819d-4ab9175b2d11"],
Cell[1456, 53, 1326, 47, 2328, "Text",ExpressionUUID->"c55db92e-c919-43f8-8a2b-3ac0cca1e381"]
}, Closed]],
Cell[2797, 103, 966, 32, 55, "Text",ExpressionUUID->"873d17d5-d20d-454f-9abb-c61f78b0b6bd"],
Cell[CellGroupData[{
Cell[3788, 139, 204, 5, 85, "Section",ExpressionUUID->"173c2924-6d97-4a8d-a555-e9aae66fa09a"],
Cell[CellGroupData[{
Cell[4017, 148, 135, 2, 67, "Subsection",ExpressionUUID->"2b324f19-b4f9-480b-a233-3efa58047f54"],
Cell[4155, 152, 925, 23, 340, "Text",ExpressionUUID->"4c8972a6-079f-4079-9879-4b2f18827fb8"],
Cell[5083, 177, 866, 23, 294, "Text",ExpressionUUID->"69fb5a1d-8a3a-460d-9255-7d430e99623f"],
Cell[5952, 202, 1823, 61, 131, "Text",ExpressionUUID->"2c670a48-25e0-4fd7-9369-054957ac0082"]
}, Closed]],
Cell[CellGroupData[{
Cell[7812, 268, 153, 2, 43, "Subsection",ExpressionUUID->"6caee4e7-dbdf-4e38-bac3-2e8699d611ab"],
Cell[7968, 272, 1775, 56, 519, "Text",ExpressionUUID->"5f209b81-a7b6-4560-967c-b30ccadb1815"],
Cell[CellGroupData[{
Cell[9768, 332, 979, 32, 294, "Text",ExpressionUUID->"68bf135f-0e63-4ca9-9f3a-6c16c774fa8f"],
Cell[10750, 366, 322, 9, 509, "Text",ExpressionUUID->"18e13e01-555f-4c6e-91cb-19935052484f"],
Cell[11075, 377, 328, 9, 509, "Text",ExpressionUUID->"47be14e5-260f-41b5-bd36-4ab48f10f48d"],
Cell[11406, 388, 375, 10, 509, "Text",ExpressionUUID->"9f05d15d-1a7e-4ab6-b139-6ec1544670f6"],
Cell[11784, 400, 360, 11, 509, "Text",ExpressionUUID->"3780f30b-e153-437d-89b3-3ed073daf029"],
Cell[12147, 413, 379, 11, 509, "Text",ExpressionUUID->"1b41e437-9be5-455f-bfe6-7014cd463f88"],
Cell[12529, 426, 596, 18, 509, "Text",ExpressionUUID->"9972d9ed-e4c5-4de4-9df0-cbaf8f52e1bf"],
Cell[13128, 446, 730, 25, 509, "Text",ExpressionUUID->"eedf1b2b-5ac2-4884-b9c3-b5aa3ec0ccab"],
Cell[13861, 473, 508, 16, 509, "Text",ExpressionUUID->"2bb2efa8-a043-4f9c-8043-0e2250e5bea7"],
Cell[14372, 491, 330, 9, 509, "Text",ExpressionUUID->"ac57db93-a796-4e9c-8bca-ae7433ded89f"]
}, Closed]],
Cell[14717, 503, 1256, 35, 1790, "Text",ExpressionUUID->"e5b3baba-41da-4518-bcf3-2096c7e90d85"],
Cell[15976, 540, 1564, 42, 2893, "Text",ExpressionUUID->"0d551833-618c-413f-b08d-64e5e8b7137e"],
Cell[CellGroupData[{
Cell[17565, 586, 165, 2, 579, "Subsubsection",ExpressionUUID->"0e534907-8848-4087-bfa8-a7b970096715"],
Cell[17733, 590, 926, 24, 1188, "Text",ExpressionUUID->"a59513f9-7c51-4b43-a546-e76fce43ae08"],
Cell[18662, 616, 632, 20, 865, "Text",ExpressionUUID->"3e4b7901-2c3d-405e-ae78-271120c697a7"],
Cell[19297, 638, 511, 21, 522, "Text",ExpressionUUID->"719c43b6-1ad9-4a4f-845d-c6f829573e51"],
Cell[19811, 661, 733, 23, 865, "Text",ExpressionUUID->"9a81196d-fdbf-46dd-8263-bec2986157c0"],
Cell[20547, 686, 659, 21, 509, "Text",ExpressionUUID->"1d378a62-742f-4d30-b712-622170e94e08"],
Cell[21209, 709, 310, 9, 509, "Text",ExpressionUUID->"932ceba4-13ce-4423-99df-dabfee9f8d76"],
Cell[21522, 720, 862, 27, 509, "Text",ExpressionUUID->"56e76f6b-150d-4644-bc65-3d2eb67e69eb"],
Cell[22387, 749, 1755, 59, 1867, "Text",ExpressionUUID->"feb250c6-0dc5-4864-af65-c9721ed52b1a"]
}, Open  ]],
Cell[24157, 811, 451, 11, 2129, "Text",ExpressionUUID->"4c2f5789-22bd-4eeb-b883-c6b8022c1d81"]
}, Closed]],
Cell[CellGroupData[{
Cell[24645, 827, 171, 2, 43, "Subsection",ExpressionUUID->"68d12292-51e5-4176-a124-fe361bc980eb"],
Cell[24819, 831, 336, 12, 1183, "Text",ExpressionUUID->"cb46d9f3-1b39-4412-80a0-4da3d42a81f1"],
Cell[25158, 845, 295, 9, 712, "Text",ExpressionUUID->"3f1b374e-6f88-4b08-92d5-d6fb9cb9e33b"],
Cell[25456, 856, 465, 15, 1183, "Text",ExpressionUUID->"39063825-66a8-4f7c-b89d-e35dce99956e"],
Cell[25924, 873, 377, 9, 1183, "Text",ExpressionUUID->"0bc7bd6b-01dd-4b4d-8032-8692f1a93dad"],
Cell[26304, 884, 630, 21, 1691, "Text",ExpressionUUID->"bc68b52f-2e6d-44eb-a1c7-8e558ad6ad0a"],
Cell[26937, 907, 630, 21, 1691, "Text",ExpressionUUID->"b54ebef1-ad6d-4874-ab4c-1bea8720758d"],
Cell[27570, 930, 1051, 34, 1656, "Text",ExpressionUUID->"071cc2a5-0ff5-4ded-8469-db6a193a7be3"],
Cell[28624, 966, 732, 27, 2129, "Text",ExpressionUUID->"eb136a01-5be6-478e-9ec4-0fb532bf3ac5"],
Cell[29359, 995, 474, 15, 1183, "Text",ExpressionUUID->"ead68687-1dca-46f1-9cff-56896a36c7fb"],
Cell[29836, 1012, 793, 24, 1211, "Text",ExpressionUUID->"e83236e5-8e85-4017-88eb-8a07932b83a1"],
Cell[30632, 1038, 1607, 54, 2634, "Text",ExpressionUUID->"75baf6eb-3e43-45d1-a60a-d25b66f40262"]
}, Closed]],
Cell[CellGroupData[{
Cell[32276, 1097, 152, 2, 43, "Subsection",ExpressionUUID->"f60eec5e-56ea-4898-918b-1bf4a751fe7f"],
Cell[32431, 1101, 787, 21, 4515, "Text",ExpressionUUID->"8ada4136-3fc1-4de6-8fa4-13a13b9a60ae"],
Cell[33221, 1124, 595, 18, 1211, "Text",ExpressionUUID->"5fb3fc67-e161-4f42-bc21-919661cb1910"],
Cell[33819, 1144, 411, 13, 730, "Text",ExpressionUUID->"7e360fa6-3f45-4ed2-982d-450fad317033"],
Cell[34233, 1159, 727, 22, 2102, "Text",ExpressionUUID->"859dd086-a6a1-4807-9d8c-b736ac2e486a"],
Cell[34963, 1183, 541, 16, 2129, "Text",ExpressionUUID->"d3cce596-762f-4f2d-a405-5510deaa6d28"],
Cell[35507, 1201, 726, 24, 2623, "Text",ExpressionUUID->"eabf8842-9fd1-4279-ad9a-7a5e0b8626a2"],
Cell[36236, 1227, 2120, 84, 6510, "Text",ExpressionUUID->"c1433082-d37f-4f12-b578-4550fe5d0872"],
Cell[38359, 1313, 651, 15, 2585, "Text",ExpressionUUID->"2e30bcb5-c96e-49c8-86fe-58c6f57a6e60"],
Cell[39013, 1330, 889, 23, 3554, "Text",ExpressionUUID->"3d2fa420-c2f3-4c54-9c44-2bfa509aac53"]
}, Closed]],
Cell[CellGroupData[{
Cell[39939, 1358, 159, 2, 43, "Subsection",ExpressionUUID->"08bf26da-9c5d-441d-a0ac-426b2a1c0aa5"],
Cell[40101, 1362, 183, 4, 1183, "Text",ExpressionUUID->"e2e22da1-3418-4930-8e4b-fe0ef75f78ac"],
Cell[CellGroupData[{
Cell[40309, 1370, 976, 34, 3616, "Text",ExpressionUUID->"a31f900b-a568-444b-8abd-50aa8869db97"],
Cell[41288, 1406, 626, 21, 1262, "Text",ExpressionUUID->"a66f50f2-fe66-4f2d-b228-4ab07e1f8412"],
Cell[41917, 1429, 662, 22, 1262, "Text",ExpressionUUID->"b1933f76-e5a6-4d5d-8511-49d0b6b3451b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42616, 1456, 1083, 34, 3609, "Text",ExpressionUUID->"7820a9a8-932c-47ae-a809-2a828e939880"],
Cell[43702, 1492, 662, 22, 1262, "Text",ExpressionUUID->"a1bceec7-a767-4112-91cf-240095778dfc"],
Cell[44367, 1516, 719, 24, 1262, "Text",ExpressionUUID->"c3774d73-94cf-4614-8617-3fdd31baf72d"],
Cell[45089, 1542, 615, 24, 1183, "Text",ExpressionUUID->"15da7955-0c93-4dac-9fa2-6167e3abbeee"],
Cell[45707, 1568, 639, 20, 2129, "Text",ExpressionUUID->"95d3bd87-c09e-4625-b991-983f2c00a476"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46383, 1593, 1609, 56, 4988, "Text",ExpressionUUID->"0bf673b3-36cc-4bd2-99a1-a3e5a8171415"],
Cell[47995, 1651, 1071, 41, 1695, "Text",ExpressionUUID->"c09563a3-175c-44b4-a6c1-03698228b4f1"],
Cell[49069, 1694, 2013, 76, 1737, "Text",ExpressionUUID->"7ebdcda5-073b-4da0-9913-eed447bf297b"],
Cell[51085, 1772, 1050, 36, 3109, "Text",ExpressionUUID->"e9ae95a4-e0e7-4ffb-81ce-3f2d062b2ebe"]
}, Open  ]],
Cell[52150, 1811, 903, 32, 3239, "Text",ExpressionUUID->"20aced06-5c1a-4b6d-8c46-5ee843d661b4"],
Cell[53056, 1845, 1080, 42, 2690, "Text",ExpressionUUID->"a6b7f3a8-ba90-45cf-806d-a5ebc95a9615"],
Cell[CellGroupData[{
Cell[54161, 1891, 847, 24, 3570, "Text",ExpressionUUID->"f39e662e-6c23-45cc-b88d-f6b94c24dda1"],
Cell[55011, 1917, 538, 14, 810, "Text",ExpressionUUID->"4ad6d70a-4fd4-4ddb-8ff9-5c9eeb52f2da"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[55598, 1937, 156, 2, 43, "Subsection",ExpressionUUID->"b3fc218f-744e-458a-bd02-e2905241cb99"],
Cell[55757, 1941, 501, 10, 146, "Text",ExpressionUUID->"109c1e99-f680-430d-aafe-974131b206be"],
Cell[CellGroupData[{
Cell[56283, 1955, 425, 13, 56, "Subsubsection",ExpressionUUID->"fbe4dd2f-1b43-4d96-a70f-76b5e61e5e1e"],
Cell[56711, 1970, 787, 26, 205, "Text",ExpressionUUID->"6767cfe3-c5df-4c67-900f-04e51f9788e8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57535, 2001, 412, 12, 78, "Subsubsection",ExpressionUUID->"52c7bcf0-749e-442c-898f-4e41fa314e3f"],
Cell[57950, 2015, 678, 21, 294, "Text",ExpressionUUID->"954316ed-4edc-4669-8738-5d1d24aeeee8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58665, 2041, 406, 12, 78, "Subsubsection",ExpressionUUID->"c2df9beb-d144-49db-9e07-c2b52900651f"],
Cell[59074, 2055, 479, 15, 204, "Text",ExpressionUUID->"b1514241-27bd-4859-b52c-f36d2047bf87"]
}, Closed]],
Cell[CellGroupData[{
Cell[59590, 2075, 402, 12, 60, "Subsubsection",ExpressionUUID->"f89da904-0f7e-4a41-beb6-d15a1df443ff"],
Cell[59995, 2089, 496, 15, 204, "Text",ExpressionUUID->"5bf769a5-b844-4106-b65c-6606ba9c063e"]
}, Closed]],
Cell[CellGroupData[{
Cell[60528, 2109, 478, 15, 60, "Subsubsection",ExpressionUUID->"197c7693-d138-480d-815a-20976cc3d5e6"],
Cell[61009, 2126, 467, 19, 68, "Text",ExpressionUUID->"d2a6fd66-b905-490c-a1ca-fbeccb4ed162"]
}, Open  ]],
Cell[61491, 2148, 694, 22, 159, "Text",ExpressionUUID->"1da44339-3e30-4371-8e1d-245b4c76493c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62222, 2175, 137, 2, 93, "Subsection",ExpressionUUID->"93f8b4b4-559e-4ec1-861f-3bffe108948b"],
Cell[62362, 2179, 495, 12, 7019, "Text",ExpressionUUID->"b1f6a197-ddd7-489d-a998-6a920557c034"]
}, Closed]],
Cell[62872, 2194, 585, 12, 194, "Text",ExpressionUUID->"ce903355-bd00-4c02-8142-530a0607a573"],
Cell[63460, 2208, 801, 30, 161, "Text",ExpressionUUID->"f33c8ce5-d142-4560-abbb-7716c76b7d93"]
}, Closed]],
Cell[64276, 2241, 120, 3, 32, "Text",ExpressionUUID->"b65d8ee8-2f6d-4af3-8212-5637a54f4474"],
Cell[CellGroupData[{
Cell[64421, 2248, 202, 5, 85, "Section",ExpressionUUID->"ee6effb8-abac-448e-8d16-d04c591c5a02"],
Cell[64626, 2255, 180, 4, 1538, "Input",ExpressionUUID->"ae28db5a-38c1-48a5-ab27-40648f80d51d"],
Cell[CellGroupData[{
Cell[64831, 2263, 142, 3, 2471, "Input",ExpressionUUID->"a99268d3-baa0-4575-a11a-7af576bbc269",
 InitializationCell->True],
Cell[64976, 2268, 757, 15, 70, "Message",ExpressionUUID->"df763ac3-9753-40a6-a39f-5fff943cfe00"]
}, Open  ]],
Cell[65748, 2286, 536, 16, 4650, "Text",ExpressionUUID->"e883cdef-f3f8-443e-b8e4-2d5f2af27028"],
Cell[66287, 2304, 86, 0, 1538, "Input",ExpressionUUID->"cc6976d9-2e40-43ea-81fe-f25eb0f7084b"],
Cell[66376, 2306, 485, 16, 3322, "Text",ExpressionUUID->"aa546552-0d1c-48ef-ab6b-1d813fda1443"],
Cell[66864, 2324, 297, 8, 3322, "Text",ExpressionUUID->"469b5241-371d-4ff1-806b-8b5b94c61778"]
}, Closed]],
Cell[67176, 2335, 120, 3, 32, "Text",ExpressionUUID->"b929167e-301b-47e0-bb06-fd8b7e56756f"],
Cell[67299, 2340, 252, 6, 85, "Section",ExpressionUUID->"d4db6884-e79e-430e-a3bc-05bcdb8f3307"],
Cell[CellGroupData[{
Cell[67576, 2350, 247, 4, 43, "Subsection",ExpressionUUID->"960d3d59-44b4-4599-a928-fb011bcb1f83"],
Cell[67826, 2356, 344, 8, 40, "Input",ExpressionUUID->"8b295497-70f6-42f8-b3ab-461017426410"],
Cell[68173, 2366, 1351, 33, 72, "Input",ExpressionUUID->"06525bfd-0c76-4938-b208-b2b6e7606d6b"],
Cell[CellGroupData[{
Cell[69549, 2403, 147, 3, 40, "Input",ExpressionUUID->"3cede667-5d72-4da7-83cf-93f9f60f6442"],
Cell[69699, 2408, 1511, 38, 107, "Print",ExpressionUUID->"8d375a40-4915-4d10-a2e1-608e83889138"],
Cell[71213, 2448, 1324, 34, 32, "Print",ExpressionUUID->"94d7ff4e-1a1d-40c6-b6b0-2d03f0583518"],
Cell[72540, 2484, 1615, 42, 146, "Print",ExpressionUUID->"7384de08-f328-4a91-8bea-139649606a95"],
Cell[74158, 2528, 520, 10, 32, "Print",ExpressionUUID->"a6bb9dcd-fb26-40c3-a834-22999c615456"],
Cell[74681, 2540, 524, 10, 32, "Print",ExpressionUUID->"92be932e-f87e-4b7b-baf9-82274d43013f"],
Cell[75208, 2552, 540, 10, 32, "Print",ExpressionUUID->"165f6d45-b765-43f1-831d-baf07a7e2472"],
Cell[75751, 2564, 577, 10, 32, "Print",ExpressionUUID->"f21b06ee-62e6-46c5-aa58-1e9672c14bab"],
Cell[76331, 2576, 524, 10, 32, "Print",ExpressionUUID->"05aa453a-aeca-4662-9634-742fc54e8d91"],
Cell[76858, 2588, 522, 10, 32, "Print",ExpressionUUID->"9e34f33e-7daf-47e4-855d-76600199e357"],
Cell[77383, 2600, 455, 10, 45, "Print",ExpressionUUID->"06bf413c-5978-4e9d-a85b-1c04b70093bb"],
Cell[77841, 2612, 528, 10, 32, "Print",ExpressionUUID->"2ccc7cfe-80b0-4f25-b2d5-ff12f97ad9d5"],
Cell[78372, 2624, 370, 5, 32, "Print",ExpressionUUID->"68919bc5-32e9-4b00-b83c-6f31193bca80"]
}, Open  ]],
Cell[78757, 2632, 1945, 54, 105, "Input",ExpressionUUID->"f144990b-57e6-49c4-94cf-2acdb48ad19a"],
Cell[CellGroupData[{
Cell[80727, 2690, 496, 11, 69, "Input",ExpressionUUID->"e04c1855-65c0-4878-93ef-59df489f91af"],
Cell[81226, 2703, 2417, 69, 137, "Output",ExpressionUUID->"c9b7f7a7-34d5-489a-b03a-b1c80da29e3f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83680, 2777, 1328, 40, 125, "Input",ExpressionUUID->"f7605d14-a658-4fec-8f63-8655082f1127"],
Cell[85011, 2819, 421, 7, 46, "Output",ExpressionUUID->"3510e300-56ab-4021-b54d-0b7510a563e4"],
Cell[85435, 2828, 528, 11, 46, "Output",ExpressionUUID->"e39ddd92-102c-4056-9638-c23992ded6bc"],
Cell[85966, 2841, 423, 7, 46, "Output",ExpressionUUID->"75bd6264-e28b-43b8-8040-ddbdc28b1b31"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86426, 2853, 408, 10, 69, "Input",ExpressionUUID->"3d0d9396-a6f2-4e5e-acc7-2e61c566926a"],
Cell[86837, 2865, 12614, 361, 552, "Output",ExpressionUUID->"d13c7b4d-2a41-4f6a-bf49-e130a3ed6940"]
}, Open  ]],
Cell[CellGroupData[{
Cell[99488, 3231, 546, 12, 69, "Input",ExpressionUUID->"cee50043-606f-4cef-be98-86564c267161"],
Cell[100037, 3245, 1922, 60, 82, "Output",ExpressionUUID->"beae9bb3-ecee-4097-b3c0-a2e5893b46cd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101996, 3310, 252, 7, 40, "Input",ExpressionUUID->"692866ed-fd5b-41d3-b09d-e58e231775bc"],
Cell[102251, 3319, 2197, 66, 162, "Output",ExpressionUUID->"f6db7a6d-e90e-4726-9b82-edc54075a770"]
}, Open  ]],
Cell[CellGroupData[{
Cell[104485, 3390, 369, 10, 40, "Input",ExpressionUUID->"480d6932-b1ff-41e0-a45f-df2c968321c9"],
Cell[104857, 3402, 531, 14, 50, "Output",ExpressionUUID->"438493ea-f30e-4c2e-8042-78ce09a9f8df"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105425, 3421, 603, 15, 69, "Input",ExpressionUUID->"201a8a4e-485d-4837-9a27-62a765db8ed1"],
Cell[106031, 3438, 1784, 54, 146, "Output",ExpressionUUID->"9f3dd966-d6b6-4c07-9b48-b2ea21b40f2e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107852, 3497, 1174, 36, 121, "Input",ExpressionUUID->"b7238b5e-7be3-46d2-90b2-64900ce0756c"],
Cell[109029, 3535, 548, 14, 46, "Output",ExpressionUUID->"c2ef05f3-47d8-4da9-a3df-1d5c37ac8314"]
}, Open  ]],
Cell[CellGroupData[{
Cell[109614, 3554, 1634, 43, 136, "Input",ExpressionUUID->"06fb4256-ff0d-4289-9ef6-420d3c38ebd1"],
Cell[111251, 3599, 5438, 150, 210, "Output",ExpressionUUID->"b5695827-fb89-4bfa-9fed-ad537dd343db"],
Cell[116692, 3751, 465, 9, 50, "Output",ExpressionUUID->"67d0e963-9ec4-4c87-a5f9-812c50490f7a"],
Cell[117160, 3762, 643, 16, 46, "Output",ExpressionUUID->"7f46773f-cff7-4a35-941b-10ff1ebf80ee"]
}, Open  ]],
Cell[117818, 3781, 517, 11, 40, "Input",ExpressionUUID->"617f5b54-a9bf-44d4-850f-e5d6213c1ae2"],
Cell[CellGroupData[{
Cell[118360, 3796, 260, 7, 40, "Input",ExpressionUUID->"acac5274-9c6b-45e0-8f52-1083131148fe"],
Cell[118623, 3805, 632, 18, 50, "Output",ExpressionUUID->"ed237cc5-240d-4493-8e04-5a63bf31fd00"]
}, Open  ]],
Cell[CellGroupData[{
Cell[119292, 3828, 530, 15, 69, "Input",ExpressionUUID->"d6978ab3-1e4c-49be-8521-f45ac120dfd7"],
Cell[119825, 3845, 653, 20, 46, "Output",ExpressionUUID->"ee428f28-869f-4dcc-b0a9-0d484c95398f"]
}, Open  ]],
Cell[120493, 3868, 193, 4, 40, "Input",ExpressionUUID->"758213cf-93f9-481b-a063-98af91581e02"]
}, Closed]],
Cell[CellGroupData[{
Cell[120723, 3877, 768, 13, 43, "Subsection",ExpressionUUID->"fa39f474-d804-480f-abfa-a53fd6c58997"],
Cell[121494, 3892, 663, 17, 69, "Input",ExpressionUUID->"bd803918-bbfd-4631-b1bb-c284e6aaa812"],
Cell[122160, 3911, 501, 10, 40, "Input",ExpressionUUID->"03a2a5b0-db96-4d79-a30f-a2b3b1dd0fe3"],
Cell[122664, 3923, 1989, 49, 69, "Input",ExpressionUUID->"1b40145d-a902-4da4-af9f-08ac0060645a"],
Cell[CellGroupData[{
Cell[124678, 3976, 147, 3, 40, "Input",ExpressionUUID->"5b3b1dc9-c0a7-4c10-87bb-abb57568533b"],
Cell[124828, 3981, 3327, 78, 111, "Print",ExpressionUUID->"00a41a98-6aa7-400f-9bfb-306820ca074f"],
Cell[128158, 4061, 3088, 78, 58, "Print",ExpressionUUID->"fc5ae938-f3a5-4895-90a3-4e78743f36b9"],
Cell[131249, 4141, 3687, 92, 163, "Print",ExpressionUUID->"b0eb3bca-cbfc-4ab6-8b01-cc4797d056ad"],
Cell[134939, 4235, 583, 11, 32, "Print",ExpressionUUID->"d12e66b3-d69b-4c29-8db5-69870908ea23"],
Cell[135525, 4248, 624, 11, 32, "Print",ExpressionUUID->"b509c52c-09e2-4305-a8ea-78067e1cd938"],
Cell[136152, 4261, 611, 11, 32, "Print",ExpressionUUID->"772a2493-5e46-4c45-a180-ae310b941d08"],
Cell[136766, 4274, 638, 11, 32, "Print",ExpressionUUID->"f8a0458f-22ad-4f38-9fd5-839abf53f365"],
Cell[137407, 4287, 624, 11, 32, "Print",ExpressionUUID->"1d32130e-6562-4a43-9bcc-0add744f8b0f"],
Cell[138034, 4300, 619, 11, 32, "Print",ExpressionUUID->"4b46bd46-7f2a-4053-b5ba-83b916b29569"],
Cell[138656, 4313, 601, 11, 32, "Print",ExpressionUUID->"739fb512-4682-44b4-a935-9ec8eec30258"],
Cell[139260, 4326, 437, 6, 32, "Print",ExpressionUUID->"9d21f570-c78b-4e4f-b01a-a556caa42cf3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[139734, 4337, 878, 21, 153, "Input",ExpressionUUID->"4a4c67a8-b7fc-49bb-a8b6-ddf8974efe4f"],
Cell[140615, 4360, 736, 16, 46, "Output",ExpressionUUID->"5b6d3c1c-e8c7-4b5a-b604-636b5d174bb7"],
Cell[141354, 4378, 736, 16, 46, "Output",ExpressionUUID->"764fd5fc-e074-48f1-9b7b-801f84e78e99"],
Cell[142093, 4396, 736, 16, 46, "Output",ExpressionUUID->"16dbde58-a8c4-457f-aad3-7db9da94ac05"]
}, Open  ]],
Cell[CellGroupData[{
Cell[142866, 4417, 194, 4, 40, "Input",ExpressionUUID->"73eee0d8-5312-40a8-ac98-4b07ade2b22d"],
Cell[143063, 4423, 832, 23, 134, "Output",ExpressionUUID->"2ca34280-fac2-4a94-8223-731e476e5378"]
}, Open  ]],
Cell[CellGroupData[{
Cell[143932, 4451, 196, 4, 40, "Input",ExpressionUUID->"88e4f444-2e0c-49d2-98d0-5a135dd4e07f"],
Cell[144131, 4457, 793, 22, 110, "Output",ExpressionUUID->"e24a0b81-c016-4fe4-83dc-b2813d9477f0"]
}, Open  ]],
Cell[144939, 4482, 5944, 171, 508, "Input",ExpressionUUID->"fc8980dd-572a-4ea2-871d-a3b63ab9418e"],
Cell[CellGroupData[{
Cell[150908, 4657, 878, 24, 104, "Input",ExpressionUUID->"86567fbd-c4bc-44d5-b3d2-b80a8f11409b"],
Cell[151789, 4683, 2462, 67, 194, "Output",ExpressionUUID->"89f3179d-fd22-47c5-aca1-c88ded39c4d9"],
Cell[154254, 4752, 2148, 55, 202, "Output",ExpressionUUID->"4a0a7bf8-40f1-4620-b79d-b0106d7bce03"]
}, Open  ]],
Cell[CellGroupData[{
Cell[156439, 4812, 875, 26, 84, "Input",ExpressionUUID->"b5bd3ca8-64dc-44df-bfd7-68d03e404b50"],
Cell[157317, 4840, 1381, 34, 77, "Output",ExpressionUUID->"500f2e25-ea6b-4cd8-99b0-ba56e6624811"]
}, Open  ]],
Cell[158713, 4877, 445, 13, 40, "Input",ExpressionUUID->"c9344d7b-a4b8-42af-876c-96ac55d95339"],
Cell[CellGroupData[{
Cell[159183, 4894, 516, 15, 69, "Input",ExpressionUUID->"90818ef1-04ef-4b35-b40b-0985befaa4f6"],
Cell[159702, 4911, 473, 14, 48, "Output",ExpressionUUID->"808cb14f-753e-4d2f-91dd-f23d6a9ff915"]
}, Closed]],
Cell[CellGroupData[{
Cell[160212, 4930, 558, 16, 62, "Input",ExpressionUUID->"ff744f14-8881-4044-a0c5-2e3d3401ae66"],
Cell[160773, 4948, 667, 15, 46, "Output",ExpressionUUID->"7df654c0-0efc-47b4-8362-e13185dc0eed"]
}, Closed]],
Cell[CellGroupData[{
Cell[161477, 4968, 546, 16, 62, "Input",ExpressionUUID->"eb984dab-1cef-41d5-b72b-b9201250e01b"],
Cell[162026, 4986, 736, 16, 46, "Output",ExpressionUUID->"f549de37-4485-4ecd-9e95-aa2fc9c32e93"]
}, Closed]],
Cell[CellGroupData[{
Cell[162799, 5007, 624, 18, 62, "Input",ExpressionUUID->"592db7d8-1297-4696-8cd2-3967e9dffcc9"],
Cell[163426, 5027, 891, 24, 662, "Output",ExpressionUUID->"bf5bb0e6-1a46-463f-b6c6-b3737856b636"]
}, Closed]],
Cell[CellGroupData[{
Cell[164354, 5056, 739, 20, 62, "Input",ExpressionUUID->"528cc183-000a-4fba-beb7-6ced103ed7f6"],
Cell[165096, 5078, 1439, 33, 1470, "Output",ExpressionUUID->"f3af9cd2-4c10-41b0-ae24-327f7807d166"]
}, Closed]],
Cell[CellGroupData[{
Cell[166572, 5116, 464, 13, 62, "Input",ExpressionUUID->"162c3115-ca9c-4576-ba05-f1e92da5110e"],
Cell[167039, 5131, 1482, 42, 1099, "Output",ExpressionUUID->"097ba427-3101-453b-b447-f9c2d817791c"]
}, Closed]],
Cell[CellGroupData[{
Cell[168558, 5178, 504, 14, 62, "Input",ExpressionUUID->"239eca5a-6e9b-4fcd-94b8-7df4626c6b52"],
Cell[169065, 5194, 1973, 47, 1587, "Output",ExpressionUUID->"302986a3-97d5-46de-9add-1357d8e3cf8a"]
}, Closed]],
Cell[CellGroupData[{
Cell[171075, 5246, 584, 16, 63, "Input",ExpressionUUID->"6ec639ca-045b-4663-9b20-c1ae687dc312"],
Cell[171662, 5264, 487, 11, 644, "Output",ExpressionUUID->"8040d046-d31e-4a73-9e94-f320d5b5297a"]
}, Closed]],
Cell[CellGroupData[{
Cell[172186, 5280, 462, 13, 62, "Input",ExpressionUUID->"a7f4d4bd-d595-4ac1-a771-520189140943"],
Cell[172651, 5295, 2949, 77, 132, "Output",ExpressionUUID->"f78b32b5-871a-476b-be43-1fe6bd433887"]
}, Open  ]],
Cell[CellGroupData[{
Cell[175637, 5377, 90, 0, 40, "Input",ExpressionUUID->"b0c5d5da-03cf-4d5a-b333-1932e0b08af4"],
Cell[175730, 5379, 214, 5, 46, "Output",ExpressionUUID->"29ba3ead-4306-49b1-a728-9e0538c45c65"]
}, Open  ]],
Cell[CellGroupData[{
Cell[175981, 5389, 611, 18, 97, "Input",ExpressionUUID->"96a375cc-d97f-443e-a901-640c93f088ac"],
Cell[176595, 5409, 690, 19, 82, "Output",ExpressionUUID->"062d172e-d084-4341-8bcb-573d8fe41c2d"],
Cell[177288, 5430, 2766, 76, 152, "Output",ExpressionUUID->"5862b0da-31c5-455d-9268-001087aad2ac"]
}, Open  ]],
Cell[CellGroupData[{
Cell[180091, 5511, 345, 8, 40, "Input",ExpressionUUID->"300955a5-db3c-4266-8d43-0e2e862b6392"],
Cell[180439, 5521, 4257, 107, 134, "Print",ExpressionUUID->"89c04bc6-c55a-4c0d-a047-fd828812dae9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[184733, 5633, 535, 15, 44, "Input",ExpressionUUID->"6593738b-6c18-4010-a85e-5536c21f6547"],
Cell[185271, 5650, 671, 17, 69, "Input",ExpressionUUID->"cc22990c-3d6c-4cf0-8f8a-6e152140262a"],
Cell[CellGroupData[{
Cell[185967, 5671, 402, 12, 58, "Input",ExpressionUUID->"a9729b4c-e5f9-4fe8-be54-18c537adcd1a"],
Cell[186372, 5685, 1083, 25, 46, "Output",ExpressionUUID->"f724650b-c9af-4b6f-93a7-9a4547be4192"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187492, 5715, 2824, 69, 202, "Input",ExpressionUUID->"22f3e54c-3a85-4b6f-a4e7-da70a5c5b153"],
Cell[190319, 5786, 205, 4, 46, "Output",ExpressionUUID->"0f1de97d-4a9c-4c74-ba47-38f36fa663a2"],
Cell[190527, 5792, 222, 5, 46, "Output",ExpressionUUID->"f1f1bdfe-b6bb-4bb6-97ce-b5ab725e4b47"]
}, Open  ]],
Cell[190764, 5800, 2420, 66, 256, "Input",ExpressionUUID->"2aea9703-4dda-43af-8aa6-ff81d07b0fd2"],
Cell[CellGroupData[{
Cell[193209, 5870, 303, 8, 56, "Input",ExpressionUUID->"5218cea2-30ea-4d67-917f-abaefd08e957"],
Cell[193515, 5880, 483, 16, 64, "Output",ExpressionUUID->"ca9502c2-ee0d-422d-8235-599e6b0a09dd"]
}, Open  ]],
Cell[194013, 5899, 2906, 72, 449, "Input",ExpressionUUID->"082be1fd-fd73-4dca-b3af-aadfc386c2f3"],
Cell[CellGroupData[{
Cell[196944, 5975, 227, 5, 56, "Input",ExpressionUUID->"96fde3d8-3a54-4efa-8d82-0106ea6fc916"],
Cell[197174, 5982, 7768, 203, 280, "Output",ExpressionUUID->"4cb41bfd-ec94-4649-91ef-8bdff33874a8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[204979, 6190, 3716, 113, 835, "Input",ExpressionUUID->"d15753e3-49b9-4335-baab-cc07dc710d99"],
Cell[208698, 6305, 432, 10, 64, "Output",ExpressionUUID->"a66be7fe-ac8b-4c21-9790-412fbefe2417"],
Cell[209133, 6317, 468, 11, 64, "Output",ExpressionUUID->"6b7bcf9d-0a6d-44c2-b569-d981a24179fe"],
Cell[209604, 6330, 488, 12, 64, "Output",ExpressionUUID->"c50571b6-4690-41d5-9b78-997b05703a34"],
Cell[210095, 6344, 401, 9, 64, "Output",ExpressionUUID->"cc4153c9-4481-4472-82a9-f58e0fc5a9c1"],
Cell[210499, 6355, 629, 14, 971, "Output",ExpressionUUID->"287c9fab-13b6-40fb-acee-02c4ac9673a4"],
Cell[211131, 6371, 5358, 149, 7415, "Output",ExpressionUUID->"487a9c3b-28e3-464d-8c23-bf477cd17407"],
Cell[216492, 6522, 474, 10, 644, "Output",ExpressionUUID->"46ceaed9-17ff-400b-9f3a-f614cf92956e"],
Cell[216969, 6534, 248, 3, 644, "Output",ExpressionUUID->"5f1dc399-1eb6-4e69-86ed-e023122256d1"]
}, Open  ]],
Cell[217232, 6540, 1096, 25, 1394, "Input",ExpressionUUID->"5af9a251-7701-440b-906f-e0e040bc2ada"],
Cell[218331, 6567, 467, 13, 561, "Input",ExpressionUUID->"0b9dc60a-9782-416e-9f3d-aac524c674d7"],
Cell[CellGroupData[{
Cell[218823, 6584, 811, 20, 1874, "Input",ExpressionUUID->"8b77b810-7877-489e-bc40-ec720256be58"],
Cell[219637, 6606, 1563, 36, 1482, "Output",ExpressionUUID->"514f6daf-5162-42d6-948b-a4900f401275"],
Cell[221203, 6644, 942, 22, 1776, "Output",ExpressionUUID->"18add396-db3f-4626-b18f-7fcaddcf0cb6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[222182, 6671, 584, 15, 971, "Input",ExpressionUUID->"ccdfab94-771f-4208-8ae8-c5b6fe66a4b0"],
Cell[222769, 6688, 481, 11, 662, "Output",ExpressionUUID->"ae24f4e9-44a3-4f45-b0d0-16680a2f2072"]
}, Open  ]],
Cell[CellGroupData[{
Cell[223287, 6704, 751, 19, 1373, "Input",ExpressionUUID->"21908ccf-04c7-4184-951b-234bbc23bca5"],
Cell[224041, 6725, 946, 24, 2074, "Output",ExpressionUUID->"2a77e9f7-cdc2-4a36-9e14-95b456248515"]
}, Open  ]],
Cell[CellGroupData[{
Cell[225024, 6754, 555, 17, 1099, "Input",ExpressionUUID->"9ccd0ecd-5038-4f0e-b24b-a422b59e5cea"],
Cell[225582, 6773, 421, 11, 1099, "Input",ExpressionUUID->"b80cf608-8aff-48db-8740-7652103ab84c"],
Cell[CellGroupData[{
Cell[226028, 6788, 1005, 26, 1902, "Input",ExpressionUUID->"5a87d6ed-5e14-43df-907b-059da88d964c"],
Cell[227036, 6816, 603, 15, 1261, "Output",ExpressionUUID->"3ab09f6e-94b9-4281-a8b6-ecb86a47b845"]
}, Open  ]],
Cell[CellGroupData[{
Cell[227676, 6836, 3062, 75, 5161, "Input",ExpressionUUID->"db701f15-c07f-428f-b245-053d3395496a"],
Cell[230741, 6913, 1675, 46, 76, "Output",ExpressionUUID->"fe9f2bca-ad2f-4e02-8596-e71ad9a02cc5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[232453, 6964, 3521, 90, 283, "Input",ExpressionUUID->"639df8da-905a-4ef1-96f8-cd0dd6224960"],
Cell[235977, 7056, 2086, 57, 154, "Output",ExpressionUUID->"849a2fa1-2533-4372-b2a1-5b41292c7ba7"]
}, Open  ]],
Cell[238078, 7116, 951, 23, 126, "Input",ExpressionUUID->"82a248f0-6b1a-496b-a1c5-9c6c4987956b"],
Cell[CellGroupData[{
Cell[239054, 7143, 1262, 31, 74, "Input",ExpressionUUID->"63583de1-f203-4683-b615-bb4aab4df8ef"],
Cell[240319, 7176, 1774, 48, 111, "Output",ExpressionUUID->"1eec2078-4974-489c-ab6d-0c0b90b4701b"]
}, Open  ]],
Cell[242108, 7227, 191, 4, 40, "Input",ExpressionUUID->"820cd1d3-dea6-48b8-a6c9-6566bd0f6caf"]
}, Open  ]],
Cell[242314, 7234, 189, 4, 40, "Input",ExpressionUUID->"69d7e86e-76a0-4030-88e2-29d2057fca2f"]
}, Open  ]],
Cell[242518, 7241, 1002, 32, 40, "Input",ExpressionUUID->"626ace68-fd4b-40c1-9fe0-429900aa2e5b"],
Cell[243523, 7275, 193, 4, 40, "Input",ExpressionUUID->"64af0b94-a472-445b-8855-c20200ec1c45"]
}, Open  ]],
Cell[243731, 7282, 221, 5, 40, "Input",ExpressionUUID->"5b74c4d6-37de-4227-b4b9-b25a5d28c258"]
}
]
*)

